# Getting Started with Beaver

## Getting Started

### Install the Package

Install the gem from the command line:

```ruby
gem install apimaticcalculatortest -v 1.0.0
```

Or add the gem to your Gemfile and run `bundle`:

```ruby
gem 'apimaticcalculatortest', '1.0.0'
```

For additional gem details, see the [RubyGems page for the apimaticcalculatortest gem](https://rubygems.org/gems/apimaticcalculatortest/versions/1.0.0).

### Environments

The SDK can be configured to use a different environment for making API calls. Available environments are:

#### Fields

| Name | Description |
|  --- | --- |
| production | **Default** POC |
| environment2 | Internal Stage |
| environment3 | External Stage |
| environment4 | Production |

### Initialize the API Client

The following parameters are configurable for the API Client:

| Parameter | Type | Description |
|  --- | --- | --- |
| `app_token` | `String` |  |
| `environment` | Environment | The API environment. <br> **Default: `Environment.PRODUCTION`** |
| `timeout` | `Float` | The value to use for connection timeout. <br> **Default: 60** |
| `max_retries` | `Integer` | The number of times to retry an endpoint call if it fails. <br> **Default: 0** |
| `retry_interval` | `Float` | Pause in seconds between retries. <br> **Default: 1** |
| `backoff_factor` | `Float` | The amount to multiply each successive retry's interval amount by in order to provide backoff. <br> **Default: 1** |

The API client can be initialized as follows:

```ruby
client = Beaver::Client.new(
  app_token: 'App-Token',
  environment: Environment::PRODUCTION,
)
```

### Authorization

This API uses `Custom Header Signature`.

## Client Class Documentation

### Beaver Client

The gateway for the SDK. This class acts as a factory for the Controllers and also holds the configuration of the SDK.

### Controllers

| Name | Description |
|  --- | --- |
| api | Gets APIController |

## API Reference

### List of APIs

* [API](#api)

### API

#### Overview

##### Get instance

An instance of the `APIController` class can be accessed from the API Client.

```
client_controller = client.client
```

#### POST Accounts

The POST /accounts call allows your platform to create a new account owned by a legal entity. The accounts resource allows your platform to create a new merchant account for each distinct business purpose.

```ruby
def post_accounts(app_id,
                  app_token,
                  api_version,
                  body,
                  unique_key: nil,
                  we_pay_risk_token: nil,
                  client_ip: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`AccountsRequest`](#accounts-request) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `we_pay_risk_token` | `String` | Header, Optional | - |
| `client_ip` | `String` | Header, Optional | - |

##### Response Type

[`AccountResp`](#account-resp)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = AccountsRequest.new
body.description = 'The Foo Bar campaign is raising money for Bar Baz.'
body.incoming_payments = IncomingPaymentsReq.new
body.incoming_payments.opted_out_methods = OptedOutMethods.new
body.incoming_payments.opted_out_methods.countries = CountriesOptedOutMethods.new
body.incoming_payments.opted_out_methods.countries.ca = CountryOptedOutMethods.new
body.incoming_payments.opted_out_methods.countries.ca.debit_cards = true
body.industry = Industry.new
body.industry.category_detail = 'Website design'
body.industry.merchant_category_code = '7333'
body.legal_entity_id = '3cd20b3c-4008-400b-b708-2b844ce7be84'
body.name = 'Foo Bar campaign'
body.payout = PayoutReq.new
body.payout.currencies = Currencies3.new
body.payout.currencies.usd = USD2.new
body.payout.currencies.usd.payout_method_id = '0102b1c6-2bc7-448a-aa1d-076b1637547c'
body.payout.currencies.usd.period = PeriodEnum::DAILY
body.statement_description = 'Thanks for your Foo Bar campaign donation'

result = client_controller.post_accounts(app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS, UNSUPPORTED_COUNTRY, UNSUPPORTED_CURRENCY | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Accounts

The GET /accounts call allows your platform to look up a collection of accounts. The accounts resource allows your platform to create a new merchant account for each distinct business purpose.

```ruby
def get_accounts(app_id,
                 app_token,
                 api_version,
                 unique_key: nil,
                 page: nil,
                 page_size: 10,
                 create_time_start: nil,
                 create_time_end: nil,
                 owner_id: nil,
                 beneficiary_legal_entity_id: nil,
                 reference_id: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 50` |
| `create_time_start` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the start of the search window, inclusive. |
| `create_time_end` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the end of the search window, inclusive. |
| `owner_id` | `String` | Query, Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `beneficiary_legal_entity_id` | `String` | Query, Optional | Filter search window by elements that match the account's beneficiary legal entity.<br>**Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `reference_id` | `String` | Query, Optional | Return elements having this reference_id. |

##### Response Type

[`AccountsResponse`](#accounts-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_accounts(app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Accounts-Id

The POST /accounts/{id} call allows your platform to update and add custom data to an account. The accounts resource allows your platform to create a new merchant account for each distinct business purpose.

```ruby
def post_accounts_id(id,
                     app_id,
                     app_token,
                     api_version,
                     body,
                     unique_key: nil,
                     we_pay_risk_token: nil,
                     client_ip: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`AccountsRequest1`](#accounts-request-1) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `we_pay_risk_token` | `String` | Header, Optional | - |
| `client_ip` | `String` | Header, Optional | - |

##### Response Type

[`AccountResp`](#account-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = AccountsRequest1.new
body.description = 'The Foo Bar campaign is raising money for Bar Baz.'
body.incoming_payments = IncomingPaymentsReq.new
body.incoming_payments.opted_out_methods = OptedOutMethods.new
body.incoming_payments.opted_out_methods.countries = CountriesOptedOutMethods.new
body.incoming_payments.opted_out_methods.countries.ca = CountryOptedOutMethods.new
body.incoming_payments.opted_out_methods.countries.ca.debit_cards = true
body.industry = Industry.new
body.industry.category_detail = 'Website design'
body.industry.merchant_category_code = '7333'
body.name = 'Foo Bar campaign'
body.payout = PayoutReq.new
body.payout.currencies = Currencies3.new
body.payout.currencies.usd = USD2.new
body.payout.currencies.usd.payout_method_id = '0102b1c6-2bc7-448a-aa1d-076b1637547c'
body.payout.currencies.usd.period = PeriodEnum::DAILY
body.payout.default_currency = CurrencyEnum::USD
body.statement_description = 'Thanks for your Foo Bar campaign donation'

result = client_controller.post_accounts_id(id, app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS, UNSUPPORTED_COUNTRY, UNSUPPORTED_CURRENCY | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 409 | RESOURCE_CONFLICT | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Accounts-Id

The GET /accounts/{id} call allows your platform to look up a single account. The accounts resource allows your platform to create a new merchant account for each distinct business purpose.

```ruby
def get_accounts_id(id,
                    app_id,
                    app_token,
                    api_version,
                    unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`AccountResp`](#account-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_accounts_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 401 | COULD_NOT_AUTHENTICATE | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Accounts-Id-Capabilities

The POST /accounts/{id}/capabilities call allows your platform to update an account's capabilities. The accounts resource allows your platform to create a new merchant account for each distinct business purpose.

```ruby
def post_accounts_id_capabilities(id,
                                  app_id,
                                  app_token,
                                  api_version,
                                  body,
                                  unique_key: nil,
                                  is_expanded: true)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`AccountsCapabilitiesRequest`](#accounts-capabilities-request) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `is_expanded` | `Boolean` | Query, Optional | Return a descriptive response enumerating any unfulfilled requirements.<br>**Default**: `true` |

##### Response Type

[`CapabilitiesResp`](#capabilities-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = AccountsCapabilitiesRequest.new
body.payouts = Payouts1.new
body.payouts.application_block = ApplicationBlock4.new
body.payouts.application_block.is_blocked = true
body.payouts.application_block.reason = 'This is a sham!'

result = client_controller.post_accounts_id_capabilities(id, app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Accounts-Id-Capabilities

The GET /accounts/{id}/capabilities call allows your platform to look up an account's capabilities. The accounts resource allows your platform to create a new merchant account for each distinct business purpose.

```ruby
def get_accounts_id_capabilities(id,
                                 app_id,
                                 app_token,
                                 api_version,
                                 unique_key: nil,
                                 is_expanded: true)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `is_expanded` | `Boolean` | Query, Optional | Return a descriptive response enumerating any unfulfilled requirements.<br>**Default**: `true` |

##### Response Type

[`CapabilitiesResp`](#capabilities-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_accounts_id_capabilities(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Adjustments

The GET /adjustments call allows your platform to look up a collection of adjustments. The adjustments resource notifies your platform that WePay made an adjustment to an account.

```ruby
def get_adjustments(app_id,
                    app_token,
                    api_version,
                    unique_key: nil,
                    page: nil,
                    page_size: 10,
                    create_time_start: nil,
                    create_time_end: nil,
                    owner_id: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 50` |
| `create_time_start` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the start of the search window, inclusive. |
| `create_time_end` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the end of the search window, inclusive. |
| `owner_id` | `String` | Query, Optional | - |

##### Response Type

[`AdjustmentsResponse`](#adjustments-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_adjustments(app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Adjustments-Id

The GET /adjustments/{id} call allows your platform to look up a single adjustment. The adjustments resource notifies your platform that WePay made an adjustment to an account.

```ruby
def get_adjustments_id(id,
                       app_id,
                       app_token,
                       api_version,
                       unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`Adjustments`](#adjustments)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_adjustments_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Adjustments-Id

The POST /adjustments/{id} call allows your platform to update and add custom data to an adjustment. The adjustments resource notifies your platform that WePay made an adjustment to an account.

```ruby
def post_adjustments_id(id,
                        app_id,
                        app_token,
                        api_version,
                        body,
                        unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`AdjustmentsRequest`](#adjustments-request) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`Adjustments`](#adjustments)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = AdjustmentsRequest.new
body.custom_data = JSON.parse('{"reference_number":43453}')

result = client_controller.post_adjustments_id(id, app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Billing Statements

The GET /billing_statements call allows your platform to look up a collection of billing statements. Billing statements provide aggregate transaction amounts for an account in a certain time period.

```ruby
def get_billing_statements(app_id,
                           app_token,
                           api_version,
                           unique_key: nil,
                           page: nil,
                           page_size: 10,
                           account_id: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 500` |
| `account_id` | `String` | Query, Optional | All billing statements owned by an account. |

##### Response Type

[`BillingStatementsResponse`](#billing-statements-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_billing_statements(app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Billing Statements-Id

The GET /billing_statements/{id} call allows your platform to look up a single billing statement. Billing statements provide aggregate transaction amounts for an account in a certain time period.

```ruby
def get_billing_statements_id(id,
                              app_id,
                              app_token,
                              api_version,
                              unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`BillingStatement`](#billing-statement)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_billing_statements_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Billing Statements-Id-Interchange Fees

Look up summaries of interchange fee transactions in a billing statement.

```ruby
def get_billing_statements_id_interchange_fees(id,
                                               app_id,
                                               app_token,
                                               api_version,
                                               unique_key: nil,
                                               page: nil,
                                               page_size: 10)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 500` |

##### Response Type

[`BillingStatementsInterchangeFeesResponse`](#billing-statements-interchange-fees-response)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_billing_statements_id_interchange_fees(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Billing Statements-Id-Transactions Summary

The GET /billing_statements/{id}/transactions_summary call allows your platform to look up all transactions in a single billing statement.

```ruby
def get_billing_statements_id_transactions_summary(id,
                                                   app_id,
                                                   app_token,
                                                   api_version,
                                                   unique_key: nil,
                                                   page: nil,
                                                   page_size: 10)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 500` |

##### Response Type

[`BillingStatementsTransactionsSummaryResponse`](#billing-statements-transactions-summary-response)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_billing_statements_id_transactions_summary(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Disputes

The GET /disputes call allows your platform to look up a collection of disputes. Disputes represent a conflict between a payer and merchant.

```ruby
def get_disputes(app_id,
                 app_token,
                 api_version,
                 unique_key: nil,
                 page: nil,
                 page_size: 10,
                 create_time_start: nil,
                 create_time_end: nil,
                 owner_id: nil,
                 type: nil,
                 payment_id: nil,
                 status: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 50` |
| `create_time_start` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the start of the search window, inclusive. |
| `create_time_end` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the end of the search window, inclusive. |
| `owner_id` | `String` | Query, Optional | - |
| `type` | [`Type6Enum`](#type-6) | Query, Optional | The type of dispute to filter by |
| `payment_id` | `String` | Query, Optional | - |
| `status` | [`Status5Enum`](#status-5) | Query, Optional | - |

##### Response Type

[`DisputesResponse`](#disputes-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_disputes(app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Disputes-Id

The GET /disputes/{id} call allows your platform to look up a single dispute. Disputes represent a conflict between a payer and merchant.

```ruby
def get_disputes_id(id,
                    app_id,
                    app_token,
                    api_version,
                    content_type,
                    unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `content_type` | `String` | Header, Required | **Constraints**: *Pattern*: `application/json` |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`Disputes`](#disputes)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
content_type = 'Content-Type2'

result = client_controller.get_disputes_id(id, app_id, app_token, api_version, content_type, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Disputes-Id

The POST /disputes/{id}  call allows your platform to update and add custom data to a single dispute. Disputes represent a conflict between a payer and merchant.

```ruby
def post_disputes_id(id,
                     app_id,
                     app_token,
                     api_version,
                     body,
                     unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`DisputesRequest`](#disputes-request) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`Disputes`](#disputes)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = DisputesRequest.new
body.documentation = Documentation1.new
body.documentation.documents = ['docu-abc123', 'docu-efg456', 'docu-hij789']
body.documentation.explanation = 'lorem ipsum dolores umbridge'

result = client_controller.post_disputes_id(id, app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | DISPUTE_CANNOT_BE_FURTHER_MODIFIED, INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Disputes-Id-Concede

The POST /disputes/{id}/concede call allows your platform to concede a dispute on behalf of your merchant. Disputes represent a conflict between a payer and merchant.

```ruby
def post_disputes_id_concede(id,
                             app_id,
                             app_token,
                             api_version,
                             content_type,
                             unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `content_type` | `String` | Header, Required | **Constraints**: *Pattern*: `application/json` |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`Disputes`](#disputes)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
content_type = 'Content-Type2'

result = client_controller.post_disputes_id_concede(id, app_id, app_token, api_version, content_type, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | DISPUTE_CANNOT_BE_CONCEDED, INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Items

The POST /items call allows your platform to create a new item. Items describe an item or service for sale.  For standardized merchandise, an item could be a stock keeping unit (SKU).

```ruby
def post_items(app_id,
               app_token,
               api_version,
               body,
               unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`ItemReq`](#item-req) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`ItemResp`](#item-resp)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = ItemReq.new
body.account_id = 'd7608b20-fea5-4eb5-bd30-d3f58435e78b'
body.description = 'Classic Iron Anvil'
body.photos = []
body.price = 490
body.product_code = 'XYZ321'
body.product_details = JSON.parse('{"band":"nike"}')
body.product_name = 'Acme Anvil - 100 Lb'
body.rbits = []


body.rbits[0] = EmbeddedRbit.new
body.rbits[0].address = AddressRbit.new
body.rbits[0].address.origin_address = AddressRbits.new
body.rbits[0].address.origin_address.city = 'Sunnyvale'
body.rbits[0].address.origin_address.country = CountryCodeEnum::US
body.rbits[0].address.origin_address.line1 = '20 Main Street'
body.rbits[0].address.origin_address.postal_code = '94085'
body.rbits[0].address.origin_address.region = 'CA'
body.rbits[0].receive_time = 1367958263
body.rbits[0].source = RbitSourceEnum::PARTNER_DATABASE
body.rbits[0].type = RbitTypesEnum::ADDRESS

body.reference_number = 'abc_123456'
body.shipping_options = ['regular', 'expedited']
body.terms = Terms.new
body.terms.terms_text = 'lorem ipsum...'
body.terms.terms_uri = 'https://example.com/terms_of_service'
body.uri = 'https://example.com/abc_123456'
body.weight = Weight.new
body.weight.units = UnitsEnum::POUNDS
body.weight.weight = 135.76

result = client_controller.post_items(app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Items

The GET /items call allows your platform to look up a collection of items. Items describe an item or service for sale.  For standardized merchandise, an item could be a stock keeping unit (SKU).

```ruby
def get_items(app_id,
              app_token,
              api_version,
              unique_key: nil,
              page: nil,
              page_size: 10,
              create_time_start: nil,
              create_time_end: nil,
              reference_number: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 50` |
| `create_time_start` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the start of the search window, inclusive. |
| `create_time_end` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the end of the search window, inclusive. |
| `reference_number` | `String` | Query, Optional | Return elements with this reference number. |

##### Response Type

[`ItemsResponse`](#items-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_items(app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Items-Id

The GET /items/{id} call allows your platform to look up a single item. Items describe an item or service for sale.  For standardized merchandise, an item could be a stock keeping unit (SKU).

```ruby
def get_items_id(id,
                 app_id,
                 app_token,
                 api_version,
                 unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`ItemResp`](#item-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_items_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### DELETE Items-Id

The DELETE /items/{id} call allows your platform to delete an item. Items describe an item or service for sale.  For standardized merchandise, an item could be a stock keeping unit (SKU).

```ruby
def delete_items_id(id,
                    app_id,
                    app_token,
                    api_version,
                    unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`ItemResp`](#item-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.delete_items_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Items-Id

The POST /items/{id} call allows your platform to update and add custom data an item. Items describe an item or service for sale.  For standardized merchandise, an item could be a stock keeping unit (SKU).

```ruby
def post_items_id(id,
                  app_id,
                  app_token,
                  api_version,
                  body,
                  unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`ItemReq`](#item-req) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`ItemResp`](#item-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = ItemReq.new
body.account_id = 'ABC123'
body.description = 'Classic Iron Anvil'
body.photos = []
body.price = 490
body.product_code = 'XYZ321'
body.product_details = JSON.parse('{"band":"nike"}')
body.product_name = 'Acme Anvil - 100 Lb'
body.rbits = []


body.rbits[0] = EmbeddedRbit.new
body.rbits[0].address = AddressRbit.new
body.rbits[0].address.origin_address = AddressRbits.new
body.rbits[0].address.origin_address.city = 'Sunnyvale'
body.rbits[0].address.origin_address.country = CountryCodeEnum::US
body.rbits[0].address.origin_address.line1 = '20 Main Street'
body.rbits[0].address.origin_address.postal_code = '94085'
body.rbits[0].address.origin_address.region = 'CA'
body.rbits[0].receive_time = 1367958263
body.rbits[0].source = RbitSourceEnum::PARTNER_DATABASE
body.rbits[0].type = RbitTypesEnum::ADDRESS

body.reference_number = 'abc_123456'
body.shipping_options = ['regular', 'expedited']
body.terms = Terms.new
body.terms.terms_text = 'lorem ipsum...'
body.terms.terms_uri = 'https://example.com/terms_of_service'
body.uri = 'https://example.com/abc_123456'
body.weight = Weight.new
body.weight.units = UnitsEnum::POUNDS
body.weight.weight = 135.76

result = client_controller.post_items_id(id, app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Legal Entities

The POST /legal_entities call allows your platform to create a new legal entity. Onboarding a merchant requires the creation of a legal entity. A legal entity may be a business, individual, nonprofit, etc., and is completely owned by a single partner application. WePay collects information about the legal entity so we can properly underwrite them when provisioning a merchant account.

```ruby
def post_legal_entities(app_id,
                        app_token,
                        api_version,
                        body,
                        unique_key: nil,
                        we_pay_risk_token: nil,
                        client_ip: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`LegalEntity`](#legal-entity) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `we_pay_risk_token` | `String` | Header, Optional | - |
| `client_ip` | `String` | Header, Optional | - |

##### Response Type

[`LegalEntityResp`](#legal-entity-resp)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = LegalEntity.new
body.address = AddressLegalEntitiesNullable.new
body.address.city = 'San Francisco'
body.address.country = CountryCodeEnum::US
body.address.line1 = '123 Fake Street'
body.address.postal_code = '94101'
body.address.region = 'CA'
body.controller = ControllerReq.new
body.controller.address = AddressLegalEntitiesNullable.new
body.controller.address.city = 'Beverly Hills'
body.controller.address.country = CountryCodeEnum::US
body.controller.address.line1 = '456 Nocturn Alley'
body.controller.address.postal_code = '90210'
body.controller.address.region = 'CA'
body.controller.date_of_birth = DateOfBirth.new
body.controller.date_of_birth.day = 1
body.controller.date_of_birth.month = 1
body.controller.date_of_birth.year = 1900
body.controller.email = 'example@example.com'
body.controller.name = HumanNameFullNullable.new
body.controller.name.first = 'Foo'
body.controller.name.last = 'Bar'
body.controller.personal_country_info = PersonalCountryInfo.new
body.controller.personal_country_info.us = US.new
body.controller.personal_country_info.us.social_security_number = '012-34-5678'
body.controller.phone = PhoneLegalEntitiesNullable.new
body.controller.phone.country_code = '+1'
body.controller.phone.phone_number = '5556667777'
body.controller.job_title = 'CFO'
body.country = CountryCodeEnum::US
body.description = 'The Foo Bar Charity is very important.'
body.entity_country_info = EntityCountryInfo.new
body.entity_country_info.us = US4.new
body.entity_country_info.us.employer_identification_number = '123211230'
body.entity_name = 'Foo Bar Charity'
body.primary_url = 'http://www.example.com'
body.terms_of_service = TermsOfService.new
body.terms_of_service.acceptance_time = 1490656130
body.terms_of_service.original_ip = '12.37.161.213'

result = client_controller.post_legal_entities(app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS, UNSUPPORTED_COUNTRY | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Legal Entities

The GET /legal_entities call allows your platform to look up a collection of legal entities. Onboarding a merchant requires the creation of a legal entity. A legal entity may be a business, individual, nonprofit, etc., and is completely owned by a single partner application. WePay collects information about the legal entity so we can properly underwrite them when provisioning a merchant account.

```ruby
def get_legal_entities(app_id,
                       app_token,
                       api_version,
                       unique_key: nil,
                       page: nil,
                       page_size: 10,
                       create_time_start: nil,
                       create_time_end: nil,
                       reference_id: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 50` |
| `create_time_start` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the start of the search window, inclusive. |
| `create_time_end` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the end of the search window, inclusive. |
| `reference_id` | `String` | Query, Optional | Return elements having this reference_id. |

##### Response Type

[`LegalEntitiesResponse`](#legal-entities-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_legal_entities(app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Legal Entities-Id

The POST /legal_entities/{id} call allows your platform to update and add custom data to a legal entity. Onboarding a merchant requires the creation of a legal entity. A legal entity may be a business, individual, nonprofit, etc., and is completely owned by a single partner application. WePay collects information about the legal entity so we can properly underwrite them when provisioning a merchant account.

```ruby
def post_legal_entities_id(id,
                           app_id,
                           app_token,
                           api_version,
                           body,
                           we_pay_risk_token: nil,
                           unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`LegalEntitiesRequest`](#legal-entities-request) | Body, Required | - |
| `we_pay_risk_token` | `String` | Header, Optional | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`LegalEntityResp`](#legal-entity-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = LegalEntitiesRequest.new
body.address = AddressLegalEntitiesNullable.new
body.address.city = 'San Francisco'
body.address.country = CountryCodeEnum::US
body.address.line1 = '123 Fake Street'
body.address.postal_code = '94101'
body.address.region = 'CA'
body.controller = ControllerReq.new
body.controller.address = AddressLegalEntitiesNullable.new
body.controller.address.city = 'Beverly Hills'
body.controller.address.country = CountryCodeEnum::US
body.controller.address.line1 = '456 Nocturn Alley'
body.controller.address.postal_code = '90210'
body.controller.address.region = 'CA'
body.controller.date_of_birth = DateOfBirth.new
body.controller.date_of_birth.day = 1
body.controller.date_of_birth.month = 1
body.controller.date_of_birth.year = 1900
body.controller.email = 'example@example.com'
body.controller.name = HumanNameFullNullable.new
body.controller.name.first = 'Foo'
body.controller.name.last = 'Bar'
body.controller.personal_country_info = PersonalCountryInfo.new
body.controller.personal_country_info.us = US.new
body.controller.personal_country_info.us.social_security_number = '012-34-5678'
body.controller.phone = PhoneLegalEntitiesNullable.new
body.controller.phone.country_code = '+1'
body.controller.phone.phone_number = '5556667777'
body.controller.job_title = 'CFO'
body.description = 'The Foo Bar Charity is very important.'
body.entity_country_info = EntityCountryInfo.new
body.entity_country_info.us = US4.new
body.entity_country_info.us.employer_identification_number = '123211230'
body.entity_name = 'Foo Bar Charity'
body.primary_url = 'http://www.example.com'

result = client_controller.post_legal_entities_id(id, app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS, UNSUPPORTED_COUNTRY | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 409 | RESOURCE_CONFLICT | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Legal Entities-Id

The GET /legal_entities/{id} call allows your platform to look up a single legal entity. Onboarding a merchant requires the creation of a legal entity. A legal entity may be a business, individual, nonprofit, etc., and is completely owned by a single partner application. WePay collects information about the legal entity so we can properly underwrite them when provisioning a merchant account.

```ruby
def get_legal_entities_id(id,
                          app_id,
                          app_token,
                          api_version,
                          unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`LegalEntityResp`](#legal-entity-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_legal_entities_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Legal Entities-Id-Verifications

The POST /legal_entities/{id}/verifications call allows your platform to add and update documents to help WePay verify the identity of a legal entity. Onboarding a merchant requires the creation of a legal entity. A legal entity may be a business, individual, nonprofit, etc., and is completely owned by a single partner application. WePay collects information about the legal entity so we can properly underwrite them when provisioning a merchant account.

```ruby
def post_legal_entities_id_verifications(id,
                                         app_id,
                                         app_token,
                                         api_version,
                                         body,
                                         unique_key: nil,
                                         is_expanded: true)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`LegalEntitiesVerificationsRequest`](#legal-entities-verifications-request) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `is_expanded` | `Boolean` | Query, Optional | Return a descriptive response enumerating any unfulfilled requirements.<br>**Default**: `true` |

##### Response Type

[`LegalEntitiesVerificationsResponse`](#legal-entities-verifications-response)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = LegalEntitiesVerificationsRequest.new
body.controller = Controller.new
body.controller.personal_verification = PersonalVerification.new
body.controller.personal_verification.documents = ['724ec0d3-2eb5-461e-b72d-a15c6b1a9970', '3838d4ba-f497-4b6f-8d22-19b90cec4f23', '242f9ec7-a309-412c-976d-cc84074a508a']

result = client_controller.post_legal_entities_id_verifications(id, app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS, JSON_PARSE_FAILURE | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 409 | RESOURCE_CONFLICT | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Legal Entities-Id-Verifications

The GET /legal_entities/{id}/verifications call allows your platform to retrieve the information WePay requires to verify the identity of a legal entity. Onboarding a merchant requires the creation of a legal entity. A legal entity may be a business, individual, nonprofit, etc., and is completely owned by a single partner application. WePay collects information about the legal entity so we can properly underwrite them when provisioning a merchant account.

```ruby
def get_legal_entities_id_verifications(id,
                                        app_id,
                                        app_token,
                                        api_version,
                                        unique_key: nil,
                                        is_expanded: true,
                                        is_synchronous: false)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `is_expanded` | `Boolean` | Query, Optional | Return a descriptive response enumerating any unfulfilled requirements.<br>**Default**: `true` |
| `is_synchronous` | `Boolean` | Query, Optional | Delay returning until the legal entity has been assessed for risk, up to X seconds.<br>**Default**: `false` |

##### Response Type

[`LegalEntitiesVerificationsResponse`](#legal-entities-verifications-response)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_legal_entities_id_verifications(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Notifications

The  GET /notifications call allows your platform to look up a collection of notifications. The notifications resource allows your platform to retrieve details on a specific notification or a collection of notifications. Your platform can utilize notifications to gain insight into WePay’s system, communicate with your users, monitor issues, etc.

```ruby
def get_notifications(app_id,
                      app_token,
                      api_version,
                      unique_key: nil,
                      page: nil,
                      page_size: 10,
                      object_type: nil,
                      object_id: nil,
                      event_time_start: nil,
                      event_time_end: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 50` |
| `object_type` | `String` | Query, Optional | Scope type of a notification |
| `object_id` | `String` | Query, Optional | Scope id of a notification |
| `event_time_start` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the start of the search window, inclusive. |
| `event_time_end` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the end of the search window, inclusive. |

##### Response Type

[`NotificationsResponse`](#notifications-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_notifications(app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Notifications-Id

The GET /notifications/{id} call allows your platform to look up a notification. The notifications resource allows your platform to retrieve details on a specific notification or a collection of notifications. Your platform can utilize notifications to gain insight into WePay’s system, communicate with your users, monitor issues, etc.

```ruby
def get_notifications_id(id,
                         app_id,
                         app_token,
                         api_version,
                         unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`NotificationsResponse1`](#notifications-response-1)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_notifications_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Notification Preferences

The GET /notification_preferences call allows your platform to look up a collection of notification preferences. Notification preferences allow your platform to subscribe to notifications based on an event topic.

```ruby
def get_notification_preferences(app_id,
                                 app_token,
                                 api_version,
                                 unique_key: nil,
                                 page: nil,
                                 page_size: 10,
                                 create_time_start: nil,
                                 create_time_end: nil,
                                 type: nil,
                                 status: nil,
                                 topic: nil,
                                 callback_uri: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 50` |
| `create_time_start` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the start of the search window, inclusive. |
| `create_time_end` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the end of the search window, inclusive. |
| `type` | [`Type27Enum`](#type-27) | Query, Optional | Type of notification preference |
| `status` | [`Status20Enum`](#status-20) | Query, Optional | Status of the notification preference |
| `topic` | [`TopicEnum`](#topic) | Query, Optional | Topic of the notification preference to search for. |
| `callback_uri` | `String` | Query, Optional | Callback URI of the notification preference to search for. |

##### Response Type

[`NotificationPreferencesResponse`](#notification-preferences-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_notification_preferences(app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Notification Preferences

The POST /notification_preferences call allows your platform to create a new notification preference. Notification preferences allow your platform to subscribe to notifications based on an event topic.

```ruby
def post_notification_preferences(app_id,
                                  app_token,
                                  api_version,
                                  body,
                                  unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`NotificationPreferencesRequest`](#notification-preferences-request) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`NotificationPreferencesResponse1`](#notification-preferences-response-1)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = NotificationPreferencesRequest.new
body.callback_uri = 'https://example.com/payments'
body.topic = Topic1Enum::ENUM_PAYMENTSCOMPLETED

result = client_controller.post_notification_preferences(app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Notification Preferences-Id

The GET /notification_preferences/{id} call allows your platform to look up a single notification preference. Notification preferences allow your platform to subscribe to notifications based on an event topic.

```ruby
def get_notification_preferences_id(id,
                                    app_id,
                                    app_token,
                                    api_version,
                                    unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`NotificationPreferencesResponse2`](#notification-preferences-response-2)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_notification_preferences_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Notification Preferences-Id

The POST /notification_preferences/{id} call allows your platform to update a notification preference. Notification preferences allow your platform to subscribe to notifications based on an event topic.

```ruby
def post_notification_preferences_id(id,
                                     app_id,
                                     app_token,
                                     api_version,
                                     body,
                                     unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`NotificationPreferencesRequest1`](#notification-preferences-request-1) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`NotificationPreferencesResponse1`](#notification-preferences-response-1)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = NotificationPreferencesRequest1.new
body.callback_uri = 'https://example.com'

result = client_controller.post_notification_preferences_id(id, app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### DELETE Notification Preferences-Id

The DELETE /notification_preferences/{id} call allows your platform to delete a notification preference. Notification preferences allow your platform to subscribe to notifications based on an event topic.

```ruby
def delete_notification_preferences_id(id,
                                       app_id,
                                       app_token,
                                       api_version,
                                       unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`NotificationPreferencesResponse1`](#notification-preferences-response-1)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.delete_notification_preferences_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS, RESOURCE_PREVIOUSLY_DELETED | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Orders

The POST /orders call allows your platform to create a new order. Orders identify both the merchant and payer, and describe items sold, shipment date, prices, delivery details, and payment terms.

```ruby
def post_orders(app_id,
                app_token,
                api_version,
                body,
                unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`OrderReq`](#order-req) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`OrderResp`](#order-resp)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = OrderReq.new
body.account_id = 'd7608b20-fea5-4eb5-bd30-d3f58435e78b'
body.alternate_tax_amount = 35
body.alternate_tax_id = '11'
body.buyer = Buyer.new
body.buyer.legal_entity_id = '1490656130'
body.buyer.type = Type12Enum::LEGAL_ENTITY_ID
body.customer_reference_number = 'cust# 1234'
body.delivery_type = DeliveryTypeEnum::POINT_OF_SALE
body.discount_amount = 0
body.duty_amount = 0
body.freight_amount = 0
body.grand_total_amount = 1000
body.line_items = []


body.line_items[0] = LineItem1.new
body.line_items[0].commodity_code = 'ABC123'
body.line_items[0].currency = CurrencyEnum::USD
body.line_items[0].description = 'Classic Iron Anvil'
body.line_items[0].discount_amount = 0
body.line_items[0].item = ItemNullableReq.new
body.line_items[0].item.account_id = 'd7608b20-fea5-4eb5-bd30-d3f58435e78b'
body.line_items[0].item.description = 'Classic Iron Anvil'
body.line_items[0].item.photos = []
body.line_items[0].item.price = 490
body.line_items[0].item.product_code = 'XYZ321'
body.line_items[0].item.product_details = JSON.parse('{"band":"nike"}')
body.line_items[0].item.product_name = 'Acme Anvil - 100 Lb'
body.line_items[0].item.reference_number = 'abc_123456'
body.line_items[0].item.shipping_options = ['regular', 'expedited']
body.line_items[0].item.terms = Terms.new
body.line_items[0].item.terms.terms_text = 'lorem ipsum...'
body.line_items[0].item.terms.terms_uri = 'https://example.com/terms_of_service'
body.line_items[0].item.uri = 'https://example.com/abc_123456'
body.line_items[0].item.weight = Weight.new
body.line_items[0].item.weight.units = UnitsEnum::POUNDS
body.line_items[0].item.weight.weight = 71.77
body.line_items[0].quantity = 1
body.line_items[0].tax_amount = 5
body.line_items[0].tax_rate = 1.99
body.line_items[0].tax_type_applied = 'VAT'
body.line_items[0].total_amount = 500
body.line_items[0].unit_of_measure = 'count'
body.line_items[0].unit_price = 490

body.line_items[1] = LineItem1.new
body.line_items[1].commodity_code = 'XYZ999'
body.line_items[1].currency = CurrencyEnum::USD
body.line_items[1].description = 'Classic Catapult'
body.line_items[1].discount_amount = 0
body.line_items[1].item = ItemNullableReq.new
body.line_items[1].item.account_id = 'd7608b20-fea5-4eb5-bd30-d3f58435e78b'
body.line_items[1].item.description = 'Classic Catapult'
body.line_items[1].item.photos = ['http://imgur.com/o4Qk0AF']
body.line_items[1].item.price = 490
body.line_items[1].item.product_code = 'AAAXYZ321'
body.line_items[1].item.product_name = 'Acme Catapult'
body.line_items[1].item.reference_number = 'abc_654321'
body.line_items[1].item.shipping_options = ['regular', 'expedited']
body.line_items[1].item.terms = Terms.new
body.line_items[1].item.terms.terms_text = 'lorem ipsum...'
body.line_items[1].item.terms.terms_uri = 'https://example.com/terms_of_service'
body.line_items[1].item.uri = 'https://example.com/abc_654321'
body.line_items[1].item.weight = Weight.new
body.line_items[1].item.weight.units = UnitsEnum::POUNDS
body.line_items[1].item.weight.weight = 71.78
body.line_items[1].quantity = 1
body.line_items[1].tax_amount = 5
body.line_items[1].tax_rate = 1.99
body.line_items[1].tax_type_applied = 'VAT'
body.line_items[1].total_amount = 500
body.line_items[1].unit_of_measure = 'count'
body.line_items[1].unit_price = 490

body.notes = 'urgent order'
body.rbits = []


body.rbits[0] = EmbeddedRbit.new
body.rbits[0].address = AddressRbit.new
body.rbits[0].address.origin_address = AddressRbits.new
body.rbits[0].address.origin_address.city = 'Sunnyvale'
body.rbits[0].address.origin_address.country = CountryCodeEnum::US
body.rbits[0].address.origin_address.line1 = '20 Main Street'
body.rbits[0].address.origin_address.postal_code = '94085'
body.rbits[0].address.origin_address.region = 'CA'
body.rbits[0].receive_time = 1367958263
body.rbits[0].source = RbitSourceEnum::PARTNER_DATABASE
body.rbits[0].type = RbitTypesEnum::ADDRESS

body.rbits[1] = EmbeddedRbit.new
body.rbits[1].auto_billing = AutoBilling.new
body.rbits[1].auto_billing.autobill_setup_time = 1209600
body.rbits[1].auto_billing.payment_frequency = 'monthly'
body.rbits[1].auto_billing.payment_number = 1
body.rbits[1].auto_billing.setup_by = SetupByEnum::PAYER
body.rbits[1].auto_billing.total_payments_scheduled = 5
body.rbits[1].receive_time = 1367958263
body.rbits[1].source = RbitSourceEnum::USER
body.rbits[1].type = RbitTypesEnum::AUTO_BILLING

body.reference_number = 'invoice #54321'
body.service_address = AddressPaymentsReq.new
body.service_address.city = 'San Francisco'
body.service_address.country = CountryCodeEnum::US
body.service_address.line1 = '123 Fake Street'
body.service_address.postal_code = '94101'
body.service_address.region = 'CA'
body.ship_from_address = AddressPaymentsReq.new
body.ship_from_address.city = 'San Francisco'
body.ship_from_address.country = CountryCodeEnum::US
body.ship_from_address.line1 = '123 Fake Street'
body.ship_from_address.postal_code = '94101'
body.ship_from_address.region = 'CA'
body.ship_to_address = AddressPaymentsReq.new
body.ship_to_address.city = 'San Francisco'
body.ship_to_address.country = CountryCodeEnum::US
body.ship_to_address.line1 = '123 Fake Street'
body.ship_to_address.postal_code = '94101'
body.ship_to_address.region = 'CA'
body.shipping_status = ShippingStatus1.new
body.shipping_status.carrier = 'UPS'
body.shipping_status.expected_delivery_time = 1490656130
body.shipping_status.shipping_time = 1390656130
body.shipping_status.tracking_number = '1Z34567890'
body.shipping_status.tracking_uri = 'https://example.com/ups/1Z34567890'
body.short_description = 'Donation to ABC campaign'
body.status = Status4Enum::PAID
body.tax_amount = 35
body.type = Type4Enum::GOODS
body.vat_amount = 5
body.vat_rate = 1.99

result = client_controller.post_orders(app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Orders

The GET /orders call allows your platform to look up a collection of orders. Orders identify both the merchant and payer, and describe items sold, shipment date, prices, delivery details, and payment terms.

```ruby
def get_orders(app_id,
               app_token,
               api_version,
               unique_key: nil,
               page: nil,
               page_size: 10,
               create_time_start: nil,
               create_time_end: nil,
               reference_number: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 50` |
| `create_time_start` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the start of the search window, inclusive. |
| `create_time_end` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the end of the search window, inclusive. |
| `reference_number` | `String` | Query, Optional | Return elements with this reference number. |

##### Response Type

[`OrdersResponse`](#orders-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_orders(app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Orders-Id

The GET /orders/{id} call allows your platform to look up a single order. Orders identify both the merchant and payer, and describe items sold, shipment date, prices, delivery details, and payment terms.

```ruby
def get_orders_id(id,
                  app_id,
                  app_token,
                  api_version,
                  unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`OrderResp`](#order-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_orders_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### DELETE Orders-Id

The DELETE /orders/{id} call allows your platform to delete an order. Orders identify both the merchant and payer, and describe items sold, shipment date, prices, delivery details, and payment terms.

```ruby
def delete_orders_id(id,
                     app_id,
                     app_token,
                     api_version,
                     unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`OrderResp`](#order-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.delete_orders_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Orders-Id

The POST /orders/{id} call allows your platform to update and add custom data an order. Orders identify both the merchant and payer, and describe items sold, shipment date, prices, delivery details, and payment terms.

```ruby
def post_orders_id(id,
                   app_id,
                   app_token,
                   api_version,
                   body,
                   unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`OrderReq`](#order-req) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`OrderResp`](#order-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = OrderReq.new
body.account_id = 'd7608b20-fea5-4eb5-bd30-d3f58435e78b'
body.alternate_tax_amount = 35
body.alternate_tax_id = '11'
body.buyer = Buyer.new
body.buyer.legal_entity_id = '1490656130'
body.buyer.type = Type12Enum::LEGAL_ENTITY_ID
body.customer_reference_number = 'cust# 1234'
body.delivery_type = DeliveryTypeEnum::POINT_OF_SALE
body.discount_amount = 0
body.duty_amount = 0
body.freight_amount = 0
body.grand_total_amount = 1000
body.line_items = []


body.line_items[0] = LineItem1.new
body.line_items[0].commodity_code = 'ABC123'
body.line_items[0].currency = CurrencyEnum::USD
body.line_items[0].description = 'Classic Iron Anvil'
body.line_items[0].discount_amount = 0
body.line_items[0].item = ItemNullableReq.new
body.line_items[0].item.account_id = 'd7608b20-fea5-4eb5-bd30-d3f58435e78b'
body.line_items[0].item.description = 'Classic Iron Anvil'
body.line_items[0].item.photos = []
body.line_items[0].item.price = 490
body.line_items[0].item.product_code = 'XYZ321'
body.line_items[0].item.product_details = JSON.parse('{"band":"nike"}')
body.line_items[0].item.product_name = 'Acme Anvil - 100 Lb'
body.line_items[0].item.reference_number = 'abc_123456'
body.line_items[0].item.shipping_options = ['regular', 'expedited']
body.line_items[0].item.terms = Terms.new
body.line_items[0].item.terms.terms_text = 'lorem ipsum...'
body.line_items[0].item.terms.terms_uri = 'https://example.com/terms_of_service'
body.line_items[0].item.uri = 'https://example.com/abc_123456'
body.line_items[0].item.weight = Weight.new
body.line_items[0].item.weight.units = UnitsEnum::POUNDS
body.line_items[0].item.weight.weight = 71.77
body.line_items[0].quantity = 1
body.line_items[0].tax_amount = 5
body.line_items[0].tax_rate = 1.99
body.line_items[0].tax_type_applied = 'VAT'
body.line_items[0].total_amount = 500
body.line_items[0].unit_of_measure = 'count'
body.line_items[0].unit_price = 490

body.line_items[1] = LineItem1.new
body.line_items[1].commodity_code = 'XYZ999'
body.line_items[1].currency = CurrencyEnum::USD
body.line_items[1].description = 'Classic Catapult'
body.line_items[1].discount_amount = 0
body.line_items[1].item = ItemNullableReq.new
body.line_items[1].item.account_id = 'd7608b20-fea5-4eb5-bd30-d3f58435e78b'
body.line_items[1].item.description = 'Classic Catapult'
body.line_items[1].item.photos = ['http://imgur.com/o4Qk0AF']
body.line_items[1].item.price = 490
body.line_items[1].item.product_code = 'AAAXYZ321'
body.line_items[1].item.product_name = 'Acme Catapult'
body.line_items[1].item.reference_number = 'abc_654321'
body.line_items[1].item.shipping_options = ['regular', 'expedited']
body.line_items[1].item.terms = Terms.new
body.line_items[1].item.terms.terms_text = 'lorem ipsum...'
body.line_items[1].item.terms.terms_uri = 'https://example.com/terms_of_service'
body.line_items[1].item.uri = 'https://example.com/abc_654321'
body.line_items[1].item.weight = Weight.new
body.line_items[1].item.weight.units = UnitsEnum::POUNDS
body.line_items[1].item.weight.weight = 71.78
body.line_items[1].quantity = 1
body.line_items[1].tax_amount = 5
body.line_items[1].tax_rate = 1.99
body.line_items[1].tax_type_applied = 'VAT'
body.line_items[1].total_amount = 500
body.line_items[1].unit_of_measure = 'count'
body.line_items[1].unit_price = 490

body.notes = 'urgent order'
body.rbits = []


body.rbits[0] = EmbeddedRbit.new
body.rbits[0].address = AddressRbit.new
body.rbits[0].address.origin_address = AddressRbits.new
body.rbits[0].address.origin_address.city = 'Sunnyvale'
body.rbits[0].address.origin_address.country = CountryCodeEnum::US
body.rbits[0].address.origin_address.line1 = '20 Main Street'
body.rbits[0].address.origin_address.postal_code = '94085'
body.rbits[0].address.origin_address.region = 'CA'
body.rbits[0].receive_time = 1367958263
body.rbits[0].source = RbitSourceEnum::PARTNER_DATABASE
body.rbits[0].type = RbitTypesEnum::ADDRESS

body.rbits[1] = EmbeddedRbit.new
body.rbits[1].auto_billing = AutoBilling.new
body.rbits[1].auto_billing.autobill_setup_time = 1209600
body.rbits[1].auto_billing.payment_frequency = 'monthly'
body.rbits[1].auto_billing.payment_number = 1
body.rbits[1].auto_billing.setup_by = SetupByEnum::PAYER
body.rbits[1].auto_billing.total_payments_scheduled = 5
body.rbits[1].receive_time = 1367958263
body.rbits[1].source = RbitSourceEnum::USER
body.rbits[1].type = RbitTypesEnum::AUTO_BILLING

body.reference_number = 'invoice #54321'
body.service_address = AddressPaymentsReq.new
body.service_address.city = 'San Francisco'
body.service_address.country = CountryCodeEnum::US
body.service_address.line1 = '123 Fake Street'
body.service_address.postal_code = '94101'
body.service_address.region = 'CA'
body.ship_from_address = AddressPaymentsReq.new
body.ship_from_address.city = 'San Francisco'
body.ship_from_address.country = CountryCodeEnum::US
body.ship_from_address.line1 = '123 Fake Street'
body.ship_from_address.postal_code = '94101'
body.ship_from_address.region = 'CA'
body.ship_to_address = AddressPaymentsReq.new
body.ship_to_address.city = 'San Francisco'
body.ship_to_address.country = CountryCodeEnum::US
body.ship_to_address.line1 = '123 Fake Street'
body.ship_to_address.postal_code = '94101'
body.ship_to_address.region = 'CA'
body.shipping_status = ShippingStatus1.new
body.shipping_status.carrier = 'UPS'
body.shipping_status.expected_delivery_time = 1490656130
body.shipping_status.shipping_time = 1390656130
body.shipping_status.tracking_number = '1Z34567890'
body.shipping_status.tracking_uri = 'https://example.com/ups/1Z34567890'
body.short_description = 'Donation to ABC campaign'
body.status = Status4Enum::PAID
body.tax_amount = 35
body.type = Type4Enum::GOODS
body.vat_amount = 5
body.vat_rate = 1.99

result = client_controller.post_orders_id(id, app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Payments

The POST /payments call allows your platform to create a new payment.  undefined

```ruby
def post_payments(app_id,
                  app_token,
                  api_version,
                  unique_key,
                  body,
                  we_pay_risk_token: nil,
                  client_ip: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Required | - |
| `body` | [`PaymentsRequest`](#payments-request) | Body, Required | - |
| `we_pay_risk_token` | `String` | Header, Optional | - |
| `client_ip` | `String` | Header, Optional | - |

##### Response Type

[`PaymentsV30`](#payments-v-3-0)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
unique_key = 'Unique-Key0'
body = PaymentsRequest.new
body.account_id = 'abc123'
body.amount = 1000
body.auto_capture = true
body.currency = CurrencyEnum::USD
body.custom_data = JSON.parse('{"my_key":"invoice #54321"}')
body.fee_amount = 30
body.order_id = 'ordr-3cd20b3c-4008-400b-b708-2b844ce7be84'
body.payment_method = PaymentMethodForPayments.new
body.payment_method.credit_card = CreditCard2.new
body.payment_method.credit_card.auto_update = false
body.payment_method.credit_card.card_holder = HolderReq.new
body.payment_method.credit_card.card_holder.address = AddressPaymentsReq.new
body.payment_method.credit_card.card_holder.address.city = 'Redwood City'
body.payment_method.credit_card.card_holder.address.country = CountryCodeEnum::US
body.payment_method.credit_card.card_holder.address.line1 = '350 Convention Way'
body.payment_method.credit_card.card_holder.address.postal_code = '94025'
body.payment_method.credit_card.card_holder.address.region = 'CA'
body.payment_method.credit_card.card_holder.email = 'example@wepay.com'
body.payment_method.credit_card.card_holder.holder_name = 'John Snow'
body.payment_method.credit_card.card_number = '5496198584584769'
body.payment_method.credit_card.cvv = '007'
body.payment_method.credit_card.expiration_month = 4
body.payment_method.credit_card.expiration_year = 2030
body.payment_method.credit_card.virtual_terminal_mode = VirtualTerminalModeEnum::WEB
body.payment_method.credit_card.card_on_file = true
body.payment_method.credit_card.recurring = false
body.payment_method.custom_data = JSON.parse('{"my_key":"invoice #54321"}')
body.payment_method.type = Type9Enum::CREDIT_CARD
body.initiated_by = InitiatedByReqEnum::CUSTOMER
body.reference_id = 'dfeb052b-ae8c-4a69-b909-8d9ecdd7c742'

result = client_controller.post_payments(app_id, app_token, api_version, unique_key, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS, MERCHANT_ACCOUNT_CANNOT_ACCEPT_PAYMENTS, TRANSACTION_DECLINED, UNSUPPORTED_CURRENCY | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Payments

The GET /payments call allows your platform to look up a collection of payments. undefined

```ruby
def get_payments(app_id,
                 app_token,
                 api_version,
                 unique_key: nil,
                 page: nil,
                 page_size: 10,
                 create_time_start: nil,
                 create_time_end: nil,
                 owner_id: nil,
                 payment_method_type: nil,
                 payment_method_id: nil,
                 status: nil,
                 reference_id: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 50` |
| `create_time_start` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the start of the search window, inclusive. |
| `create_time_end` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the end of the search window, inclusive. |
| `owner_id` | `String` | Query, Optional | - |
| `payment_method_type` | [`PaymentMethodTypeEnum`](#payment-method-type) | Query, Optional | The last 4 digits of the card to search for. |
| `payment_method_id` | `String` | Query, Optional | - |
| `status` | [`Status3Enum`](#status-3) | Query, Optional | - |
| `reference_id` | `String` | Query, Optional | The reference_id to search for. |

##### Response Type

[`PaymentsResponse`](#payments-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_payments(app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Payments-Id

The GET /payments/{id} call allows your platform to look up a single payment. undefined

```ruby
def get_payments_id(id,
                    app_id,
                    app_token,
                    api_version,
                    unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`PaymentsV30`](#payments-v-3-0)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_payments_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Payments-Id

The POST /payments/{id} call allows your platform to update and add custom data to a payment. undefined

```ruby
def post_payments_id(id,
                     app_id,
                     app_token,
                     api_version,
                     body,
                     unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`PaymentsRequest1`](#payments-request-1) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`PaymentsV30`](#payments-v-3-0)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = PaymentsRequest1.new
body.custom_data = JSON.parse('{"Another Key":"some value","a_reference_number":4}')
body.reference_id = 'dfeb052b-ae8c-4a69-b909-8d9ecdd7c742'

result = client_controller.post_payments_id(id, app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Payments-Id-Cancel

The POST /payments/{id}/cancel call allows your platform to cancel a payment. undefined

```ruby
def post_payments_id_cancel(id,
                            app_id,
                            app_token,
                            api_version,
                            body,
                            unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`PaymentsCancelRequest`](#payments-cancel-request) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`PaymentsV30`](#payments-v-3-0)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = PaymentsCancelRequest.new
body.cancel_reason = 'item(s) delayed - cannot fulfill order'

result = client_controller.post_payments_id_cancel(id, app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS, PAYMENT_CANNOT_BE_CANCELED | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Payments-Id-Capture

The POST /payments/{id}/capture call allows your platform to capture a payment (when `auto_capture` is set to false). undefined

```ruby
def post_payments_id_capture(id,
                             app_id,
                             app_token,
                             api_version,
                             unique_key: nil,
                             body: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `body` | [`PaymentsCaptureRequest`](#payments-capture-request) | Body, Optional | - |

##### Response Type

[`PaymentsV30`](#payments-v-3-0)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = PaymentsCaptureRequest.new
body.amounts = CaptureAmounts.new
body.amounts.amount = 1500
body.amounts.currency = CurrencyEnum::USD
body.amounts.fee_amount = 150

result = client_controller.post_payments_id_capture(id, app_id, app_token, api_version, body: body)
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Payment Methods

The POST /payment_methods call allows your platform to create a payment method. Payment methods represent payment data like credit cards and bank accounts, and allow your platform to charge and accept money from a payer.

```ruby
def post_payment_methods(app_id,
                         app_token,
                         api_version,
                         body,
                         unique_key: nil,
                         we_pay_risk_token: nil,
                         client_ip: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`PaymentMethodReq`](#payment-method-req) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `we_pay_risk_token` | `String` | Header, Optional | - |
| `client_ip` | `String` | Header, Optional | - |

##### Response Type

[`PaymentMethodResp`](#payment-method-resp)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = PaymentMethodReq.new
body.credit_card = CreditCard2.new
body.credit_card.auto_update = false
body.credit_card.card_holder = HolderReq.new
body.credit_card.card_holder.address = AddressPaymentsReq.new
body.credit_card.card_holder.address.country = CountryCodeEnum::US
body.credit_card.card_holder.address.postal_code = '94025'
body.credit_card.card_holder.email = 'example@wepay.com'
body.credit_card.card_holder.holder_name = 'John Snow'
body.credit_card.card_number = '5496198584584769'
body.credit_card.cvv = '007'
body.credit_card.expiration_month = 4
body.credit_card.expiration_year = 2020
body.credit_card.trigger_verification = true
body.credit_card.virtual_terminal_mode = VirtualTerminalModeEnum::MOBILE
body.credit_card.card_on_file = false
body.credit_card.recurring = false
body.custom_data = JSON.parse('{"my_key":"invoice #54321"}')
body.type = Type3Enum::CREDIT_CARD

result = client_controller.post_payment_methods(app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS, MERCHANT_ACCOUNT_CANNOT_ACCEPT_PAYMENTS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Payment Methods

The GET /payment_methods call allows your platform to look up a collection of payment methods. Payment methods represent payment data like credit cards and bank accounts, and allow your platform to charge and accept money from a payer.

```ruby
def get_payment_methods(app_id,
                        app_token,
                        api_version,
                        unique_key: nil,
                        page: nil,
                        page_size: 10,
                        create_time_start: nil,
                        create_time_end: nil,
                        card_brand: nil,
                        card_last_four: nil,
                        bank_routing_number: nil,
                        bank_last_four: nil,
                        type: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 50` |
| `create_time_start` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the start of the search window, inclusive. |
| `create_time_end` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the end of the search window, inclusive. |
| `card_brand` | [`CardBrand2Enum`](#card-brand-2) | Query, Optional | The brand of the card to search for. |
| `card_last_four` | `String` | Query, Optional | The last 4 digits of the card to search for. |
| `bank_routing_number` | `String` | Query, Optional | The routing number of the bank to search for. |
| `bank_last_four` | `String` | Query, Optional | The last 4 of the bank account number to search for. |
| `type` | [`Type3Enum`](#type-3) | Query, Optional | The type of payment method to search for. Required unless page is provided |

##### Response Type

[`PaymentMethodsResponse`](#payment-methods-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_payment_methods(app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Payment Methods-Id

The POST /payment_methods/{id} call allows your platform to update and add custom data to an existing payment method. Payment methods represent payment data like credit cards and bank accounts, and allow your platform to charge and accept money from a payer.

```ruby
def post_payment_methods_id(id,
                            app_id,
                            app_token,
                            api_version,
                            body,
                            unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`PaymentMethodsRequest`](#payment-methods-request) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`PaymentMethodResp`](#payment-method-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = PaymentMethodsRequest.new
body.type = Type3Enum::PAYMENT_BANK_US

result = client_controller.post_payment_methods_id(id, app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Payment Methods-Id

The GET /payment_methods/{id} call allows your platform to look up a specific payment method. Payment methods represent payment data like credit cards and bank accounts, and allow your platform to charge and accept money from a payer.

```ruby
def get_payment_methods_id(id,
                           app_id,
                           app_token,
                           api_version,
                           unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`PaymentMethodResp`](#payment-method-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_payment_methods_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### DELETE Payment Methods-Id

The DELETE /payment_methods/{id} call allows your platform to delete a single payment method. Payment methods represent payment data like credit cards and bank accounts, and allow your platform to charge and accept money from a payer.

```ruby
def delete_payment_methods_id(id,
                              app_id,
                              app_token,
                              api_version,
                              unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`PaymentMethodResp`](#payment-method-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.delete_payment_methods_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS, PAYMENT_METHOD_CANNOT_BE_DELETED | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Payment Methods-Id-Verify Bank Deposits

The POST /payment_methods/{id}/verify_bank_deposits call allows your platform to verify a payment method. Payment methods represent payment data like credit cards and bank accounts, and allow your platform to charge and accept money from a payer.

```ruby
def post_payment_methods_id_verify_bank_deposits(id,
                                                 app_id,
                                                 app_token,
                                                 api_version,
                                                 body,
                                                 unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`PaymentMethodsVerifyBankDepositsRequest`](#payment-methods-verify-bank-deposits-request) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`PaymentMethodResp`](#payment-method-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = PaymentMethodsVerifyBankDepositsRequest.new
body.microdeposits = [10, 55]

result = client_controller.post_payment_methods_id_verify_bank_deposits(id, app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS, PAYMENT_METHOD_CANNOT_BE_VERIFIED | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Payouts

The GET /payouts call allows your platform to look up a collection of payouts. Payouts allow your merchants to receive their funds from your platform.

```ruby
def get_payouts(app_id,
                app_token,
                api_version,
                unique_key: nil,
                page: nil,
                page_size: 10,
                create_time_start: nil,
                create_time_end: nil,
                owner_id: nil,
                payout_method_type: nil,
                payout_method_id: nil,
                status: nil,
                payment_id: nil,
                refund_id: nil,
                dispute_id: nil,
                recovery_id: nil,
                adjustment_id: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 50` |
| `create_time_start` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the start of the search window, inclusive. |
| `create_time_end` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the end of the search window, inclusive. |
| `owner_id` | `String` | Query, Optional | The ID of the owning entity for which to find payouts. |
| `payout_method_type` | [`PayoutMethodTypeEnum`](#payout-method-type) | Query, Optional | The payout method type to search for. |
| `payout_method_id` | `String` | Query, Optional | Search for a payout that uses this payout method ID. |
| `status` | [`StatusEnum`](#status) | Query, Optional | The status of the payout to search for. |
| `payment_id` | `String` | Query, Optional | Search for a payout that includes funds with this payment ID. |
| `refund_id` | `String` | Query, Optional | Search for a payout that includes funds with this refund ID. |
| `dispute_id` | `String` | Query, Optional | Search for a payout that includes funds with this dispute ID. |
| `recovery_id` | `String` | Query, Optional | Search for a payout that includes funds with this recovery ID. |
| `adjustment_id` | `String` | Query, Optional | Search for a payout that includes funds with this adjustment ID. |

##### Response Type

[`PayoutsResponse`](#payouts-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_payouts(app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Payouts-Id

The POST /payouts/{id} call allows your platform to update and add custom data to a payout. Payouts allow your merchants to receive their funds from your platform.

```ruby
def post_payouts_id(id,
                    app_id,
                    app_token,
                    api_version,
                    body,
                    unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`PayoutsRequest`](#payouts-request) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`Payout`](#payout)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = PayoutsRequest.new

result = client_controller.post_payouts_id(id, app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Payouts-Id

The GET /payouts/{id} call allows your platform to look up a single payout. Payouts allow your merchants to receive their funds from your platform.

```ruby
def get_payouts_id(id,
                   app_id,
                   app_token,
                   content_type,
                   unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `content_type` | `String` | Header, Required | **Constraints**: *Pattern*: `application/json` |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`Payout`](#payout)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
content_type = 'Content-Type2'

result = client_controller.get_payouts_id(id, app_id, app_token, content_type, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Payout Methods

The POST /payout_methods call allows your platform to create a new payout method owned by a legal entity. Payout methods represent payout targets, such as bank accounts.

```ruby
def post_payout_methods(app_id,
                        app_token,
                        api_version,
                        body,
                        unique_key: nil,
                        we_pay_risk_token: nil,
                        client_ip: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`PayoutMethodReq`](#payout-method-req) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `we_pay_risk_token` | `String` | Header, Optional | - |
| `client_ip` | `String` | Header, Optional | - |

##### Response Type

[`PayoutMethodResp`](#payout-method-resp)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = PayoutMethodReq.new
body.custom_data = JSON.parse('{"my_key":"invoice #54321"}')
body.legal_entity_id = '42d2c2f1-5aeb-4929-944f-e220b4c9425b'
body.nickname = 'bofa checking 6789'
body.payout_bank_us = PayoutBankUs1.new
body.payout_bank_us.account_number = '123456789'
body.payout_bank_us.account_type = AccountTypeEnum::CHECKING
body.payout_bank_us.routing_number = '987654321'
body.type = Type2Enum::PAYOUT_BANK_US

result = client_controller.post_payout_methods(app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS, MERCHANT_ACCOUNT_CANNOT_ACCEPT_PAYMENTS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Payout Methods

The GET /payout_methods call allows your platform to look up a collection of payout methods. Payout methods represent payout targets, such as bank accounts.

```ruby
def get_payout_methods(app_id,
                       app_token,
                       api_version,
                       unique_key: nil,
                       page: nil,
                       page_size: 10,
                       create_time_start: nil,
                       create_time_end: nil,
                       owner_id: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 50` |
| `create_time_start` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the start of the search window, inclusive. |
| `create_time_end` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the end of the search window, inclusive. |
| `owner_id` | `String` | Query, Optional | The ID of the owning entity for which to find payout methods. Required unless "page" provided. |

##### Response Type

[`PayoutMethodsResponse`](#payout-methods-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_payout_methods(app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Payout Methods-Id

The POST /payout_methods/{id}  call allows your platform to update and add custom data to a payout method. Payout methods represent payout targets, such as bank accounts.

```ruby
def post_payout_methods_id(id,
                           app_id,
                           app_token,
                           api_version,
                           body,
                           unique_key: nil,
                           we_pay_risk_token: nil,
                           client_ip: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`PayoutMethodsRequest`](#payout-methods-request) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `we_pay_risk_token` | `String` | Header, Optional | - |
| `client_ip` | `String` | Header, Optional | - |

##### Response Type

[`PayoutMethodResp`](#payout-method-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = PayoutMethodsRequest.new

result = client_controller.post_payout_methods_id(id, app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Payout Methods-Id

The GET /payout_methods/{id} call allows your platform to look up a single payout method. Payout methods represent payout targets, such as bank accounts.

```ruby
def get_payout_methods_id(id,
                          app_id,
                          app_token,
                          api_version,
                          unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`PayoutMethodResp`](#payout-method-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_payout_methods_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Rbits

The POST /rbits call allows your platform to create an rbit for a user, account, or transaction. The rbits resource provides a way to communicate risk-related account and transaction level information between an application and WePay. An rbit contains risk related information about your users, their accounts, and their transactions.

```ruby
def post_rbits(app_id,
               app_token,
               api_version,
               body,
               unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`RbitsRequest`](#rbits-request) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`RbitsResponse`](#rbits-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = RbitsRequest.new
body.address = AddressRbit.new
body.address.origin_address = AddressRbits.new
body.address.origin_address.city = 'Palo Alto'
body.address.origin_address.country = CountryCodeEnum::US
body.address.origin_address.line1 = '380 Portage Avenue'
body.address.origin_address.postal_code = '93036'
body.address.origin_address.region = 'CA'
body.associated_resource = AssociatedResource.new
body.associated_resource.id = 'f48cd8e6-e802-4500-a0f9-3ab6228c6f23'
body.associated_resource.resource = ResourceTypesRbitEnum::ACCOUNTS
body.receive_time = 1367958263
body.source = RbitSourceEnum::GUIDESTAR
body.type = RbitTypesEnum::ADDRESS

result = client_controller.post_rbits(app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Rbits

The GET /rbits call allows your platform to look up a collection of rbits. The rbits resource provides a way to communicate risk-related account and transaction level information between an application and WePay. An rbit contains risk related information about your users, their accounts, and their transactions.

```ruby
def get_rbits(app_id,
              app_token,
              api_version,
              unique_key: nil,
              page: nil,
              page_size: 10,
              create_time_start: nil,
              create_time_end: nil,
              owner_id: nil,
              owner_type: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 50` |
| `create_time_start` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the start of the search window, inclusive. |
| `create_time_end` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the end of the search window, inclusive. |
| `owner_id` | `String` | Query, Optional | The ID of the owner for which to find rbits. |
| `owner_type` | `String` | Query, Optional | The resource type of the owner for which to find rbits. |

##### Response Type

[`RbitsResponse1`](#rbits-response-1)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_rbits(app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Rbits-Id

The GET /rbits/{id} call allows your platform to look up a single rbit. The rbits resource provides a way to communicate risk-related account and transaction level information between an application and WePay. An rbit contains risk related information about your users, their accounts, and their transactions.

```ruby
def get_rbits_id(id,
                 app_id,
                 app_token,
                 api_version,
                 unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`RbitsResponse`](#rbits-response)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_rbits_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### DELETE Rbits-Id

The DELETE /rbits call allows you to delete an rbit. The rbits resource provides a way to communicate risk-related account and transaction level information between an application and WePay. An rbit contains risk related information about your users, their accounts, and their transactions.

```ruby
def delete_rbits_id(id,
                    app_id,
                    app_token,
                    api_version,
                    unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`RbitsResponse`](#rbits-response)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.delete_rbits_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Recoveries

The GET /recoveries call allows your platform to look up a collection of recoveries. The recovery resource notifies your platform that WePay made a recovery attempt to a merchant’s bank account in order to bring their balance up to $0.

```ruby
def get_recoveries(app_id,
                   app_token,
                   api_version,
                   unique_key: nil,
                   page: nil,
                   page_size: 10,
                   create_time_start: nil,
                   create_time_end: nil,
                   owner_id: nil,
                   payout_method_type: nil,
                   payout_method_id: nil,
                   status: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 50` |
| `create_time_start` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the start of the search window, inclusive. |
| `create_time_end` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the end of the search window, inclusive. |
| `owner_id` | `String` | Query, Optional | The ID of the owning entity for which to find recoveries. |
| `payout_method_type` | [`PayoutMethodTypeEnum`](#payout-method-type) | Query, Optional | The payout method type to filter by. |
| `payout_method_id` | `String` | Query, Optional | The payout method id to filter by. |
| `status` | [`StatusEnum`](#status) | Query, Optional | The status of recoveries to return. |

##### Response Type

[`RecoveriesResponse`](#recoveries-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_recoveries(app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Recoveries-Id

The GET /recoveries/{id} call allows your platform to look up information on a single recovery. The recovery resource notifies your platform that WePay made a recovery attempt to a merchant’s bank account in order to bring their balance up to $0.

```ruby
def get_recoveries_id(id,
                      app_id,
                      app_token,
                      api_version,
                      unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`Recoveries`](#recoveries)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_recoveries_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Recoveries-Id

The POST /recoveries/{id} call allows your platform to update and add custom data to a recovery. The recovery resource notifies your platform that WePay made a recovery attempt to a merchant’s bank account in order to bring their balance up to $0.

```ruby
def post_recoveries_id(id,
                       app_id,
                       app_token,
                       api_version,
                       body,
                       unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`RecoveriesRequest`](#recoveries-request) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`Recoveries`](#recoveries)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = RecoveriesRequest.new
body.custom_data = JSON.parse('{"receipt_number":1258372}')

result = client_controller.post_recoveries_id(id, app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Refunds

The GET /refunds call allows your platform to look up a collection of refunds. Refunds facilitate the return of money from the merchant to the payer.

```ruby
def get_refunds(app_id,
                app_token,
                api_version,
                unique_key: nil,
                page: nil,
                page_size: 10,
                create_time_start: nil,
                create_time_end: nil,
                owner_id: nil,
                payment_method_type: nil,
                payment_method_id: nil,
                status: nil,
                payment_id: nil,
                reference_id: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 50` |
| `create_time_start` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the start of the search window, inclusive. |
| `create_time_end` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the end of the search window, inclusive. |
| `owner_id` | `String` | Query, Optional | The ID of the owning entity for which to find refunds. |
| `payment_method_type` | [`PaymentMethodTypeEnum`](#payment-method-type) | Query, Optional | The payment method type to filter by. |
| `payment_method_id` | `String` | Query, Optional | The payment method id to filter by. |
| `status` | [`StatusEnum`](#status) | Query, Optional | The status of refunds to return. |
| `payment_id` | `String` | Query, Optional | The payment id to filter by. |
| `reference_id` | `String` | Query, Optional | The reference_id to search for. |

##### Response Type

[`RefundsResponse`](#refunds-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_refunds(app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Refunds

The POST /refunds call allows your platform to create a new refund. Refunds facilitate the return of money from the merchant to the payer.

```ruby
def post_refunds(app_id,
                 app_token,
                 api_version,
                 unique_key,
                 body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Required | - |
| `body` | [`RefundReq`](#refund-req) | Body, Required | - |

##### Response Type

[`RefundResp`](#refund-resp)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
unique_key = 'Unique-Key0'
body = RefundReq.new
body.amounts = RefundAmounts.new
body.amounts.total_amount = 300
body.amounts.currency = CurrencyEnum::USD
body.amounts.fee_refund_amount = 50
body.order_id = 'ordr-123-abc'
body.payment_id = '18752aba-25d0-4328-aac9-a0ba7216eb67'
body.refund_reason = 'Item(s) returned'
body.reference_id = 'reference_id_0'

result = client_controller.post_refunds(app_id, app_token, api_version, unique_key, body)
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS, PAYMENT_CANNOT_BE_REFUNDED | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Refunds-Id

The GET /refunds/{id} call allows your platform to look up a single refund. Refunds facilitate the return of money from the merchant to the payer.

```ruby
def get_refunds_id(id,
                   app_id,
                   app_token,
                   api_version,
                   unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`RefundResp`](#refund-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_refunds_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Refunds-Id

The POST /refunds/{id} call allows your platform to update and add custom data to a refund. Refunds facilitate the return of money from the merchant to the payer.

```ruby
def post_refunds_id(id,
                    app_id,
                    app_token,
                    api_version,
                    body,
                    unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`RefundsRequest`](#refunds-request) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`RefundResp`](#refund-resp)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = RefundsRequest.new
body.custom_data = JSON.parse('{"order_id":34211134828443}')
body.reference_id = 'reference_id_0'

result = client_controller.post_refunds_id(id, app_id, app_token, api_version, body, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Terminals

Onboard a Point-of-Sale terminal into the WePay system. A terminals resource represents a mechanism by which you can control the configuration and lifecycle of your terminals. You can only have one non-deleted instance of a terminals resource per physical terminal, which is uniquely identified by the model and serial number.

```ruby
def post_terminals(app_id,
                   app_token,
                   api_version,
                   body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`TerminalsRequest`](#terminals-request) | Body, Required | - |

##### Response Type

[`TerminalResp`](#terminal-resp)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = TerminalsRequest.new
body.account_id = '0ef0dcd6-a2c6-49c4-9051-bbbe5c6c36e2'
body.serial_number = 'FA00332-1000138'
body.model = Model1Enum::VERIFONE_P400
body.reference_id = 'abc12345'
body.terminal_configuration = TerminalConfiguration1.new
body.terminal_configuration.address = AddressTerminalsReq.new
body.terminal_configuration.address.city = 'Redwood City'
body.terminal_configuration.address.country = CountryCodeEnum::US
body.terminal_configuration.address.line1 = '250 Convention Way'
body.terminal_configuration.address.line2 = 'Suite 200'
body.terminal_configuration.address.postal_code = '94063'
body.terminal_configuration.address.region = 'CA'
body.terminal_configuration.currency = CurrencyEnum::USD
body.terminal_configuration.supported_card_brands = [TerminalsSupportedCardBrandEnum::VISA, TerminalsSupportedCardBrandEnum::AMERICAN_EXPRESS, TerminalsSupportedCardBrandEnum::DISCOVER, TerminalsSupportedCardBrandEnum::MASTERCARD]
body.terminal_configuration.timezone = TimezoneEnum::ENUM_USPACIFIC
body.terminal_configuration.tip = TerminalsTip.new
body.terminal_configuration.tip.mode = ModeEnum::PROMPT_ON_TERMINAL
body.terminal_configuration.tip.terminal_display = TerminalDisplay.new
body.terminal_configuration.tip.terminal_display.amount_guide_type = AmountGuideTypeEnum::PERCENTAGE_GUIDE
body.terminal_configuration.tip.terminal_display.percentage_guide = PercentageGuide.new
body.terminal_configuration.tip.terminal_display.percentage_guide.show_amount = false
body.terminal_configuration.tip.terminal_display.percentage_guide.percentage_low = 15
body.terminal_configuration.tip.terminal_display.percentage_guide.percentage_medium = 18
body.terminal_configuration.tip.terminal_display.percentage_guide.percentage_high = 20
body.terminal_configuration.signature_required = true
body.terminal_configuration.contactless_payments = ContactlessPaymentsReq.new
body.terminal_configuration.contactless_payments.enabled = true
body.terminal_configuration.contactless_payments.credit_debit_preference = CreditDebitPreferenceEnum::CREDIT
body.terminal_configuration.quick_chip = QuickChip.new
body.terminal_configuration.quick_chip.enabled = true
body.terminal_configuration.deferred_authorization = DeferredAuthorization.new
body.terminal_configuration.deferred_authorization.enabled = true
body.terminal_configuration.deferred_authorization.international_enabled = true
body.terminal_configuration.deferred_authorization.max_transaction_count = 20
body.terminal_configuration.deferred_authorization.max_total_amount = 250000
body.terminal_configuration.deferred_authorization.max_transaction_amount = 12500
body.terminal_configuration.deferred_authorization.supported_card_entry_modes = [SupportedCardEntryModeEnum::CHIP, SupportedCardEntryModeEnum::CONTACTLESS]

result = client_controller.post_terminals(app_id, app_token, api_version, body)
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS, ACCOUNT_CANNOT_CREATE_TERMINALS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Terminals

Look up a collection of terminals, filtered by the optional specified parameters.

```ruby
def get_terminals(app_id,
                  app_token,
                  api_version,
                  page: nil,
                  page_size: 10,
                  create_time_start: nil,
                  create_time_end: nil,
                  account_id: nil,
                  reference_id: nil,
                  model: nil,
                  serial_number: nil,
                  status: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 50` |
| `create_time_start` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the start of the search window, inclusive. |
| `create_time_end` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the end of the search window, inclusive. |
| `account_id` | `String` | Query, Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `reference_id` | `String` | Query, Optional | Filter search window by elements that match the reference ID.<br>**Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `model` | [`Model1Enum`](#model-1) | Query, Optional | Filter search window by elements that match the model. |
| `serial_number` | `String` | Query, Optional | Filter search window by elements that match the serial_number. |
| `status` | [`TerminalsStatusEnum`](#terminals-status) | Query, Optional | Filter search window by elements that match the status. |

##### Response Type

[`TerminalsResponse`](#terminals-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
serial_number = 'FA00332-1000138'

result = client_controller.get_terminals(app_id, app_token, api_version, serial_number: serial_number, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Terminals-Id

Modify a terminal's configuration. Note that changes in configuration will only be reflected on your physical terminal when it has performed an online update. You cannot modify the configuration of an inactive or deleted terminal.

```ruby
def post_terminals_id(app_id,
                      app_token,
                      api_version,
                      body,
                      id)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`TerminalsRequest1`](#terminals-request-1) | Body, Required | - |
| `id` | `String` | Template, Required | - |

##### Response Type

[`TerminalResp`](#terminal-resp)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
body = TerminalsRequest1.new
body.reference_id = 'abc12345'
body.terminal_configuration = TerminalConfiguration2.new
body.terminal_configuration.contactless_payments = ContactlessPaymentsReq.new
body.terminal_configuration.contactless_payments.enabled = true
body.terminal_configuration.contactless_payments.credit_debit_preference = CreditDebitPreferenceEnum::CREDIT
id = 'id0'

result = client_controller.post_terminals_id(app_id, app_token, api_version, body, id)
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Terminals-Id

Look up a terminal to see its current status and configuration.

```ruby
def get_terminals_id(app_id,
                     app_token,
                     api_version,
                     id)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `id` | `String` | Template, Required | - |

##### Response Type

[`TerminalResp`](#terminal-resp)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
id = 'id0'

result = client_controller.get_terminals_id(app_id, app_token, api_version, id)
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### DELETE Terminals-Id

Delete's the terminal from the system, marking it as deleted. The physical terminal represented by this API record will not be able to process payments until it is onboarded again.

```ruby
def delete_terminals_id(app_id,
                        app_token,
                        api_version,
                        id)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `id` | `String` | Template, Required | - |

##### Response Type

[`TerminalResp`](#terminal-resp)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
id = 'id0'

result = client_controller.delete_terminals_id(app_id, app_token, api_version, id)
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Terminals-Id-Activate

Activating a terminal will allow it to process payments after being deactivated. You can only activate a deactivated terminal.

```ruby
def post_terminals_id_activate(app_id,
                               app_token,
                               api_version,
                               content_type,
                               id,
                               unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `content_type` | `String` | Header, Required | **Constraints**: *Pattern*: `application/json` |
| `id` | `String` | Template, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`TerminalResp`](#terminal-resp)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
content_type = 'Content-Type2'
id = 'id0'

result = client_controller.post_terminals_id_activate(app_id, app_token, api_version, content_type, id, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Terminals-Id-Deactivate

Dectivating a terminal will prevent it from processin payments after being deactivated. You can only deactivate an active terminal.

```ruby
def post_terminals_id_deactivate(app_id,
                                 app_token,
                                 api_version,
                                 content_type,
                                 id,
                                 unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `content_type` | `String` | Header, Required | **Constraints**: *Pattern*: `application/json` |
| `id` | `String` | Template, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`TerminalResp`](#terminal-resp)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'
content_type = 'Content-Type2'
id = 'id0'

result = client_controller.post_terminals_id_deactivate(app_id, app_token, api_version, content_type, id, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### POST Tokens

Create a new token

:information_source: **Note** This endpoint does not require authentication.

```ruby
def post_tokens(app_id,
                api_version,
                body,
                unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `body` | [`TokensRequest`](#tokens-request) | Body, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`TokensResponse`](#tokens-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
api_version = 'Api-Version8'
body = TokensRequest.new
body.payment_methods = PaymentMethodReq.new
body.payment_methods.credit_card = CreditCard2.new
body.payment_methods.credit_card.auto_update = false
body.payment_methods.credit_card.card_holder = HolderReq.new
body.payment_methods.credit_card.card_holder.address = AddressPaymentsReq.new
body.payment_methods.credit_card.card_holder.address.country = CountryCodeEnum::US
body.payment_methods.credit_card.card_holder.address.postal_code = '94025'
body.payment_methods.credit_card.card_holder.email = 'example@wepay.com'
body.payment_methods.credit_card.card_holder.holder_name = 'John Snow'
body.payment_methods.credit_card.card_number = '5496198584584769'
body.payment_methods.credit_card.cvv = '007'
body.payment_methods.credit_card.expiration_month = 4
body.payment_methods.credit_card.expiration_year = 2020
body.payment_methods.credit_card.trigger_verification = false
body.payment_methods.credit_card.virtual_terminal_mode = VirtualTerminalModeEnum::WEB
body.payment_methods.credit_card.card_on_file = false
body.payment_methods.credit_card.recurring = false
body.payment_methods.type = Type3Enum::CREDIT_CARD
body.resource = Resource2Enum::PAYMENT_METHODS

result = client_controller.post_tokens(app_id, api_version, body, )
```

#### GET Transaction Records

The GET /transaction_records call allows your platform to look up a collection of transaction records. Transactions records represent one entry (e.g. payout) and the impact to an account’s balance.

```ruby
def get_transaction_records(app_id,
                            app_token,
                            api_version,
                            unique_key: nil,
                            page: nil,
                            page_size: 10,
                            create_time_start: nil,
                            create_time_end: nil,
                            account_id: nil,
                            payout_id: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |
| `page` | `String` | Query, Optional | Return elements starting from this page. If specified, no other query parameters can be specified. |
| `page_size` | `Integer` | Query, Optional | Maximum number of items per page of results.<br>**Default**: `10`<br>**Constraints**: `>= 1`, `<= 500` |
| `create_time_start` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the start of the search window, inclusive. |
| `create_time_end` | `Integer` | Query, Optional | The create time epoch timestamp (in seconds) for the end of the search window, inclusive. |
| `account_id` | `String` | Query, Optional | All transaction records for resources owned by an account (Payments, Refunds, Adjustments, Payouts, Recoveries, Disputes). |
| `payout_id` | `String` | Query, Optional | All transaction records for resources included in a payout (very useful for reconciliation). |

##### Response Type

[`TransactionRecordsResponse`](#transaction-records-response)

##### Example Usage

```ruby
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_transaction_records(app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

#### GET Transaction Records-Id

The GET /transaction_records/{id} call allows your platform to look up a single transaction record. Transactions records represent one entry (e.g. payout) and the impact to an account’s balance.

```ruby
def get_transaction_records_id(id,
                               app_id,
                               app_token,
                               api_version,
                               unique_key: nil)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Template, Required | - |
| `app_id` | `String` | Header, Required | - |
| `app_token` | `String` | Header, Required | - |
| `api_version` | `String` | Header, Required | - |
| `unique_key` | `String` | Header, Optional | - |

##### Response Type

[`TransactionRecord`](#transaction-record)

##### Example Usage

```ruby
id = 'id0'
app_id = 'App-Id2'
app_token = 'App-Token0'
api_version = 'Api-Version8'

result = client_controller.get_transaction_records_id(id, app_id, app_token, api_version, )
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | INVALID_PARAMS | `APIException` |
| 403 | NOT_AUTHORIZED | `APIException` |
| 500 | UNEXPECTED_ERROR | `APIException` |

## Model Reference

### Structures

* [Partner Service](#partner-service)
* [Address-Rbits](#address-rbits)
* [Country Opted Out Methods](#country-opted-out-methods)
* [Owner of Items](#owner-of-items)
* [Terms](#terms)
* [Weight](#weight)
* [Phone-Legal Entities-Nullable](#phone-legal-entities-nullable)
* [Human Name-Full-Nullable](#human-name-full-nullable)
* [Address-Legal Entities-Nullable](#address-legal-entities-nullable)
* [Mfa-Rbit](#mfa-rbit)
* [Phone-Rbit](#phone-rbit)
* [Person-Rbit](#person-rbit)
* [Partner Service-Rbit](#partner-service-rbit)
* [Industry Code](#industry-code)
* [Fundraising Update](#fundraising-update)
* [Address-Rbit](#address-rbit)
* [Auto Billing](#auto-billing)
* [Business Description](#business-description)
* [Business Name](#business-name)
* [External Account](#external-account)
* [Fundraising Event](#fundraising-event)
* [Transaction Details](#transaction-details)
* [Address-Payments-Resp](#address-payments-resp)
* [Pricing by Currency](#pricing-by-currency)
* [Countries Opted Out Methods](#countries-opted-out-methods)
* [Item-Nullable-Resp](#item-nullable-resp)
* [Additional Representative-Req](#additional-representative-req)
* [Address-Payments-Req](#address-payments-req)
* [Address-Terminals-Resp](#address-terminals-resp)
* [Terminals-Tip](#terminals-tip)
* [Quick Chip](#quick-chip)
* [Additional Representative-Resp](#additional-representative-resp)
* [Deferred Authorization](#deferred-authorization)
* [Holder-Resp](#holder-resp)
* [Opted Out Methods](#opted-out-methods)
* [Transactions Summary Summaries](#transactions-summary-summaries)
* [Recovery Pending Reason](#recovery-pending-reason)
* [Refund Pending Reason](#refund-pending-reason)
* [Payment Pending Reason](#payment-pending-reason)
* [Payout Pending Reason](#payout-pending-reason)
* [Transaction Record Non Expanded](#transaction-record-non-expanded)
* [Payout Failure Reason](#payout-failure-reason)
* [Owner Is Account](#owner-is-account)
* [Payout Method Non Expanded](#payout-method-non-expanded)
* [Payment Method Non Expanded](#payment-method-non-expanded)
* [Order Non Expanded](#order-non-expanded)
* [Payment Failure Reason](#payment-failure-reason)
* [Holder-Req](#holder-req)
* [Token](#token)
* [Controller-Req](#controller-req)
* [Additional Representatives-Req](#additional-representatives-req)
* [Terms-Nullable](#terms-nullable)
* [Address-Nullable](#address-nullable)
* [Owner-Legal Entities-Nullable](#owner-legal-entities-nullable)
* [Owner-Applications](#owner-applications)
* [Controller-Resp](#controller-resp)
* [Additional Representatives-Resp](#additional-representatives-resp)
* [Recovery Failure Reason](#recovery-failure-reason)
* [Dispute Reason](#dispute-reason)
* [Payment Non Expanded](#payment-non-expanded)
* [Pricing](#pricing)
* [Refund-Amounts](#refund-amounts)
* [Payout-Resp](#payout-resp)
* [Refund Failure Reason](#refund-failure-reason)
* [Owner-Legal Entities](#owner-legal-entities)
* [Incoming Payments-Resp](#incoming-payments-resp)
* [Item-Nullable-Req](#item-nullable-req)
* [Refund-Resp](#refund-resp)
* [Recoveries](#recoveries)
* [Payout Method-Resp](#payout-method-resp)
* [Payout](#payout)
* [Payment Method-Resp](#payment-method-resp)
* [Payments-V 3 0](#payments-v-3-0)
* [Payment Bank Us-Req](#payment-bank-us-req)
* [Legal Entity](#legal-entity)
* [Order-Resp](#order-resp)
* [Address-Terminals-Req](#address-terminals-req)
* [Contactless Payments-Req](#contactless-payments-req)
* [Terminal-Resp](#terminal-resp)
* [Legal Entity-Resp](#legal-entity-resp)
* [Item-Resp](#item-resp)
* [Disputes](#disputes)
* [Transactions Summary](#transactions-summary)
* [Interchange Fee](#interchange-fee)
* [Billing Statement](#billing-statement)
* [Adjustments](#adjustments)
* [Account-Resp](#account-resp)
* [Transaction Record](#transaction-record)
* [Owner-Accounts](#owner-accounts)
* [Incoming Payments-Req](#incoming-payments-req)
* [Capture-Amounts](#capture-amounts)
* [Payment Method for Payments](#payment-method-for-payments)
* [Payment Method-Req](#payment-method-req)
* [Payout-Req](#payout-req)
* [Payout Method-Req](#payout-method-req)
* [Capabilities-Resp](#capabilities-resp)
* [Item-Req](#item-req)
* [Refund-Req](#refund-req)
* [Order-Req](#order-req)
* [Accounts Capabilities Request](#accounts-capabilities-request)
* [Accounts Request](#accounts-request)
* [Accounts Request 1](#accounts-request-1)
* [Accounts Response](#accounts-response)
* [Additional Representatives](#additional-representatives)
* [Additional Representatives 1](#additional-representatives-1)
* [Adjustments Request](#adjustments-request)
* [Adjustments Response](#adjustments-response)
* [Application Block](#application-block)
* [Application Block 4](#application-block-4)
* [Associated Phone](#associated-phone)
* [Associated Resource](#associated-resource)
* [Balances](#balances)
* [Billing Statements Interchange Fees Response](#billing-statements-interchange-fees-response)
* [Billing Statements Response](#billing-statements-response)
* [Billing Statements Transactions Summary Response](#billing-statements-transactions-summary-response)
* [Buyer](#buyer)
* [CA](#ca)
* [CA1](#ca1)
* [CA4](#ca4)
* [CAD](#cad)
* [CAD1](#cad1)
* [CAD2](#cad2)
* [Contactless Payments](#contactless-payments)
* [Controller](#controller)
* [Controller 1](#controller-1)
* [Credit Card](#credit-card)
* [Credit Card 1](#credit-card-1)
* [Credit Card 2](#credit-card-2)
* [Credit Card 4](#credit-card-4)
* [Currencies](#currencies)
* [Currencies 1](#currencies-1)
* [Currencies 2](#currencies-2)
* [Currencies 3](#currencies-3)
* [Current Issue](#current-issue)
* [Current Issue 2](#current-issue-2)
* [Date of Birth](#date-of-birth)
* [Detail](#detail)
* [Detail 1](#detail-1)
* [Detail 2](#detail-2)
* [Detail 3](#detail-3)
* [Detail 4](#detail-4)
* [Detail 5](#detail-5)
* [Detail 6](#detail-6)
* [Detail 7](#detail-7)
* [Detail 8](#detail-8)
* [Detail 9](#detail-9)
* [Detail 10](#detail-10)
* [Disputes Request](#disputes-request)
* [Disputes Response](#disputes-response)
* [Document](#document)
* [Documentation](#documentation)
* [Documentation 1](#documentation-1)
* [Embedded-Rbit](#embedded-rbit)
* [Entity Country Info](#entity-country-info)
* [Entity Verification](#entity-verification)
* [Entity Verification 1](#entity-verification-1)
* [Flat Guide](#flat-guide)
* [GB](#gb)
* [GBP](#gbp)
* [GBP1](#gbp1)
* [GBP2](#gbp2)
* [Industry](#industry)
* [Interchange Plus](#interchange-plus)
* [Itemized Receipt](#itemized-receipt)
* [Items Response](#items-response)
* [Legal Entities Request](#legal-entities-request)
* [Legal Entities Response](#legal-entities-response)
* [Legal Entities Verifications Request](#legal-entities-verifications-request)
* [Legal Entities Verifications Response](#legal-entities-verifications-response)
* [Line Item](#line-item)
* [Line Item 1](#line-item-1)
* [Name](#name)
* [Notification Preferences Request](#notification-preferences-request)
* [Notification Preferences Request 1](#notification-preferences-request-1)
* [Notification Preferences Response](#notification-preferences-response)
* [Notification Preferences Response 1](#notification-preferences-response-1)
* [Notification Preferences Response 2](#notification-preferences-response-2)
* [Notifications Response](#notifications-response)
* [Notifications Response 1](#notifications-response-1)
* [Orders Response](#orders-response)
* [Owner 3](#owner-3)
* [Owner 16](#owner-16)
* [Owner 20](#owner-20)
* [Payment Methods Request](#payment-methods-request)
* [Payment Methods Response](#payment-methods-response)
* [Payment Methods Verify Bank Deposits Request](#payment-methods-verify-bank-deposits-request)
* [Payment Bank](#payment-bank)
* [Payment Bank Us](#payment-bank-us)
* [Payments](#payments)
* [Payments Cancel Request](#payments-cancel-request)
* [Payments Capture Request](#payments-capture-request)
* [Payments Request](#payments-request)
* [Payments Request 1](#payments-request-1)
* [Payments Response](#payments-response)
* [Payments 1](#payments-1)
* [Payout Methods Request](#payout-methods-request)
* [Payout Methods Response](#payout-methods-response)
* [Payout Bank Ca](#payout-bank-ca)
* [Payout Bank Ca 1](#payout-bank-ca-1)
* [Payout Bank Gb](#payout-bank-gb)
* [Payout Bank Gb 1](#payout-bank-gb-1)
* [Payout Bank Us](#payout-bank-us)
* [Payout Bank Us 1](#payout-bank-us-1)
* [Payouts](#payouts)
* [Payouts Request](#payouts-request)
* [Payouts Response](#payouts-response)
* [Payouts 1](#payouts-1)
* [Percentage Guide](#percentage-guide)
* [Personal Country Info](#personal-country-info)
* [Personal Country Info 1](#personal-country-info-1)
* [Personal Verification](#personal-verification)
* [Personal Verification 5](#personal-verification-5)
* [Phone](#phone)
* [Phone 1](#phone-1)
* [Rbits Request](#rbits-request)
* [Rbits Response](#rbits-response)
* [Rbits Response 1](#rbits-response-1)
* [Reason](#reason)
* [Recoveries Request](#recoveries-request)
* [Recoveries Response](#recoveries-response)
* [Refunds Request](#refunds-request)
* [Refunds Response](#refunds-response)
* [Reject Reason](#reject-reason)
* [Representative 0](#representative-0)
* [Representative 01](#representative-01)
* [Resolution](#resolution)
* [Result](#result)
* [Result 1](#result-1)
* [Result 2](#result-2)
* [Shipping Info](#shipping-info)
* [Shipping Status](#shipping-status)
* [Shipping Status 1](#shipping-status-1)
* [Standard](#standard)
* [Target](#target)
* [Terminal Configuration](#terminal-configuration)
* [Terminal Configuration 1](#terminal-configuration-1)
* [Terminal Configuration 2](#terminal-configuration-2)
* [Terminal Display](#terminal-display)
* [Terminals Request](#terminals-request)
* [Terminals Request 1](#terminals-request-1)
* [Terminals Response](#terminals-response)
* [Terms of Service](#terms-of-service)
* [Tokens Request](#tokens-request)
* [Tokens Response](#tokens-response)
* [Transaction Records Response](#transaction-records-response)
* [Upcoming Issue](#upcoming-issue)
* [US](#us)
* [US1](#us1)
* [US4](#us4)
* [USD](#usd)
* [USD1](#usd1)
* [USD2](#usd2)

#### Partner Service

##### Class Name

`PartnerService`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `currency` | [`CurrencyEnum`](#currency) | Optional | - |
| `service_monthly_cost` | `Integer` | Optional | - |
| `service_name` | `String` | Required | **Constraints**: *Maximum Length*: `1024` |

##### Example (as JSON)

```json
{
  "currency": null,
  "service_monthly_cost": null,
  "service_name": "service_name6"
}
```

#### Address-Rbits

##### Class Name

`AddressRbits`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `city` | `String` | Optional | **Constraints**: *Maximum Length*: `30` |
| `country` | [`CountryCodeEnum`](#country-code) | Optional | - |
| `line_1` | `String` | Optional | **Constraints**: *Maximum Length*: `60` |
| `line_2` | `String` | Optional | **Constraints**: *Maximum Length*: `60` |
| `postal_code` | `String` | Required | **Constraints**: *Maximum Length*: `14` |
| `region` | `String` | Optional | **Constraints**: *Maximum Length*: `30` |

##### Example (as JSON)

```json
{
  "city": null,
  "country": null,
  "line1": null,
  "line2": null,
  "postal_code": "postal_code2",
  "region": null
}
```

#### Country Opted Out Methods

##### Class Name

`CountryOptedOutMethods`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `debit_cards` | `Boolean` | Optional | - |

##### Example (as JSON)

```json
{
  "debit_cards": null
}
```

#### Owner of Items

##### Class Name

`OwnerOfItems`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Required | - |
| `path` | `String` | Required | - |
| `resource` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "id": null,
  "path": null,
  "resource": "accounts"
}
```

#### Terms

##### Class Name

`Terms`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `terms_text` | `String` | Optional | - |
| `terms_uri` | `String` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |

##### Example (as JSON)

```json
{
  "terms_text": null,
  "terms_uri": null
}
```

#### Weight

##### Class Name

`Weight`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `units` | [`UnitsEnum`](#units) | Required | - |
| `weight` | `Float` | Required | - |

##### Example (as JSON)

```json
{
  "units": "pounds",
  "weight": 192.04
}
```

#### Phone-Legal Entities-Nullable

##### Class Name

`PhoneLegalEntitiesNullable`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `country_code` | `String` | Required | **Constraints**: *Pattern*: `^\+?[0-9]{1,3}$` |
| `phone_number` | `String` | Required | **Constraints**: *Pattern*: `^[0-9]{1,14}$` |

##### Example (as JSON)

```json
{
  "country_code": "country_code0",
  "phone_number": "phone_number2"
}
```

#### Human Name-Full-Nullable

##### Class Name

`HumanNameFullNullable`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `first` | `String` | Required | **Constraints**: *Minimum Length*: `2`, *Maximum Length*: `30` |
| `last` | `String` | Required | **Constraints**: *Minimum Length*: `2`, *Maximum Length*: `30` |
| `middle` | `String` | Optional | **Constraints**: *Maximum Length*: `30` |
| `prefix` | `String` | Optional | **Constraints**: *Maximum Length*: `20` |
| `suffix` | `String` | Optional | **Constraints**: *Maximum Length*: `20` |

##### Example (as JSON)

```json
{
  "first": "first6",
  "last": "last0",
  "middle": null,
  "prefix": null,
  "suffix": null
}
```

#### Address-Legal Entities-Nullable

##### Class Name

`AddressLegalEntitiesNullable`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `city` | `String` | Required | **Constraints**: *Maximum Length*: `30` |
| `country` | [`CountryCodeEnum`](#country-code) | Required | - |
| `line_1` | `String` | Required | **Constraints**: *Maximum Length*: `60` |
| `line_2` | `String` | Optional | **Constraints**: *Maximum Length*: `60` |
| `postal_code` | `String` | Required | **Constraints**: *Maximum Length*: `14` |
| `region` | `String` | Required | **Constraints**: *Maximum Length*: `30` |

##### Example (as JSON)

```json
{
  "city": "city0",
  "country": "HK",
  "line1": "line12",
  "line2": null,
  "postal_code": "postal_code2",
  "region": "region6"
}
```

#### Mfa-Rbit

##### Class Name

`MfaRbit`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mfa_action` | [`MfaActionEnum`](#mfa-action) | Required | - |
| `associated_phone` | [`AssociatedPhone`](#associated-phone) | Required | - |

##### Example (as JSON)

```json
{
  "mfa_action": "activated",
  "associated_phone": {
    "country_code": null,
    "phone_number": null
  }
}
```

#### Phone-Rbit

##### Class Name

`PhoneRbit`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `country_code` | `String` | Required | **Constraints**: *Pattern*: `^\+?[0-9]{1,3}$` |
| `phone_number` | `String` | Required | **Constraints**: *Pattern*: `^[0-9]{1,14}$` |
| `phone_type` | [`PhoneTypeEnum`](#phone-type) | Optional | - |

##### Example (as JSON)

```json
{
  "country_code": "country_code0",
  "phone_number": "phone_number2",
  "phone_type": null
}
```

#### Person-Rbit

##### Class Name

`PersonRbit`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_of_birth` | [`DateOfBirth`](#date-of-birth) | Optional | - |
| `name` | [`Name`](#name) | Required | - |
| `role` | [`RoleEnum`](#role) | Optional | - |

##### Example (as JSON)

```json
{
  "date_of_birth": null,
  "name": {
    "first": "first6",
    "last": "last0"
  },
  "role": null
}
```

#### Partner Service-Rbit

##### Class Name

`PartnerServiceRbit`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `currency` | [`CurrencyEnum`](#currency) | Optional | - |
| `modules_used` | [`Array<PartnerService>`](#partner-service) | Optional | - |
| `service_monthly_cost` | `Integer` | Optional | - |
| `service_name` | `String` | Required | **Constraints**: *Maximum Length*: `1024` |

##### Example (as JSON)

```json
{
  "currency": null,
  "modules_used": null,
  "service_monthly_cost": null,
  "service_name": "service_name6"
}
```

#### Industry Code

##### Class Name

`IndustryCode`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `code` | `String` | Required | **Constraints**: *Maximum Length*: `32` |
| `code_type` | [`CodeTypeEnum`](#code-type) | Required | - |
| `industry_detail` | `String` | Optional | **Constraints**: *Maximum Length*: `1024` |

##### Example (as JSON)

```json
{
  "code": "code8",
  "code_type": "north_american_industry_classification_system",
  "industry_detail": null
}
```

#### Fundraising Update

##### Class Name

`FundraisingUpdate`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `campaign_page_update` | `String` | Optional | **Constraints**: *Maximum Length*: `10000` |
| `campaign_title_update` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |

##### Example (as JSON)

```json
{
  "campaign_page_update": null,
  "campaign_title_update": null
}
```

#### Address-Rbit

##### Class Name

`AddressRbit`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `address_type` | [`AddressTypeEnum`](#address-type) | Optional | - |
| `normalized_address` | [`AddressRbits`](#address-rbits) | Optional | - |
| `normalized_address_status` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `normalized_source` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `origin_address` | [`AddressRbits`](#address-rbits) | Required | - |

##### Example (as JSON)

```json
{
  "address_type": null,
  "normalized_address": null,
  "normalized_address_status": null,
  "normalized_source": null,
  "origin_address": {
    "city": null,
    "country": null,
    "line1": null,
    "line2": null,
    "postal_code": "postal_code0",
    "region": null
  }
}
```

#### Auto Billing

##### Class Name

`AutoBilling`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `autobill_setup_time` | `Integer` | Optional | - |
| `payment_frequency` | `String` | Optional | **Constraints**: *Maximum Length*: `32` |
| `payment_number` | `Integer` | Optional | - |
| `setup_by` | [`SetupByEnum`](#setup-by) | Optional | - |
| `total_payments_scheduled` | `Integer` | Optional | - |

##### Example (as JSON)

```json
{
  "autobill_setup_time": null,
  "payment_frequency": null,
  "payment_number": null,
  "setup_by": null,
  "total_payments_scheduled": null
}
```

#### Business Description

##### Class Name

`BusinessDescription`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `description` | `String` | Required | **Constraints**: *Maximum Length*: `50000` |
| `number_of_employees` | `Integer` | Optional | **Constraints**: `>= 1` |
| `sales_tax_liability_flag` | `Boolean` | Optional | - |

##### Example (as JSON)

```json
{
  "description": "description0",
  "number_of_employees": null,
  "sales_tax_liability_flag": null
}
```

#### Business Name

##### Class Name

`BusinessName`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `name` | `String` | Required | **Constraints**: *Maximum Length*: `255` |
| `name_type` | [`NameTypeEnum`](#name-type) | Optional | - |

##### Example (as JSON)

```json
{
  "name": "name0",
  "name_type": null
}
```

#### External Account

##### Class Name

`ExternalAccount`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `account_type` | `String` | Required | **Constraints**: *Maximum Length*: `255` |
| `connections` | `Integer` | Optional | - |
| `create_time` | `Integer` | Optional | - |
| `feedback_average_score` | `Float` | Optional | - |
| `feedback_score_percent_positive` | `Float` | Optional | - |
| `feedback_scores_provided` | `Integer` | Optional | - |
| `followers` | `Integer` | Optional | - |
| `following` | `Integer` | Optional | - |
| `is_partner_account` | `Boolean` | Required | - |
| `modify_time` | `Integer` | Optional | - |
| `uri` | `String` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |
| `user_id` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |

##### Example (as JSON)

```json
{
  "account_type": "account_type4",
  "connections": null,
  "create_time": null,
  "feedback_average_score": null,
  "feedback_score_percent_positive": null,
  "feedback_scores_provided": null,
  "followers": null,
  "following": null,
  "is_partner_account": false,
  "modify_time": null,
  "uri": null,
  "user_id": null
}
```

#### Fundraising Event

##### Class Name

`FundraisingEvent`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `currency` | [`CurrencyEnum`](#currency) | Optional | - |
| `event_time` | `Integer` | Optional | - |
| `fundraising_goal` | `Integer` | Optional | - |
| `giving_deadline` | `Integer` | Optional | - |
| `name` | `String` | Required | **Constraints**: *Maximum Length*: `255` |
| `uri` | `String` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |
| `description` | `String` | Optional | **Constraints**: *Maximum Length*: `64000` |
| `photo_uris` | `Array<String>` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |
| `campaign_category` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `campaign_team` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |

##### Example (as JSON)

```json
{
  "currency": null,
  "event_time": null,
  "fundraising_goal": null,
  "giving_deadline": null,
  "name": "name0",
  "uri": null,
  "description": null,
  "photo_uris": null,
  "campaign_category": null,
  "campaign_team": null
}
```

#### Transaction Details

##### Class Name

`TransactionDetails`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `discount` | `String` | Optional | **Constraints**: *Maximum Length*: `2083` |
| `itemized_receipt` | [`Array<ItemizedReceipt>`](#itemized-receipt) | Optional | - |
| `note` | `String` | Optional | **Constraints**: *Maximum Length*: `2083` |
| `purchase_order_id` | `String` | Optional | **Constraints**: *Maximum Length*: `2083` |
| `receipt_uri` | `String` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |
| `service_address` | [`AddressRbits`](#address-rbits) | Optional | - |
| `shipping_address` | [`AddressRbits`](#address-rbits) | Optional | - |
| `shipping_info` | [`Array<ShippingInfo>`](#shipping-info) | Optional | - |
| `terms_text` | `String` | Optional | **Constraints**: *Maximum Length*: `2083` |
| `terms_uri` | `String` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |

##### Example (as JSON)

```json
{
  "discount": null,
  "itemized_receipt": null,
  "note": null,
  "purchase_order_id": null,
  "receipt_uri": null,
  "service_address": null,
  "shipping_address": null,
  "shipping_info": null,
  "terms_text": null,
  "terms_uri": null
}
```

#### Address-Payments-Resp

##### Class Name

`AddressPaymentsResp`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `city` | `String` | Optional | **Constraints**: *Maximum Length*: `30` |
| `country` | [`CountryCodeEnum`](#country-code) | Required | - |
| `line_1` | `String` | Optional | **Constraints**: *Maximum Length*: `60` |
| `line_2` | `String` | Optional | **Constraints**: *Maximum Length*: `60` |
| `postal_code` | `String` | Required | **Constraints**: *Maximum Length*: `14` |
| `region` | `String` | Optional | **Constraints**: *Maximum Length*: `30` |

##### Example (as JSON)

```json
{
  "city": null,
  "country": "HK",
  "line1": null,
  "line2": null,
  "postal_code": "postal_code2",
  "region": null
}
```

#### Pricing by Currency

##### Class Name

`PricingByCurrency`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `credit_card` | [`CreditCard`](#credit-card) | Optional | - |
| `payment_bank` | [`PaymentBank`](#payment-bank) | Optional | - |

##### Example (as JSON)

```json
{
  "credit_card": null,
  "payment_bank": null
}
```

#### Countries Opted Out Methods

##### Class Name

`CountriesOptedOutMethods`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `ca` | [`CountryOptedOutMethods`](#country-opted-out-methods) | Optional | - |

##### Example (as JSON)

```json
{
  "CA": null
}
```

#### Item-Nullable-Resp

##### Class Name

`ItemNullableResp`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `create_time` | `Integer` | Required | - |
| `currency` | [`CurrencyEnum`](#currency) | Optional | - |
| `description` | `String` | Optional | **Constraints**: *Maximum Length*: `2047` |
| `id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `owner` | [`OwnerOfItems`](#owner-of-items) | Required | - |
| `path` | `String` | Required | - |
| `photos` | `Array<String>` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |
| `price` | `Integer` | Optional | - |
| `product_code` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `product_details` | `Object` | Optional | - |
| `product_name` | `String` | Required | **Constraints**: *Maximum Length*: `255` |
| `reference_number` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `resource` | `String` | Required | - |
| `shipping_options` | `Array<String>` | Optional | **Constraints**: *Unique Items Required* |
| `state` | `String` | Required | - |
| `terms` | [`Terms`](#terms) | Optional | - |
| `uri` | `String` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |
| `weight` | [`Weight`](#weight) | Optional | - |

##### Example (as JSON)

```json
{
  "create_time": null,
  "id": null,
  "owner": {
    "id": null,
    "path": null,
    "resource": "accounts"
  },
  "path": null,
  "product_name": null,
  "resource": "items",
  "state": null
}
```

#### Additional Representative-Req

##### Class Name

`AdditionalRepresentativeReq`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `is_auxiliary_controller` | `Boolean` | Optional | - |
| `is_beneficial_owner` | `Boolean` | Optional | - |
| `address` | [`AddressLegalEntitiesNullable`](#address-legal-entities-nullable) | Optional | - |
| `date_of_birth` | [`DateOfBirth`](#date-of-birth) | Optional | - |
| `email` | `String` | Optional | **Constraints**: *Maximum Length*: `254`, *Pattern*: `^.+@.+\.[a-zA-Z]{2,}$` |
| `email_is_verified` | `Boolean` | Optional | - |
| `name` | [`HumanNameFullNullable`](#human-name-full-nullable) | Optional | - |
| `personal_country_info` | [`PersonalCountryInfo`](#personal-country-info) | Optional | - |
| `phone` | [`PhoneLegalEntitiesNullable`](#phone-legal-entities-nullable) | Optional | - |
| `job_title` | `String` | Optional | **Constraints**: *Minimum Length*: `2`, *Maximum Length*: `64` |

##### Example (as JSON)

```json
{
  "is_auxiliary_controller": null,
  "is_beneficial_owner": null,
  "address": null,
  "date_of_birth": null,
  "email": null,
  "email_is_verified": null,
  "name": null,
  "personal_country_info": null,
  "phone": null,
  "job_title": null
}
```

#### Address-Payments-Req

##### Class Name

`AddressPaymentsReq`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `city` | `String` | Optional | **Constraints**: *Maximum Length*: `30` |
| `country` | [`CountryCodeEnum`](#country-code) | Required | - |
| `line_1` | `String` | Optional | **Constraints**: *Maximum Length*: `60` |
| `line_2` | `String` | Optional | **Constraints**: *Maximum Length*: `60` |
| `postal_code` | `String` | Required | **Constraints**: *Maximum Length*: `14` |
| `region` | `String` | Optional | **Constraints**: *Maximum Length*: `30` |

##### Example (as JSON)

```json
{
  "city": null,
  "country": "HK",
  "line1": null,
  "line2": null,
  "postal_code": "postal_code2",
  "region": null
}
```

#### Address-Terminals-Resp

##### Class Name

`AddressTerminalsResp`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `city` | `String` | Required | **Constraints**: *Maximum Length*: `30` |
| `country` | [`CountryCodeEnum`](#country-code) | Required | - |
| `line_1` | `String` | Required | **Constraints**: *Maximum Length*: `60` |
| `line_2` | `String` | Optional | **Constraints**: *Maximum Length*: `60` |
| `postal_code` | `String` | Required | **Constraints**: *Maximum Length*: `14` |
| `region` | `String` | Required | **Constraints**: *Maximum Length*: `30` |

##### Example (as JSON)

```json
{
  "city": "city0",
  "country": "HK",
  "line1": "line12",
  "line2": null,
  "postal_code": "postal_code2",
  "region": "region6"
}
```

#### Terminals-Tip

##### Class Name

`TerminalsTip`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mode` | [`ModeEnum`](#mode) | Required | The way in which tip is handled by this terminal. If "disabled", tip will not be prompted for. Otherwise, value determines if the prompt should appear on the terminal or on the receipt. Note: If set to "prompt_on_terminal" then you must provide the "terminal_display" field as well. |
| `terminal_display` | [`TerminalDisplay`](#terminal-display) | Optional | This configuration is required if the mode is "prompt_on_terminal", and is responsible for configuring how the tip guide appears on the physical terminal. |

##### Example (as JSON)

```json
{
  "mode": "prompt_on_terminal",
  "terminal_display": {
    "amount_guide_type": "percentage_guide",
    "percentage_guide": {
      "show_amount": false,
      "percentage_low": 15,
      "percentage_medium": 18,
      "percentage_high": 20
    }
  }
}
```

#### Quick Chip

Configuration settings for quick chip functionality.

##### Class Name

`QuickChip`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `enabled` | `Boolean` | Required | Determines if quick chip functionality is enabled on the terminal. |

##### Example (as JSON)

```json
{
  "enabled": false
}
```

#### Additional Representative-Resp

##### Class Name

`AdditionalRepresentativeResp`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `is_auxiliary_controller` | `Boolean` | Optional | - |
| `is_beneficial_owner` | `Boolean` | Optional | - |
| `address` | [`AddressLegalEntitiesNullable`](#address-legal-entities-nullable) | Optional | - |
| `date_of_birth_is_present` | `Boolean` | Optional | - |
| `email` | `String` | Optional | **Constraints**: *Maximum Length*: `254`, *Pattern*: `^.+@.+\.[a-zA-Z]{2,}$` |
| `email_is_verified` | `Boolean` | Optional | - |
| `name` | [`HumanNameFullNullable`](#human-name-full-nullable) | Optional | - |
| `personal_country_info` | [`PersonalCountryInfo1`](#personal-country-info-1) | Optional | - |
| `phone` | [`PhoneLegalEntitiesNullable`](#phone-legal-entities-nullable) | Optional | - |
| `job_title` | `String` | Optional | **Constraints**: *Minimum Length*: `2`, *Maximum Length*: `64` |

##### Example (as JSON)

```json
{
  "is_auxiliary_controller": null,
  "is_beneficial_owner": null,
  "address": null,
  "date_of_birth_is_present": null,
  "email": null,
  "email_is_verified": null,
  "name": null,
  "personal_country_info": null,
  "phone": null,
  "job_title": null
}
```

#### Deferred Authorization

Configuration settings for deferred authorization functionality.

##### Class Name

`DeferredAuthorization`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `enabled` | `Boolean` | Required | Determines if deferred authorization functionality is enabled. |
| `international_enabled` | `Boolean` | Required | Determines if international payment methods are allowed for deferred authorizations. |
| `max_transaction_count` | `Integer` | Required | The maximum number of transactions that can be processed as deferred authorizations. Once exceeded, the terminal will no longer process transactions until connectivity has been restored.<br>**Constraints**: `>= 0` |
| `max_total_amount` | `Integer` | Required | The maximum total amount of transaction volume that can be processed as deferred authorizations. Once exceeded, the terminal will no longer process transactions until connectivity has been restored.<br>**Constraints**: `>= 0` |
| `max_transaction_amount` | `Integer` | Required | The maximum total amount of transaction volume that can be processed as deferred authorizations. Once exceeded, the terminal will no longer process transactions until connectivity has been restored.<br>**Constraints**: `>= 0` |
| `supported_card_entry_modes` | [`Array<SupportedCardEntryModeEnum>`](#supported-card-entry-mode) | Required | The card entry modes that are allowed in deferred authorizations. |

##### Example (as JSON)

```json
{
  "enabled": null,
  "international_enabled": null,
  "max_transaction_count": 20,
  "max_total_amount": 250000,
  "max_transaction_amount": 12500,
  "supported_card_entry_modes": [
    "chip",
    "contactless"
  ]
}
```

#### Holder-Resp

##### Class Name

`HolderResp`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `address` | [`AddressPaymentsResp`](#address-payments-resp) | Optional | - |
| `email` | `String` | Optional | **Constraints**: *Maximum Length*: `254`, *Pattern*: `^.+@.+\.[a-zA-Z]{2,}$` |
| `holder_name` | `String` | Required | **Constraints**: *Minimum Length*: `2`, *Maximum Length*: `134` |
| `phone` | [`Phone`](#phone) | Optional | - |

##### Example (as JSON)

```json
{
  "address": null,
  "email": null,
  "holder_name": "holder_name4",
  "phone": null
}
```

#### Opted Out Methods

##### Class Name

`OptedOutMethods`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `countries` | [`CountriesOptedOutMethods`](#countries-opted-out-methods) | Optional | - |

##### Example (as JSON)

```json
{
  "countries": null
}
```

#### Transactions Summary Summaries

##### Class Name

`TransactionsSummarySummaries`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `fee_type` | [`FeeTypeEnum`](#fee-type) | Required | - |
| `currency` | [`CurrencyEnum`](#currency) | Required | - |
| `total_amount` | `Integer` | Required | **Constraints**: `>= 0` |
| `item_count` | `Integer` | Required | **Constraints**: `>= 0` |

##### Example (as JSON)

```json
{
  "fee_type": "ECHECK",
  "currency": "CAD",
  "total_amount": 112,
  "item_count": 38
}
```

#### Recovery Pending Reason

##### Class Name

`RecoveryPendingReason`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `details` | [`Array<Detail>`](#detail) | Optional | - |
| `reason_code` | [`ReasonCodeEnum`](#reason-code) | Optional | - |
| `reason_message` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "details": null,
  "reason_code": null,
  "reason_message": null
}
```

#### Refund Pending Reason

##### Class Name

`RefundPendingReason`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `details` | [`Array<Detail1>`](#detail-1) | Optional | - |
| `reason_code` | [`ReasonCode1Enum`](#reason-code-1) | Optional | - |
| `reason_message` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "details": null,
  "reason_code": null,
  "reason_message": null
}
```

#### Payment Pending Reason

##### Class Name

`PaymentPendingReason`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `details` | [`Array<Detail2>`](#detail-2) | Optional | - |
| `reason_code` | [`ReasonCode2Enum`](#reason-code-2) | Optional | - |
| `reason_message` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "details": null,
  "reason_code": null,
  "reason_message": null
}
```

#### Payout Pending Reason

##### Class Name

`PayoutPendingReason`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `details` | [`Array<Detail3>`](#detail-3) | Optional | - |
| `reason_code` | [`ReasonCode3Enum`](#reason-code-3) | Optional | - |
| `reason_message` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "details": null,
  "reason_code": null,
  "reason_message": null
}
```

#### Transaction Record Non Expanded

##### Class Name

`TransactionRecordNonExpanded`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Required | - |
| `path` | `String` | Required | - |
| `resource` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "id": null,
  "path": null,
  "resource": "transaction_records"
}
```

#### Payout Failure Reason

##### Class Name

`PayoutFailureReason`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `details` | [`Array<Detail4>`](#detail-4) | Optional | - |
| `reason_code` | [`ReasonCode4Enum`](#reason-code-4) | Optional | - |
| `reason_message` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "details": null,
  "reason_code": null,
  "reason_message": null
}
```

#### Owner Is Account

Owner structure to be used in any resource where an account is the owner

##### Class Name

`OwnerIsAccount`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Required | - |
| `path` | `String` | Required | - |
| `resource` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "id": null,
  "path": null,
  "resource": "accounts"
}
```

#### Payout Method Non Expanded

##### Class Name

`PayoutMethodNonExpanded`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Required | - |
| `path` | `String` | Required | - |
| `resource` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "id": null,
  "path": null,
  "resource": "payout_methods"
}
```

#### Payment Method Non Expanded

##### Class Name

`PaymentMethodNonExpanded`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Required | - |
| `path` | `String` | Required | - |
| `resource` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "id": null,
  "path": null,
  "resource": "payment_methods"
}
```

#### Order Non Expanded

##### Class Name

`OrderNonExpanded`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Required | - |
| `path` | `String` | Required | - |
| `resource` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "id": null,
  "path": null,
  "resource": "orders"
}
```

#### Payment Failure Reason

##### Class Name

`PaymentFailureReason`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `details` | [`Array<Detail5>`](#detail-5) | Optional | - |
| `reason_code` | [`ReasonCode5Enum`](#reason-code-5) | Optional | - |
| `reason_message` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "details": null,
  "reason_code": null,
  "reason_message": null
}
```

#### Holder-Req

##### Class Name

`HolderReq`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `address` | [`AddressPaymentsReq`](#address-payments-req) | Required | - |
| `email` | `String` | Optional | **Constraints**: *Maximum Length*: `254`, *Pattern*: `^.+@.+\.[a-zA-Z]{2,}$` |
| `holder_name` | `String` | Required | The holder name as it appears on the credit card or bank account statement.<br>Note: all printable characters accepted<br>**Constraints**: *Minimum Length*: `3`, *Maximum Length*: `26`, *Pattern*: `^[^\x00-\x1f]+$` |
| `phone` | [`Phone1`](#phone-1) | Optional | - |

##### Example (as JSON)

```json
{
  "address": {
    "city": null,
    "country": "SI",
    "line1": null,
    "line2": null,
    "postal_code": "postal_code8",
    "region": null
  },
  "email": null,
  "holder_name": "holder_name4",
  "phone": null
}
```

#### Token

##### Class Name

`Token`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `permissioned_fields` | `Array<String>` | Optional | **Constraints**: *Maximum Length*: `1024` |

##### Example (as JSON)

```json
{
  "id": "id0",
  "permissioned_fields": null
}
```

#### Controller-Req

##### Class Name

`ControllerReq`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `is_beneficial_owner` | `Boolean` | Optional | - |
| `address` | [`AddressLegalEntitiesNullable`](#address-legal-entities-nullable) | Optional | - |
| `date_of_birth` | [`DateOfBirth`](#date-of-birth) | Optional | - |
| `email` | `String` | Optional | **Constraints**: *Maximum Length*: `254`, *Pattern*: `^.+@.+\.[a-zA-Z]{2,}$` |
| `email_is_verified` | `Boolean` | Optional | - |
| `name` | [`HumanNameFullNullable`](#human-name-full-nullable) | Optional | - |
| `personal_country_info` | [`PersonalCountryInfo`](#personal-country-info) | Optional | - |
| `phone` | [`PhoneLegalEntitiesNullable`](#phone-legal-entities-nullable) | Optional | - |
| `job_title` | `String` | Optional | **Constraints**: *Minimum Length*: `2`, *Maximum Length*: `64` |

##### Example (as JSON)

```json
{
  "is_beneficial_owner": null,
  "address": null,
  "date_of_birth": null,
  "email": null,
  "email_is_verified": null,
  "name": null,
  "personal_country_info": null,
  "phone": null,
  "job_title": null
}
```

#### Additional Representatives-Req

##### Class Name

`AdditionalRepresentativesReq`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `representative_0` | [`AdditionalRepresentativeReq`](#additional-representative-req) | Optional | - |
| `representative_1` | [`AdditionalRepresentativeReq`](#additional-representative-req) | Optional | - |
| `representative_2` | [`AdditionalRepresentativeReq`](#additional-representative-req) | Optional | - |
| `representative_3` | [`AdditionalRepresentativeReq`](#additional-representative-req) | Optional | - |

##### Example (as JSON)

```json
{
  "representative_0": null,
  "representative_1": null,
  "representative_2": null,
  "representative_3": null
}
```

#### Terms-Nullable

##### Class Name

`TermsNullable`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `terms_text` | `String` | Optional | - |
| `terms_uri` | `String` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |

##### Example (as JSON)

```json
{
  "terms_text": null,
  "terms_uri": null
}
```

#### Address-Nullable

##### Class Name

`AddressNullable`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `city` | `String` | Optional | **Constraints**: *Maximum Length*: `30` |
| `country` | [`CountryCodeEnum`](#country-code) | Optional | - |
| `line_1` | `String` | Optional | **Constraints**: *Maximum Length*: `60` |
| `line_2` | `String` | Optional | **Constraints**: *Maximum Length*: `60` |
| `postal_code` | `String` | Required | **Constraints**: *Maximum Length*: `14` |
| `region` | `String` | Optional | **Constraints**: *Maximum Length*: `30` |

##### Example (as JSON)

```json
{
  "city": null,
  "country": null,
  "line1": null,
  "line2": null,
  "postal_code": "postal_code2",
  "region": null
}
```

#### Owner-Legal Entities-Nullable

##### Class Name

`OwnerLegalEntitiesNullable`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Required | - |
| `path` | `String` | Required | - |
| `resource` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "id": null,
  "path": null,
  "resource": "legal_entities"
}
```

#### Owner-Applications

##### Class Name

`OwnerApplications`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Required | - |
| `path` | `String` | Optional | - |
| `resource` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "id": null,
  "resource": "applications"
}
```

#### Controller-Resp

##### Class Name

`ControllerResp`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `is_beneficial_owner` | `Boolean` | Optional | - |
| `address` | [`AddressLegalEntitiesNullable`](#address-legal-entities-nullable) | Optional | - |
| `date_of_birth_is_present` | `Boolean` | Optional | - |
| `email` | `String` | Optional | **Constraints**: *Maximum Length*: `254`, *Pattern*: `^.+@.+\.[a-zA-Z]{2,}$` |
| `email_is_verified` | `Boolean` | Optional | - |
| `name` | [`HumanNameFullNullable`](#human-name-full-nullable) | Optional | - |
| `personal_country_info` | [`PersonalCountryInfo1`](#personal-country-info-1) | Optional | - |
| `phone` | [`PhoneLegalEntitiesNullable`](#phone-legal-entities-nullable) | Optional | - |
| `job_title` | `String` | Optional | **Constraints**: *Minimum Length*: `2`, *Maximum Length*: `64` |

##### Example (as JSON)

```json
{
  "is_beneficial_owner": null,
  "address": null,
  "date_of_birth_is_present": null,
  "email": null,
  "email_is_verified": null,
  "name": null,
  "personal_country_info": null,
  "phone": null,
  "job_title": null
}
```

#### Additional Representatives-Resp

##### Class Name

`AdditionalRepresentativesResp`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `representative_0` | [`AdditionalRepresentativeResp`](#additional-representative-resp) | Optional | - |
| `representative_1` | [`AdditionalRepresentativeResp`](#additional-representative-resp) | Optional | - |
| `representative_2` | [`AdditionalRepresentativeResp`](#additional-representative-resp) | Optional | - |
| `representative_3` | [`AdditionalRepresentativeResp`](#additional-representative-resp) | Optional | - |

##### Example (as JSON)

```json
{
  "representative_0": null,
  "representative_1": null,
  "representative_2": null,
  "representative_3": null
}
```

#### Recovery Failure Reason

##### Class Name

`RecoveryFailureReason`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `details` | [`Array<Detail6>`](#detail-6) | Optional | - |
| `reason_code` | [`ReasonCode6Enum`](#reason-code-6) | Optional | - |
| `reason_message` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "details": null,
  "reason_code": null,
  "reason_message": null
}
```

#### Dispute Reason

##### Class Name

`DisputeReason`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `reason_code` | [`ReasonCode7Enum`](#reason-code-7) | Required | The category of dispute reason |
| `reason_message` | `String` | Required | Dispute descriptive reason |
| `details` | [`Array<Detail7>`](#detail-7) | Optional | - |

##### Example (as JSON)

```json
{
  "reason_code": "INQUIRY",
  "reason_message": "reason_message2",
  "details": null
}
```

#### Payment Non Expanded

##### Class Name

`PaymentNonExpanded`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Required | - |
| `path` | `String` | Required | - |
| `resource` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "id": null,
  "path": null,
  "resource": "payments"
}
```

#### Pricing

The pricing strategy to collect payment fees for each merchant.

##### Class Name

`Pricing`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `currencies` | [`Currencies`](#currencies) | Optional | - |

##### Example (as JSON)

```json
{
  "currencies": null
}
```

#### Refund-Amounts

##### Class Name

`RefundAmounts`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `total_amount` | `Integer` | Required | **Constraints**: `>= 0` |
| `currency` | [`CurrencyEnum`](#currency) | Required | - |
| `fee_refund_amount` | `Integer` | Required | **Constraints**: `>= 0` |

##### Example (as JSON)

```json
{
  "total_amount": 112,
  "currency": "CAD",
  "fee_refund_amount": 240
}
```

#### Payout-Resp

##### Class Name

`PayoutResp`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `currencies` | [`Currencies1`](#currencies-1) | Optional | - |
| `default_currency` | [`CurrencyEnum`](#currency) | Optional | - |

##### Example (as JSON)

```json
{
  "currencies": null,
  "default_currency": null
}
```

#### Refund Failure Reason

##### Class Name

`RefundFailureReason`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `details` | [`Array<Detail8>`](#detail-8) | Optional | - |
| `reason_code` | [`ReasonCode8Enum`](#reason-code-8) | Optional | - |
| `reason_message` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "details": null,
  "reason_code": null,
  "reason_message": null
}
```

#### Owner-Legal Entities

##### Class Name

`OwnerLegalEntities`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Required | - |
| `path` | `String` | Required | - |
| `resource` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "id": null,
  "path": null,
  "resource": "legal_entities"
}
```

#### Incoming Payments-Resp

##### Class Name

`IncomingPaymentsResp`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `accepted_methods` | `Array<String>` | Required | **Constraints**: *Unique Items Required*, *Maximum Length*: `255` |
| `opted_out_methods` | [`OptedOutMethods`](#opted-out-methods) | Required | - |

##### Example (as JSON)

```json
{
  "accepted_methods": [
    "accepted_methods9"
  ],
  "opted_out_methods": {
    "countries": null
  }
}
```

#### Item-Nullable-Req

##### Class Name

`ItemNullableReq`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `account_id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `currency` | [`CurrencyEnum`](#currency) | Optional | - |
| `description` | `String` | Optional | **Constraints**: *Maximum Length*: `2047` |
| `photos` | `Array<String>` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |
| `price` | `Integer` | Optional | - |
| `product_code` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `product_details` | `Object` | Optional | - |
| `product_name` | `String` | Required | **Constraints**: *Maximum Length*: `255` |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |
| `reference_number` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `shipping_options` | `Array<String>` | Optional | **Constraints**: *Unique Items Required* |
| `terms` | [`Terms`](#terms) | Optional | - |
| `uri` | `String` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |
| `weight` | [`Weight`](#weight) | Optional | - |

##### Example (as JSON)

```json
{
  "account_id": "account_id2",
  "currency": null,
  "description": null,
  "photos": null,
  "price": null,
  "product_code": null,
  "product_details": null,
  "product_name": "product_name6",
  "rbits": null,
  "reference_number": null,
  "shipping_options": null,
  "terms": null,
  "uri": null,
  "weight": null
}
```

#### Refund-Resp

##### Class Name

`RefundResp`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `amounts` | [`RefundAmounts`](#refund-amounts) | Required | - |
| `create_time` | `Integer` | Required | - |
| `custom_data` | `Object` | Optional | - |
| `failure_reason` | [`RefundFailureReason`](#refund-failure-reason) | Required | - |
| `id` | `String` | Required | - |
| `order` | [`OrderNonExpanded`](#order-non-expanded) | Required | - |
| `owner` | [`OwnerIsAccount`](#owner-is-account) | Required | Owner structure to be used in any resource where an account is the owner |
| `path` | `String` | Required | - |
| `payment` | [`PaymentNonExpanded`](#payment-non-expanded) | Required | - |
| `payment_method` | [`PaymentMethodNonExpanded`](#payment-method-non-expanded) | Required | - |
| `pending_reasons` | [`Array<RefundPendingReason>`](#refund-pending-reason) | Optional | - |
| `refund_reason` | `String` | Required | - |
| `resource` | `String` | Required | - |
| `status` | `String` | Required | - |
| `txnr_app_fee_refund` | [`TransactionRecordNonExpanded`](#transaction-record-non-expanded) | Required | - |
| `txnr_merchant_refund` | [`TransactionRecordNonExpanded`](#transaction-record-non-expanded) | Required | - |
| `api_version` | `String` | Optional | - |
| `reference_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |

##### Example (as JSON)

```json
{
  "amounts": null,
  "create_time": null,
  "failure_reason": null,
  "id": null,
  "order": {
    "id": null,
    "path": null,
    "resource": "orders"
  },
  "owner": {
    "id": null,
    "path": null,
    "resource": "accounts"
  },
  "path": null,
  "payment": {
    "id": null,
    "path": null,
    "resource": "payments"
  },
  "payment_method": {
    "id": null,
    "path": null,
    "resource": "payment_methods"
  },
  "refund_reason": null,
  "resource": "refunds",
  "status": null,
  "txnr_app_fee_refund": {
    "id": null,
    "path": null,
    "resource": "transaction_records"
  },
  "txnr_merchant_refund": {
    "id": null,
    "path": null,
    "resource": "transaction_records"
  }
}
```

#### Recoveries

##### Class Name

`Recoveries`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `amount` | `Integer` | Required | - |
| `complete_time` | `Integer` | Optional | - |
| `create_time` | `Integer` | Required | - |
| `currency` | `String` | Required | - |
| `custom_data` | `Object` | Optional | - |
| `failure_reason` | [`RecoveryFailureReason`](#recovery-failure-reason) | Required | - |
| `id` | `String` | Required | - |
| `owner` | [`OwnerIsAccount`](#owner-is-account) | Required | Owner structure to be used in any resource where an account is the owner |
| `path` | `String` | Required | - |
| `payout_method` | [`PayoutMethodNonExpanded`](#payout-method-non-expanded) | Required | - |
| `pending_reasons` | [`Array<RecoveryPendingReason>`](#recovery-pending-reason) | Optional | - |
| `resource` | `String` | Required | - |
| `status` | [`StatusEnum`](#status) | Required | - |
| `txnr_failure` | [`TransactionRecordNonExpanded`](#transaction-record-non-expanded) | Required | - |
| `txnr_recovery` | [`TransactionRecordNonExpanded`](#transaction-record-non-expanded) | Required | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "amount": null,
  "create_time": null,
  "currency": null,
  "failure_reason": null,
  "id": null,
  "owner": {
    "id": null,
    "path": null,
    "resource": "accounts"
  },
  "path": null,
  "payout_method": {
    "id": null,
    "path": null,
    "resource": "payout_methods"
  },
  "resource": "recoveries",
  "status": null,
  "txnr_failure": {
    "id": null,
    "path": null,
    "resource": "transaction_records"
  },
  "txnr_recovery": {
    "id": null,
    "path": null,
    "resource": "transaction_records"
  }
}
```

#### Payout Method-Resp

##### Class Name

`PayoutMethodResp`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `create_time` | `Integer` | Optional | - |
| `custom_data` | `Object` | Optional | - |
| `id` | `String` | Required | - |
| `nickname` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `64` |
| `owner` | [`OwnerOfItems`](#owner-of-items) | Optional | - |
| `path` | `String` | Required | - |
| `payout_bank_ca` | [`PayoutBankCa`](#payout-bank-ca) | Optional | - |
| `payout_bank_gb` | [`PayoutBankGb`](#payout-bank-gb) | Optional | - |
| `payout_bank_us` | [`PayoutBankUs`](#payout-bank-us) | Optional | - |
| `resource` | `String` | Required | - |
| `type` | [`Type2Enum`](#type-2) | Optional | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "id": null,
  "path": null,
  "resource": "payout_methods"
}
```

#### Payout

##### Class Name

`Payout`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `amount` | `Integer` | Optional | - |
| `complete_time` | `Integer` | Optional | - |
| `create_time` | `Integer` | Optional | - |
| `currency` | [`CurrencyEnum`](#currency) | Optional | - |
| `custom_data` | `Object` | Optional | - |
| `failure_reason` | [`PayoutFailureReason`](#payout-failure-reason) | Optional | - |
| `id` | `String` | Required | - |
| `owner` | [`OwnerIsAccount`](#owner-is-account) | Required | Owner structure to be used in any resource where an account is the owner |
| `path` | `String` | Required | - |
| `payout_method` | [`PayoutMethodNonExpanded`](#payout-method-non-expanded) | Optional | - |
| `pending_reasons` | [`Array<PayoutPendingReason>`](#payout-pending-reason) | Optional | - |
| `resource` | `String` | Required | - |
| `status` | [`StatusEnum`](#status) | Optional | - |
| `txnr_failure` | [`TransactionRecordNonExpanded`](#transaction-record-non-expanded) | Optional | - |
| `txnr_payout` | [`TransactionRecordNonExpanded`](#transaction-record-non-expanded) | Optional | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "id": null,
  "owner": {
    "id": null,
    "path": null,
    "resource": "accounts"
  },
  "path": null,
  "resource": "payouts"
}
```

#### Payment Method-Resp

##### Class Name

`PaymentMethodResp`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `create_time` | `Integer` | Required | - |
| `credit_card` | [`CreditCard1`](#credit-card-1) | Optional | - |
| `custom_data` | `Object` | Optional | - |
| `id` | `String` | Required | - |
| `owner` | [`OwnerApplications`](#owner-applications) | Required | - |
| `path` | `String` | Required | - |
| `payment_bank_us` | [`PaymentBankUs`](#payment-bank-us) | Optional | - |
| `resource` | `String` | Required | - |
| `status` | [`Status2Enum`](#status-2) | Required | - |
| `type` | [`Type3Enum`](#type-3) | Required | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "create_time": null,
  "id": null,
  "owner": {
    "id": null,
    "resource": "applications"
  },
  "path": null,
  "resource": "payment_methods",
  "status": null,
  "type": null
}
```

#### Payments-V 3 0

##### Class Name

`PaymentsV30`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `amount` | `Integer` | Required | - |
| `amount_refunded` | `Integer` | Required | - |
| `amount_disputed` | `Integer` | Required | - |
| `auto_capture` | `Boolean` | Optional | - |
| `capture_at` | `Integer` | Optional | - |
| `create_time` | `Integer` | Required | - |
| `currency` | [`CurrencyEnum`](#currency) | Required | - |
| `custom_data` | `Object` | Optional | - |
| `failure_reason` | [`PaymentFailureReason`](#payment-failure-reason) | Optional | - |
| `fee_amount` | `Integer` | Optional | - |
| `id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `order` | [`OrderNonExpanded`](#order-non-expanded) | Optional | - |
| `owner` | [`OwnerIsAccount`](#owner-is-account) | Required | Owner structure to be used in any resource where an account is the owner |
| `path` | `String` | Required | - |
| `payment_method` | [`PaymentMethodNonExpanded`](#payment-method-non-expanded) | Required | - |
| `pending_reasons` | [`Array<PaymentPendingReason>`](#payment-pending-reason) | Optional | - |
| `resource` | `String` | Required | - |
| `status` | [`Status3Enum`](#status-3) | Required | - |
| `txnr_app_fee` | [`TransactionRecordNonExpanded`](#transaction-record-non-expanded) | Optional | - |
| `txnr_merchant` | [`TransactionRecordNonExpanded`](#transaction-record-non-expanded) | Optional | - |
| `initiated_by` | [`InitiatedByRespEnum`](#initiated-by-resp) | Required | - |
| `api_version` | `String` | Optional | - |
| `reference_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |

##### Example (as JSON)

```json
{
  "amount": null,
  "amount_refunded": null,
  "amount_disputed": null,
  "create_time": null,
  "currency": null,
  "id": null,
  "owner": {
    "id": null,
    "path": null,
    "resource": "accounts"
  },
  "path": null,
  "payment_method": {
    "id": null,
    "path": null,
    "resource": "payment_methods"
  },
  "resource": "payments",
  "status": null,
  "initiated_by": null
}
```

#### Payment Bank Us-Req

##### Class Name

`PaymentBankUsReq`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `account_holder` | [`HolderReq`](#holder-req) | Required | - |
| `account_number` | `String` | Required | **Constraints**: *Pattern*: `^[0-9]{3,17}$` |
| `account_type` | [`AccountTypeEnum`](#account-type) | Required | - |
| `routing_number` | `String` | Required | **Constraints**: *Pattern*: `^[0-9]{9}$` |

##### Example (as JSON)

```json
{
  "account_holder": {
    "address": {
      "city": null,
      "country": "SH",
      "line1": null,
      "line2": null,
      "postal_code": "postal_code8",
      "region": null
    },
    "email": null,
    "holder_name": "holder_name6",
    "phone": null
  },
  "account_number": "account_number0",
  "account_type": "checking",
  "routing_number": "routing_number4"
}
```

#### Legal Entity

##### Class Name

`LegalEntity`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `additional_representatives` | [`AdditionalRepresentativesReq`](#additional-representatives-req) | Optional | - |
| `address` | [`AddressLegalEntitiesNullable`](#address-legal-entities-nullable) | Optional | - |
| `controller` | [`ControllerReq`](#controller-req) | Optional | - |
| `country` | [`CountryCodeEnum`](#country-code) | Required | - |
| `custom_data` | `Object` | Optional | - |
| `description` | `String` | Optional | **Constraints**: *Maximum Length*: `1024` |
| `entity_country_info` | [`EntityCountryInfo`](#entity-country-info) | Optional | - |
| `entity_name` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `phone` | [`PhoneLegalEntitiesNullable`](#phone-legal-entities-nullable) | Optional | - |
| `primary_url` | `String` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |
| `terms_of_service` | [`TermsOfService`](#terms-of-service) | Optional | - |
| `token` | [`Token`](#token) | Optional | - |
| `reference_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |

##### Example (as JSON)

```json
{
  "additional_representatives": null,
  "address": null,
  "controller": null,
  "country": "HK",
  "custom_data": null,
  "description": null,
  "entity_country_info": null,
  "entity_name": null,
  "phone": null,
  "primary_url": null,
  "rbits": null,
  "terms_of_service": null,
  "token": null,
  "reference_id": null
}
```

#### Order-Resp

##### Class Name

`OrderResp`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `alternate_tax_amount` | `Integer` | Optional | - |
| `alternate_tax_id` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `buyer` | [`OwnerLegalEntitiesNullable`](#owner-legal-entities-nullable) | Optional | - |
| `create_time` | `Integer` | Optional | - |
| `currency` | [`CurrencyNullableEnum`](#currency-nullable) | Optional | - |
| `customer_reference_number` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `delivery_type` | [`DeliveryTypeEnum`](#delivery-type) | Optional | - |
| `discount_amount` | `Integer` | Optional | - |
| `duty_amount` | `Integer` | Optional | - |
| `freight_amount` | `Integer` | Optional | - |
| `grand_total_amount` | `Integer` | Optional | - |
| `id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `line_items` | [`Array<LineItem>`](#line-item) | Optional | - |
| `long_description` | `String` | Optional | **Constraints**: *Maximum Length*: `2047` |
| `notes` | `String` | Optional | **Constraints**: *Maximum Length*: `2047` |
| `owner` | [`OwnerOfItems`](#owner-of-items) | Optional | - |
| `path` | `String` | Optional | - |
| `reference_number` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `resource` | [`ResourceEnum`](#resource) | Optional | - |
| `service_address` | [`AddressNullable`](#address-nullable) | Optional | - |
| `ship_from_address` | [`AddressNullable`](#address-nullable) | Optional | - |
| `ship_to_address` | [`AddressNullable`](#address-nullable) | Optional | - |
| `shipping_status` | [`ShippingStatus`](#shipping-status) | Optional | - |
| `short_description` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `state` | [`StateEnum`](#state) | Optional | - |
| `status` | [`Status4Enum`](#status-4) | Optional | - |
| `tax_amount` | `Integer` | Optional | - |
| `terms` | [`TermsNullable`](#terms-nullable) | Optional | - |
| `type` | [`Type4Enum`](#type-4) | Optional | - |
| `vat_amount` | `Integer` | Optional | - |
| `vat_rate` | `Float` | Optional | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "alternate_tax_amount": null,
  "alternate_tax_id": null,
  "buyer": null,
  "create_time": null,
  "currency": null,
  "customer_reference_number": null,
  "delivery_type": null,
  "discount_amount": null,
  "duty_amount": null,
  "freight_amount": null,
  "grand_total_amount": null,
  "id": null,
  "line_items": null,
  "long_description": null,
  "notes": null,
  "owner": null,
  "path": null,
  "reference_number": null,
  "resource": null,
  "service_address": null,
  "ship_from_address": null,
  "ship_to_address": null,
  "shipping_status": null,
  "short_description": null,
  "state": null,
  "status": null,
  "tax_amount": null,
  "terms": null,
  "type": null,
  "vat_amount": null,
  "vat_rate": null,
  "api_version": null
}
```

#### Address-Terminals-Req

##### Class Name

`AddressTerminalsReq`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `city` | `String` | Required | **Constraints**: *Maximum Length*: `30` |
| `country` | [`CountryCodeEnum`](#country-code) | Required | - |
| `line_1` | `String` | Required | **Constraints**: *Maximum Length*: `60` |
| `line_2` | `String` | Optional | **Constraints**: *Maximum Length*: `60` |
| `postal_code` | `String` | Required | **Constraints**: *Maximum Length*: `14` |
| `region` | `String` | Required | **Constraints**: *Maximum Length*: `30` |

##### Example (as JSON)

```json
{
  "city": "city0",
  "country": "HK",
  "line1": "line12",
  "line2": null,
  "postal_code": "postal_code2",
  "region": "region6"
}
```

#### Contactless Payments-Req

The request schema for modifying contactless payments configuration settings.

##### Class Name

`ContactlessPaymentsReq`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `enabled` | `Boolean` | Required | Determines if contactless payments are enabled. |
| `credit_debit_preference` | [`CreditDebitPreferenceEnum`](#credit-debit-preference) | Optional | Determines how the terminal should prefer to charge contactless cards. "credit" is the EMV default, selecting the highest priority application in the card (which is the credit application). Debit preferred attempts to select debit network application on the card first. |

##### Example (as JSON)

```json
{
  "enabled": false,
  "credit_debit_preference": null
}
```

#### Terminal-Resp

##### Class Name

`TerminalResp`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `resource` | `String` | Required | - |
| `path` | `String` | Required | - |
| `owner` | [`OwnerIsAccount`](#owner-is-account) | Required | Owner structure to be used in any resource where an account is the owner |
| `api_version` | `String` | Required | - |
| `status` | [`TerminalsStatusEnum`](#terminals-status) | Required | The status of the terminal. Active means the terminal is able to accept authorizations. Inactive means the terminal has been deactivated and is unable to accept payments (this can occur for risk and fraud related reasons). |
| `serial_number` | `String` | Required | The serial number of the terminal. |
| `model` | [`ModelEnum`](#model) | Required | - |
| `reference_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `last_call_home` | `Integer` | Required | The epoch timestamp of the last time this terminal called home. |
| `terminal_application_version` | `String` | Required | The version of the application running on the terminal. |
| `terminal_configuration` | [`TerminalConfiguration`](#terminal-configuration) | Required | - |
| `gateway_id` | `String` | Optional | Unique identifier of the terminal used by our payment gateway<br>**Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |

##### Example (as JSON)

```json
{
  "id": null,
  "resource": "terminals",
  "path": null,
  "owner": {
    "id": null,
    "path": null,
    "resource": "accounts"
  },
  "api_version": null,
  "status": null,
  "serial_number": "FA00332-1000138",
  "model": null,
  "last_call_home": null,
  "terminal_application_version": null,
  "terminal_configuration": {
    "address": null,
    "currency": null,
    "supported_card_brands": [
      "visa",
      "american_express",
      "discover",
      "mastercard"
    ],
    "credit_debit_preference": null,
    "timezone": null,
    "tip": {
      "mode": "prompt_on_terminal",
      "terminal_display": {
        "amount_guide_type": "percentage_guide",
        "percentage_guide": {
          "show_amount": false,
          "percentage_low": 15,
          "percentage_medium": 18,
          "percentage_high": 20
        }
      }
    },
    "signature_required": null,
    "contactless_payments": null,
    "quick_chip": null,
    "deferred_authorization": {
      "enabled": null,
      "international_enabled": null,
      "max_transaction_count": 20,
      "max_total_amount": 250000,
      "max_transaction_amount": 12500,
      "supported_card_entry_modes": [
        "chip",
        "contactless"
      ]
    }
  }
}
```

#### Legal Entity-Resp

##### Class Name

`LegalEntityResp`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `additional_representatives` | [`AdditionalRepresentativesResp`](#additional-representatives-resp) | Optional | - |
| `address` | [`AddressLegalEntitiesNullable`](#address-legal-entities-nullable) | Optional | - |
| `controller` | [`ControllerResp`](#controller-resp) | Optional | - |
| `country` | [`CountryCodeEnum`](#country-code) | Optional | - |
| `create_time` | `Integer` | Required | - |
| `custom_data` | `Object` | Optional | - |
| `description` | `String` | Optional | **Constraints**: *Maximum Length*: `1024` |
| `entity_country_info` | [`EntityCountryInfo`](#entity-country-info) | Optional | - |
| `entity_name` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `owner` | [`OwnerApplications`](#owner-applications) | Required | - |
| `path` | `String` | Required | - |
| `phone` | [`PhoneLegalEntitiesNullable`](#phone-legal-entities-nullable) | Optional | - |
| `primary_url` | `String` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |
| `resource` | `String` | Required | - |
| `terms_of_service` | [`TermsOfService`](#terms-of-service) | Optional | - |
| `api_version` | `String` | Required | - |
| `reference_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |

##### Example (as JSON)

```json
{
  "create_time": null,
  "id": null,
  "owner": {
    "id": null,
    "resource": "applications"
  },
  "path": null,
  "resource": "legal_entities",
  "api_version": null
}
```

#### Item-Resp

##### Class Name

`ItemResp`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `create_time` | `Integer` | Required | - |
| `currency` | [`CurrencyNullableEnum`](#currency-nullable) | Optional | - |
| `description` | `String` | Optional | **Constraints**: *Maximum Length*: `2047` |
| `id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `owner` | [`OwnerOfItems`](#owner-of-items) | Required | - |
| `path` | `String` | Required | - |
| `photos` | `Array<String>` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |
| `price` | `Integer` | Optional | - |
| `product_code` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `product_details` | `Object` | Optional | - |
| `product_name` | `String` | Required | **Constraints**: *Maximum Length*: `255` |
| `reference_number` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `resource` | `String` | Required | - |
| `shipping_options` | `Array<String>` | Optional | **Constraints**: *Unique Items Required* |
| `state` | [`StateEnum`](#state) | Required | - |
| `terms` | [`TermsNullable`](#terms-nullable) | Optional | - |
| `uri` | `String` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |
| `weight` | [`Weight`](#weight) | Optional | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "create_time": null,
  "id": null,
  "owner": {
    "id": null,
    "path": null,
    "resource": "accounts"
  },
  "path": null,
  "product_name": null,
  "resource": "items",
  "state": null
}
```

#### Disputes

##### Class Name

`Disputes`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `amount` | `Integer` | Required | - |
| `create_time` | `Integer` | Required | - |
| `currency` | `String` | Required | - |
| `custom_data` | `Object` | Optional | - |
| `documentation` | [`Documentation`](#documentation) | Required | - |
| `fee` | `Integer` | Required | - |
| `id` | `String` | Required | - |
| `owner` | [`OwnerIsAccount`](#owner-is-account) | Required | Owner structure to be used in any resource where an account is the owner |
| `path` | `String` | Required | - |
| `payment` | [`PaymentNonExpanded`](#payment-non-expanded) | Required | - |
| `card_brand` | [`CardBrandEnum`](#card-brand) | Required | - |
| `reason` | [`DisputeReason`](#dispute-reason) | Required | - |
| `resolution` | [`Resolution`](#resolution) | Required | - |
| `resource` | `String` | Required | - |
| `status` | [`Status5Enum`](#status-5) | Required | - |
| `txnr_chargeback_app_fees` | [`TransactionRecordNonExpanded`](#transaction-record-non-expanded) | Required | - |
| `txnr_chargeback_merchant` | [`TransactionRecordNonExpanded`](#transaction-record-non-expanded) | Required | - |
| `txnr_chargeback_reversal_app_fee` | [`TransactionRecordNonExpanded`](#transaction-record-non-expanded) | Required | - |
| `txnr_chargeback_reversal_merchant` | [`TransactionRecordNonExpanded`](#transaction-record-non-expanded) | Required | - |
| `txnr_merchant_chargeback_fee` | [`TransactionRecordNonExpanded`](#transaction-record-non-expanded) | Required | - |
| `type` | [`Type6Enum`](#type-6) | Required | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "amount": null,
  "create_time": null,
  "currency": null,
  "documentation": null,
  "fee": null,
  "id": null,
  "owner": {
    "id": null,
    "path": null,
    "resource": "accounts"
  },
  "path": null,
  "payment": {
    "id": null,
    "path": null,
    "resource": "payments"
  },
  "card_brand": null,
  "reason": null,
  "resolution": null,
  "resource": "disputes",
  "status": null,
  "txnr_chargeback_app_fees": {
    "id": null,
    "path": null,
    "resource": "transaction_records"
  },
  "txnr_chargeback_merchant": {
    "id": null,
    "path": null,
    "resource": "transaction_records"
  },
  "txnr_chargeback_reversal_app_fee": {
    "id": null,
    "path": null,
    "resource": "transaction_records"
  },
  "txnr_chargeback_reversal_merchant": {
    "id": null,
    "path": null,
    "resource": "transaction_records"
  },
  "txnr_merchant_chargeback_fee": {
    "id": null,
    "path": null,
    "resource": "transaction_records"
  },
  "type": null
}
```

#### Transactions Summary

##### Class Name

`TransactionsSummary`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `day` | `Integer` | Required | **Constraints**: `>= 1`, `<= 31` |
| `month` | `Integer` | Required | **Constraints**: `>= 1`, `<= 12` |
| `year` | `Integer` | Required | **Constraints**: `>= 0` |
| `currency` | [`CurrencyEnum`](#currency) | Required | - |
| `total_amount` | `Integer` | Required | **Constraints**: `>= 0` |
| `item_count` | `Integer` | Required | **Constraints**: `>= 0` |
| `summaries` | [`Array<TransactionsSummarySummaries>`](#transactions-summary-summaries) | Required | **Constraints**: *Unique Items Required* |

##### Example (as JSON)

```json
{
  "day": 60,
  "month": 232,
  "year": 248,
  "currency": "CAD",
  "total_amount": 112,
  "item_count": 38,
  "summaries": [
    {
      "fee_type": "DISCOVER",
      "currency": "USD",
      "total_amount": 138,
      "item_count": 12
    },
    {
      "fee_type": "ECHECK",
      "currency": "CAD",
      "total_amount": 139,
      "item_count": 11
    },
    {
      "fee_type": "CHARGEBACK",
      "currency": "GBP",
      "total_amount": 140,
      "item_count": 10
    }
  ]
}
```

#### Interchange Fee

##### Class Name

`InterchangeFee`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `fee_type` | [`FeeTypeEnum`](#fee-type) | Required | - |
| `fee_category` | `String` | Required | Transaction fee category. |
| `currency` | [`CurrencyEnum`](#currency) | Required | - |
| `total_amount` | `Integer` | Required | Total transaction amount in a billing statement for the given fee type and fee category. |
| `item_count` | `Integer` | Required | Number of transactions in a billing statement for the given fee type and fee category. |
| `variable_fee_bps` | `Integer` | Optional | Basis points to calculate variable fee amount. |
| `fixed_fee_amount` | `Integer` | Optional | Fixed fee amount. |
| `variable_fee_markup_bps` | `Integer` | Optional | Basis points to calculate variable markup fee amount. |
| `fixed_fee_markup_amount` | `Integer` | Optional | Fixed fee markup amount. |
| `total_interchange_fee` | `Integer` | Optional | Total interchange fee amount. |
| `total_markup` | `Integer` | Optional | Total markup fee amount. |
| `total_fees` | `Integer` | Required | Total fee amount, sum of interchange fee amount, markup fee amount, and fee amount for other types. |

##### Example (as JSON)

```json
{
  "fee_type": "ECHECK",
  "fee_category": "fee_category8",
  "currency": "CAD",
  "total_amount": 112,
  "item_count": 38,
  "variable_fee_bps": null,
  "fixed_fee_amount": null,
  "variable_fee_markup_bps": null,
  "fixed_fee_markup_amount": null,
  "total_interchange_fee": null,
  "total_markup": null,
  "total_fees": 10
}
```

#### Billing Statement

##### Class Name

`BillingStatement`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Required | - |
| `resource` | `String` | Required | - |
| `path` | `String` | Required | - |
| `owner` | [`OwnerIsAccount`](#owner-is-account) | Required | Owner structure to be used in any resource where an account is the owner |
| `create_time` | `Integer` | Required | - |
| `amount` | `Integer` | Required | - |
| `currency` | [`CurrencyEnum`](#currency) | Required | - |
| `month` | `Integer` | Required | **Constraints**: `>= 1`, `<= 12` |
| `year` | `Integer` | Required | **Constraints**: `>= 0` |
| `api_version` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "id": null,
  "resource": "billing_statements",
  "path": null,
  "owner": {
    "id": null,
    "path": null,
    "resource": "accounts"
  },
  "create_time": null,
  "amount": null,
  "currency": null,
  "month": null,
  "year": null,
  "api_version": null
}
```

#### Adjustments

##### Class Name

`Adjustments`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `amount` | `Integer` | Required | - |
| `create_time` | `Integer` | Required | - |
| `currency` | `String` | Required | - |
| `custom_data` | `Object` | Optional | - |
| `id` | `String` | Required | - |
| `reason` | [`Reason`](#reason) | Required | - |
| `owner` | [`OwnerIsAccount`](#owner-is-account) | Required | Owner structure to be used in any resource where an account is the owner |
| `path` | `String` | Required | - |
| `resource` | `String` | Required | - |
| `txnr_adjustment` | [`TransactionRecordNonExpanded`](#transaction-record-non-expanded) | Required | - |
| `type` | [`Type7Enum`](#type-7) | Required | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "amount": null,
  "create_time": null,
  "currency": null,
  "id": null,
  "reason": null,
  "owner": {
    "id": null,
    "path": null,
    "resource": "accounts"
  },
  "path": null,
  "resource": "adjustments",
  "txnr_adjustment": {
    "id": null,
    "path": null,
    "resource": "transaction_records"
  },
  "type": null
}
```

#### Account-Resp

##### Class Name

`AccountResp`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `balances` | [`Balances`](#balances) | Optional | - |
| `beneficiary` | [`OwnerLegalEntities`](#owner-legal-entities) | Optional | - |
| `create_time` | `Integer` | Required | - |
| `custom_data` | `Object` | Optional | - |
| `description` | `String` | Optional | **Constraints**: *Maximum Length*: `65535` |
| `enhanced_review` | `String` | Optional | - |
| `id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `incoming_payments` | [`IncomingPaymentsResp`](#incoming-payments-resp) | Optional | - |
| `industry` | [`Industry`](#industry) | Optional | - |
| `name` | `String` | Optional | A non-empty string that does not contain the word wepay.<br>**Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255`, *Pattern*: `^((?![Ww][Ee][Pp][Aa][Yy]).)*$` |
| `owner` | [`OwnerLegalEntities`](#owner-legal-entities) | Required | - |
| `path` | `String` | Required | - |
| `payout` | [`PayoutResp`](#payout-resp) | Optional | - |
| `pricing` | [`Pricing`](#pricing) | Required | The pricing strategy to collect payment fees for each merchant. |
| `reference_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `resource` | `String` | Required | - |
| `statement_description` | `String` | Optional | A non-empty ASCII printable string does not contain the word wepay that appears on the merchants’ customers’ credit card statement.<br>**Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255`, *Pattern*: `^((?![Ww][Ee][Pp][Aa][Yy])[ -~])*$` |
| `api_version` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "create_time": null,
  "id": null,
  "owner": {
    "id": null,
    "path": null,
    "resource": "legal_entities"
  },
  "path": null,
  "pricing": null,
  "resource": "accounts",
  "api_version": null
}
```

#### Transaction Record

##### Class Name

`TransactionRecord`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `create_time` | `Integer` | Required | - |
| `currency` | [`CurrencyEnum`](#currency) | Optional | - |
| `fee_amount` | `Integer` | Optional | - |
| `gross_amount` | `Integer` | Optional | - |
| `id` | `String` | Required | - |
| `net_amount` | `Integer` | Optional | - |
| `owner` | [`Owner3`](#owner-3) | Optional | - |
| `path` | `String` | Required | - |
| `resource` | `String` | Required | - |
| `type` | [`Type8Enum`](#type-8) | Optional | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "create_time": null,
  "id": null,
  "path": null,
  "resource": "transaction_records"
}
```

#### Owner-Accounts

##### Class Name

`OwnerAccounts`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Required | - |
| `path` | `String` | Required | - |
| `resource` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "id": null,
  "path": null,
  "resource": "accounts"
}
```

#### Incoming Payments-Req

##### Class Name

`IncomingPaymentsReq`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `opted_out_methods` | [`OptedOutMethods`](#opted-out-methods) | Optional | - |

##### Example (as JSON)

```json
{
  "opted_out_methods": null
}
```

#### Capture-Amounts

##### Class Name

`CaptureAmounts`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `amount` | `Integer` | Required | **Constraints**: `>= 0` |
| `currency` | [`CurrencyEnum`](#currency) | Required | - |
| `fee_amount` | `Integer` | Required | **Constraints**: `>= 0` |

##### Example (as JSON)

```json
{
  "amount": 46,
  "currency": "CAD",
  "fee_amount": 54
}
```

#### Payment Method for Payments

##### Class Name

`PaymentMethodForPayments`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `credit_card` | [`CreditCard2`](#credit-card-2) | Optional | - |
| `custom_data` | `Object` | Optional | - |
| `payment_bank_us` | [`PaymentBankUsReq`](#payment-bank-us-req) | Optional | - |
| `payment_method_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `token` | [`Token`](#token) | Optional | - |
| `encoded_payment_method` | `String` | Optional | Encoded payment data. Currently is used for POS payment tokens but in future may be used for other types of encoded payment information<br>**Constraints**: *Minimum Length*: `1`, *Maximum Length*: `2048` |
| `type` | [`Type9Enum`](#type-9) | Required | - |

##### Example (as JSON)

```json
{
  "credit_card": null,
  "custom_data": null,
  "payment_bank_us": null,
  "payment_method_id": null,
  "token": null,
  "encoded_payment_method": null,
  "type": "payment_method_id"
}
```

#### Payment Method-Req

##### Class Name

`PaymentMethodReq`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `credit_card` | [`CreditCard2`](#credit-card-2) | Optional | - |
| `custom_data` | `Object` | Optional | - |
| `payment_bank_us` | [`PaymentBankUsReq`](#payment-bank-us-req) | Optional | - |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |
| `token` | [`Token`](#token) | Optional | - |
| `type` | [`Type3Enum`](#type-3) | Required | - |

##### Example (as JSON)

```json
{
  "credit_card": null,
  "custom_data": null,
  "payment_bank_us": null,
  "rbits": null,
  "token": null,
  "type": "credit_card"
}
```

#### Payout-Req

##### Class Name

`PayoutReq`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `currencies` | [`Currencies3`](#currencies-3) | Optional | - |
| `default_currency` | [`CurrencyEnum`](#currency) | Optional | - |

##### Example (as JSON)

```json
{
  "currencies": null,
  "default_currency": null
}
```

#### Payout Method-Req

##### Class Name

`PayoutMethodReq`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `custom_data` | `Object` | Optional | - |
| `legal_entity_id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `nickname` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `64` |
| `payout_bank_ca` | [`PayoutBankCa1`](#payout-bank-ca-1) | Optional | - |
| `payout_bank_gb` | [`PayoutBankGb1`](#payout-bank-gb-1) | Optional | - |
| `payout_bank_us` | [`PayoutBankUs1`](#payout-bank-us-1) | Optional | - |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |
| `token` | [`Token`](#token) | Optional | - |
| `type` | [`Type2Enum`](#type-2) | Required | - |

##### Example (as JSON)

```json
{
  "custom_data": null,
  "legal_entity_id": "legal_entity_id8",
  "nickname": "nickname6",
  "payout_bank_ca": null,
  "payout_bank_gb": null,
  "payout_bank_us": null,
  "rbits": null,
  "token": null,
  "type": "payout_bank_us"
}
```

#### Capabilities-Resp

##### Class Name

`CapabilitiesResp`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `owner` | [`OwnerAccounts`](#owner-accounts) | Required | - |
| `path` | `String` | Required | - |
| `payments` | [`Payments`](#payments) | Required | - |
| `payouts` | [`Payouts`](#payouts) | Required | - |
| `resource` | `String` | Required | - |
| `api_version` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "owner": {
    "id": null,
    "path": null,
    "resource": "accounts"
  },
  "path": null,
  "payments": null,
  "payouts": null,
  "resource": "capabilities",
  "api_version": null
}
```

#### Item-Req

##### Class Name

`ItemReq`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `account_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `currency` | [`CurrencyEnum`](#currency) | Optional | - |
| `description` | `String` | Optional | **Constraints**: *Maximum Length*: `2047` |
| `photos` | `Array<String>` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |
| `price` | `Integer` | Optional | - |
| `product_code` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `product_details` | `Object` | Optional | - |
| `product_name` | `String` | Required | **Constraints**: *Maximum Length*: `255` |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |
| `reference_number` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `shipping_options` | `Array<String>` | Optional | **Constraints**: *Unique Items Required* |
| `terms` | [`Terms`](#terms) | Optional | - |
| `uri` | `String` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |
| `weight` | [`Weight`](#weight) | Optional | - |

##### Example (as JSON)

```json
{
  "account_id": null,
  "currency": null,
  "description": null,
  "photos": null,
  "price": null,
  "product_code": null,
  "product_details": null,
  "product_name": "product_name6",
  "rbits": null,
  "reference_number": null,
  "shipping_options": null,
  "terms": null,
  "uri": null,
  "weight": null
}
```

#### Refund-Req

##### Class Name

`RefundReq`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `amounts` | [`RefundAmounts`](#refund-amounts) | Optional | - |
| `custom_data` | `Object` | Optional | - |
| `order_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `payment_id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |
| `refund_reason` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `65535` |
| `reference_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |

##### Example (as JSON)

```json
{
  "amounts": null,
  "custom_data": null,
  "order_id": null,
  "payment_id": "payment_id0",
  "rbits": null,
  "refund_reason": "refund_reason8",
  "reference_id": null
}
```

#### Order-Req

##### Class Name

`OrderReq`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `account_id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `alternate_tax_amount` | `Integer` | Optional | - |
| `alternate_tax_id` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `buyer` | [`Buyer`](#buyer) | Optional | - |
| `currency` | [`CurrencyEnum`](#currency) | Optional | - |
| `customer_reference_number` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `delivery_type` | [`DeliveryTypeEnum`](#delivery-type) | Optional | - |
| `discount_amount` | `Integer` | Optional | - |
| `duty_amount` | `Integer` | Optional | - |
| `freight_amount` | `Integer` | Optional | - |
| `grand_total_amount` | `Integer` | Optional | - |
| `line_items` | [`Array<LineItem1>`](#line-item-1) | Optional | - |
| `long_description` | `String` | Optional | **Constraints**: *Maximum Length*: `2047` |
| `notes` | `String` | Optional | **Constraints**: *Maximum Length*: `2047` |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |
| `reference_number` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `service_address` | [`AddressPaymentsReq`](#address-payments-req) | Optional | - |
| `ship_from_address` | [`AddressPaymentsReq`](#address-payments-req) | Optional | - |
| `ship_to_address` | [`AddressPaymentsReq`](#address-payments-req) | Optional | - |
| `shipping_status` | [`ShippingStatus1`](#shipping-status-1) | Optional | - |
| `short_description` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `status` | [`Status4Enum`](#status-4) | Optional | - |
| `tax_amount` | `Integer` | Optional | - |
| `terms` | [`Terms`](#terms) | Optional | - |
| `type` | [`Type4Enum`](#type-4) | Required | - |
| `vat_amount` | `Integer` | Optional | - |
| `vat_rate` | `Float` | Optional | - |

##### Example (as JSON)

```json
{
  "account_id": "account_id2",
  "alternate_tax_amount": null,
  "alternate_tax_id": null,
  "buyer": null,
  "currency": null,
  "customer_reference_number": null,
  "delivery_type": null,
  "discount_amount": null,
  "duty_amount": null,
  "freight_amount": null,
  "grand_total_amount": null,
  "line_items": null,
  "long_description": null,
  "notes": null,
  "rbits": null,
  "reference_number": null,
  "service_address": null,
  "ship_from_address": null,
  "ship_to_address": null,
  "shipping_status": null,
  "short_description": null,
  "status": null,
  "tax_amount": null,
  "terms": null,
  "type": "goods",
  "vat_amount": null,
  "vat_rate": null
}
```

#### Accounts Capabilities Request

##### Class Name

`AccountsCapabilitiesRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `payments` | [`Payments1`](#payments-1) | Optional | - |
| `payouts` | [`Payouts1`](#payouts-1) | Optional | - |

##### Example (as JSON)

```json
{
  "payments": null,
  "payouts": null
}
```

#### Accounts Request

##### Class Name

`AccountsRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `beneficiary_legal_entity_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `custom_data` | `Object` | Optional | - |
| `description` | `String` | Optional | **Constraints**: *Maximum Length*: `65535` |
| `incoming_payments` | [`IncomingPaymentsReq`](#incoming-payments-req) | Optional | - |
| `industry` | [`Industry`](#industry) | Optional | - |
| `legal_entity_id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `name` | `String` | Optional | A non-empty string that does not contain the word wepay.<br>**Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255`, *Pattern*: `^((?![Ww][Ee][Pp][Aa][Yy]).)*$` |
| `payout` | [`PayoutReq`](#payout-req) | Optional | - |
| `pricing` | [`Pricing`](#pricing) | Optional | The pricing strategy to collect payment fees for each merchant. |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |
| `reference_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `statement_description` | `String` | Optional | A non-empty ASCII printable string does not contain the word wepay that appears on the merchants’ customers’ credit card statement.<br>**Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255`, *Pattern*: `^((?![Ww][Ee][Pp][Aa][Yy])[ -~])*$` |

##### Example (as JSON)

```json
{
  "beneficiary_legal_entity_id": null,
  "custom_data": null,
  "description": null,
  "incoming_payments": null,
  "industry": null,
  "legal_entity_id": "legal_entity_id8",
  "name": null,
  "payout": null,
  "pricing": null,
  "rbits": null,
  "reference_id": null,
  "statement_description": null
}
```

#### Accounts Request 1

##### Class Name

`AccountsRequest1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `beneficiary_legal_entity_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `custom_data` | `Object` | Optional | - |
| `description` | `String` | Optional | **Constraints**: *Maximum Length*: `65535` |
| `incoming_payments` | [`IncomingPaymentsReq`](#incoming-payments-req) | Optional | - |
| `industry` | [`Industry`](#industry) | Optional | - |
| `name` | `String` | Optional | A non-empty string that does not contain the word wepay.<br>**Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255`, *Pattern*: `^((?![Ww][Ee][Pp][Aa][Yy]).)*$` |
| `payout` | [`PayoutReq`](#payout-req) | Optional | - |
| `pricing` | [`Pricing`](#pricing) | Optional | The pricing strategy to collect payment fees for each merchant. |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |
| `reference_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `statement_description` | `String` | Optional | A non-empty ASCII printable string does not contain the word wepay that appears on the merchants’ customers’ credit card statement.<br>**Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255`, *Pattern*: `^((?![Ww][Ee][Pp][Aa][Yy])[ -~])*$` |

##### Example (as JSON)

```json
{
  "beneficiary_legal_entity_id": null,
  "custom_data": null,
  "description": null,
  "incoming_payments": null,
  "industry": null,
  "name": null,
  "payout": null,
  "pricing": null,
  "rbits": null,
  "reference_id": null,
  "statement_description": null
}
```

#### Accounts Response

##### Class Name

`AccountsResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<AccountResp>`](#account-resp) | Required | **Constraints**: *Unique Items Required* |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "results": {
    "create_time": null,
    "id": null,
    "owner": {
      "id": null,
      "path": null,
      "resource": "legal_entities"
    },
    "path": null,
    "pricing": null,
    "resource": "accounts",
    "api_version": null
  }
}
```

#### Additional Representatives

##### Class Name

`AdditionalRepresentatives`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `representative_0` | [`Representative0`](#representative-0) | Optional | - |
| `representative_1` | [`Representative0`](#representative-0) | Optional | - |
| `representative_2` | [`Representative0`](#representative-0) | Optional | - |
| `representative_3` | [`Representative0`](#representative-0) | Optional | - |

##### Example (as JSON)

```json
{
  "representative_0": null,
  "representative_1": null,
  "representative_2": null,
  "representative_3": null
}
```

#### Additional Representatives 1

##### Class Name

`AdditionalRepresentatives1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `representative_0` | [`Representative01`](#representative-01) | Optional | - |
| `representative_1` | [`Representative01`](#representative-01) | Optional | - |
| `representative_2` | [`Representative01`](#representative-01) | Optional | - |
| `representative_3` | [`Representative01`](#representative-01) | Optional | - |

##### Example (as JSON)

```json
{
  "representative_0": null,
  "representative_1": null,
  "representative_2": null,
  "representative_3": null
}
```

#### Adjustments Request

##### Class Name

`AdjustmentsRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `custom_data` | `Object` | Optional | - |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |

##### Example (as JSON)

```json
{
  "custom_data": null,
  "rbits": null
}
```

#### Adjustments Response

##### Class Name

`AdjustmentsResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<Adjustments>`](#adjustments) | Required | **Constraints**: *Unique Items Required* |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "results": {
    "amount": null,
    "create_time": null,
    "currency": null,
    "id": null,
    "reason": null,
    "owner": {
      "id": null,
      "path": null,
      "resource": "accounts"
    },
    "path": null,
    "resource": "adjustments",
    "txnr_adjustment": {
      "id": null,
      "path": null,
      "resource": "transaction_records"
    },
    "type": null
  }
}
```

#### Application Block

##### Class Name

`ApplicationBlock`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `reason` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |

##### Example (as JSON)

```json
{
  "reason": null
}
```

#### Application Block 4

##### Class Name

`ApplicationBlock4`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `is_blocked` | `Boolean` | Required | - |
| `reason` | `String` | Required | **Constraints**: *Maximum Length*: `255` |

##### Example (as JSON)

```json
{
  "is_blocked": false,
  "reason": "reason4"
}
```

#### Associated Phone

##### Class Name

`AssociatedPhone`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `country_code` | `String` | Optional | **Constraints**: *Pattern*: `^\+?[0-9]{1,3}$` |
| `phone_number` | `String` | Optional | **Constraints**: *Pattern*: `^[0-9]{1,14}$` |

##### Example (as JSON)

```json
{
  "country_code": null,
  "phone_number": null
}
```

#### Associated Resource

##### Class Name

`AssociatedResource`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `resource` | [`ResourceTypesRbitEnum`](#resource-types-rbit) | Required | - |

##### Example (as JSON)

```json
{
  "id": "id0",
  "resource": "payments"
}
```

#### Balances

##### Class Name

`Balances`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `currencies` | [`Currencies2`](#currencies-2) | Optional | - |

##### Example (as JSON)

```json
{
  "currencies": null
}
```

#### Billing Statements Interchange Fees Response

##### Class Name

`BillingStatementsInterchangeFeesResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<InterchangeFee>`](#interchange-fee) | Required | **Constraints**: *Unique Items Required* |
| `api_version` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "next": null,
  "previous": null,
  "results": [
    {
      "fee_type": "ECHECK",
      "fee_category": "fee_category5",
      "currency": "CAD",
      "total_amount": 29,
      "item_count": 121,
      "variable_fee_bps": null,
      "fixed_fee_amount": null,
      "variable_fee_markup_bps": null,
      "fixed_fee_markup_amount": null,
      "total_interchange_fee": null,
      "total_markup": null,
      "total_fees": 183
    }
  ],
  "api_version": "api_version8"
}
```

#### Billing Statements Response

##### Class Name

`BillingStatementsResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<BillingStatement>`](#billing-statement) | Required | **Constraints**: *Unique Items Required* |
| `api_version` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "results": {
    "id": null,
    "resource": "billing_statements",
    "path": null,
    "owner": {
      "id": null,
      "path": null,
      "resource": "accounts"
    },
    "create_time": null,
    "amount": null,
    "currency": null,
    "month": null,
    "year": null,
    "api_version": null
  },
  "api_version": null
}
```

#### Billing Statements Transactions Summary Response

##### Class Name

`BillingStatementsTransactionsSummaryResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<TransactionsSummary>`](#transactions-summary) | Required | **Constraints**: *Unique Items Required* |
| `api_version` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "next": null,
  "previous": null,
  "results": [
    {
      "day": 143,
      "month": 149,
      "year": 75,
      "currency": "CAD",
      "total_amount": 29,
      "item_count": 121,
      "summaries": [
        {
          "fee_type": "DISCOVER",
          "currency": "USD",
          "total_amount": 221,
          "item_count": 185
        },
        {
          "fee_type": "ECHECK",
          "currency": "CAD",
          "total_amount": 222,
          "item_count": 184
        },
        {
          "fee_type": "CHARGEBACK",
          "currency": "GBP",
          "total_amount": 223,
          "item_count": 183
        }
      ]
    }
  ],
  "api_version": "api_version8"
}
```

#### Buyer

##### Class Name

`Buyer`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `legal_entity` | [`LegalEntity`](#legal-entity) | Optional | - |
| `legal_entity_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `type` | [`Type12Enum`](#type-12) | Required | - |

##### Example (as JSON)

```json
{
  "legal_entity": null,
  "legal_entity_id": null,
  "type": "legal_entity"
}
```

#### CA

##### Class Name

`CA`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `social_insurance_number` | `String` | Optional | **Constraints**: *Pattern*: `^\d{3}[ -]?\d{3}[ -]?\d{3}$` |

##### Example (as JSON)

```json
{
  "social_insurance_number": null
}
```

#### CA1

##### Class Name

`CA1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `social_insurance_number_is_present` | `Boolean` | Optional | - |

##### Example (as JSON)

```json
{
  "social_insurance_number_is_present": null
}
```

#### CA4

##### Class Name

`CA4`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `business_number` | `String` | Optional | **Constraints**: *Pattern*: `^\d{9}$` |
| `legal_form` | [`LegalFormEnum`](#legal-form) | Optional | - |

##### Example (as JSON)

```json
{
  "business_number": null,
  "legal_form": null
}
```

#### CAD

##### Class Name

`CAD`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `next_payout_time` | `Integer` | Optional | - |
| `payout_method_id` | `String` | Optional | - |
| `period` | [`PeriodEnum`](#period) | Optional | - |

##### Example (as JSON)

```json
{
  "next_payout_time": null,
  "payout_method_id": null,
  "period": null
}
```

#### CAD1

##### Class Name

`CAD1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `balance` | `Integer` | Optional | - |
| `incoming_pending` | `Integer` | Optional | - |
| `outgoing_pending` | `Integer` | Optional | - |
| `reserve` | `Integer` | Optional | - |

##### Example (as JSON)

```json
{
  "balance": null,
  "incoming_pending": null,
  "outgoing_pending": null,
  "reserve": null
}
```

#### CAD2

##### Class Name

`CAD2`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `payout_method_id` | `String` | Required | **Constraints**: *Maximum Length*: `255` |
| `period` | [`PeriodEnum`](#period) | Required | - |

##### Example (as JSON)

```json
{
  "payout_method_id": "payout_method_id2",
  "period": "weekly"
}
```

#### Contactless Payments

The response schema for contactless payments configuration.

##### Class Name

`ContactlessPayments`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `enabled` | `Boolean` | Required | - |
| `credit_debit_preference` | [`CreditDebitPreferenceEnum`](#credit-debit-preference) | Required | Determines how the terminal should prefer to charge contactless cards. "credit" is the EMV default, selecting the highest priority application in the card (which is the credit application). Debit preferred attempts to select debit network application on the card first. |

##### Example (as JSON)

```json
{
  "enabled": false,
  "credit_debit_preference": "credit"
}
```

#### Controller

##### Class Name

`Controller`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `personal_verification` | [`PersonalVerification`](#personal-verification) | Optional | - |

##### Example (as JSON)

```json
{
  "personal_verification": null
}
```

#### Controller 1

##### Class Name

`Controller1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `personal_verification` | [`PersonalVerification5`](#personal-verification-5) | Required | - |

##### Example (as JSON)

```json
{
  "personal_verification": {
    "current_issues": null,
    "documents": null,
    "verified": false
  }
}
```

#### Credit Card

##### Class Name

`CreditCard`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `interchange_plus` | [`InterchangePlus`](#interchange-plus) | Optional | The interchange plus pricing model for credit cards to collect platform markup fees. |
| `type` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "type": "interchange_plus"
}
```

#### Credit Card 1

##### Class Name

`CreditCard1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `auto_update` | `Boolean` | Optional | - |
| `backing_display_name` | `String` | Optional | - |
| `bin` | `String` | Optional | - |
| `card_brand` | [`CardBrandEnum`](#card-brand) | Optional | - |
| `card_entry_type` | [`CardEntryTypeEnum`](#card-entry-type) | Optional | - |
| `card_holder` | [`HolderResp`](#holder-resp) | Required | - |
| `display_name` | `String` | Optional | - |
| `expiration_month` | `Integer` | Required | - |
| `expiration_year` | `Integer` | Required | - |
| `last_four` | `String` | Optional | - |
| `virtual_terminal_mode` | [`VirtualTerminalModeEnum`](#virtual-terminal-mode) | Optional | - |
| `card_on_file` | `Boolean` | Required | - |
| `recurring` | `Boolean` | Required | - |
| `cvv_provided` | `Boolean` | Required | - |

##### Example (as JSON)

```json
{
  "auto_update": null,
  "backing_display_name": null,
  "bin": null,
  "card_brand": null,
  "card_entry_type": null,
  "card_holder": {
    "address": null,
    "email": null,
    "holder_name": "holder_name6",
    "phone": null
  },
  "display_name": null,
  "expiration_month": 226,
  "expiration_year": 0,
  "last_four": null,
  "virtual_terminal_mode": null,
  "card_on_file": false,
  "recurring": false,
  "cvv_provided": false
}
```

#### Credit Card 2

##### Class Name

`CreditCard2`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `auto_update` | `Boolean` | Optional | - |
| `card_holder` | [`HolderReq`](#holder-req) | Required | - |
| `card_number` | `String` | Required | **Constraints**: *Pattern*: `^[0-9]{12,19}$` |
| `cvv` | `String` | Optional | **Constraints**: *Pattern*: `^[0-9]{3,4}$` |
| `expiration_month` | `Integer` | Required | **Constraints**: `>= 1`, `<= 12` |
| `expiration_year` | `Integer` | Required | - |
| `trigger_verification` | `Boolean` | Optional | - |
| `virtual_terminal_mode` | [`VirtualTerminalModeEnum`](#virtual-terminal-mode) | Optional | - |
| `card_on_file` | `Boolean` | Optional | - |
| `recurring` | `Boolean` | Optional | - |

##### Example (as JSON)

```json
{
  "auto_update": null,
  "card_holder": {
    "address": {
      "city": null,
      "country": "IO",
      "line1": null,
      "line2": null,
      "postal_code": "postal_code8",
      "region": null
    },
    "email": null,
    "holder_name": "holder_name6",
    "phone": null
  },
  "card_number": "card_number6",
  "cvv": null,
  "expiration_month": 226,
  "expiration_year": 0,
  "trigger_verification": null,
  "virtual_terminal_mode": null,
  "card_on_file": null,
  "recurring": null
}
```

#### Credit Card 4

Credit card structure to be used for updating credit card information.

##### Class Name

`CreditCard4`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `card_on_file` | `Boolean` | Optional | - |
| `recurring` | `Boolean` | Optional | - |

##### Example (as JSON)

```json
{
  "card_on_file": null,
  "recurring": null
}
```

#### Currencies

##### Class Name

`Currencies`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `cad` | [`PricingByCurrency`](#pricing-by-currency) | Optional | - |
| `gbp` | [`PricingByCurrency`](#pricing-by-currency) | Optional | - |
| `usd` | [`PricingByCurrency`](#pricing-by-currency) | Optional | - |

##### Example (as JSON)

```json
{
  "CAD": null,
  "GBP": null,
  "USD": null
}
```

#### Currencies 1

##### Class Name

`Currencies1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `cad` | [`CAD`](#cad) | Optional | - |
| `gbp` | [`GBP`](#gbp) | Optional | - |
| `usd` | [`USD`](#usd) | Optional | - |

##### Example (as JSON)

```json
{
  "CAD": null,
  "GBP": null,
  "USD": null
}
```

#### Currencies 2

##### Class Name

`Currencies2`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `usd` | [`USD1`](#usd1) | Optional | - |
| `cad` | [`CAD1`](#cad1) | Optional | - |
| `gbp` | [`GBP1`](#gbp1) | Optional | - |

##### Example (as JSON)

```json
{
  "USD": null,
  "CAD": null,
  "GBP": null
}
```

#### Currencies 3

##### Class Name

`Currencies3`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `cad` | [`CAD2`](#cad2) | Optional | - |
| `gbp` | [`GBP2`](#gbp2) | Optional | - |
| `usd` | [`USD2`](#usd2) | Optional | - |

##### Example (as JSON)

```json
{
  "CAD": null,
  "GBP": null,
  "USD": null
}
```

#### Current Issue

##### Class Name

`CurrentIssue`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `additional_documents_required` | `Array<String>` | Optional | - |
| `errant_fields` | `Hash` | Optional | - |
| `in_review` | `Array<String>` | Optional | - |
| `application_block` | [`ApplicationBlock`](#application-block) | Optional | - |
| `issue_type` | [`IssueTypeEnum`](#issue-type) | Required | - |
| `target` | [`Target`](#target) | Required | - |

##### Example (as JSON)

```json
{
  "additional_documents_required": null,
  "errant_fields": null,
  "in_review": null,
  "application_block": null,
  "issue_type": "additional_documents_required",
  "target": {
    "id": null,
    "path": null,
    "resource": null
  }
}
```

#### Current Issue 2

##### Class Name

`CurrentIssue2`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `additional_documents_required` | `Array<String>` | Optional | - |
| `errant_fields` | `Hash` | Optional | - |
| `in_review` | `Array<String>` | Optional | - |
| `issue_type` | [`IssueType4Enum`](#issue-type-4) | Required | - |
| `target` | [`Target`](#target) | Required | - |

##### Example (as JSON)

```json
{
  "additional_documents_required": null,
  "errant_fields": null,
  "in_review": null,
  "issue_type": "in_review",
  "target": {
    "id": null,
    "path": null,
    "resource": null
  }
}
```

#### Date of Birth

##### Class Name

`DateOfBirth`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `day` | `Integer` | Required | **Constraints**: `>= 1`, `<= 31` |
| `month` | `Integer` | Required | **Constraints**: `>= 1`, `<= 12` |
| `year` | `Integer` | Required | **Constraints**: `>= 1900` |

##### Example (as JSON)

```json
{
  "day": 60,
  "month": 232,
  "year": 248
}
```

#### Detail

##### Class Name

`Detail`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `detail_code` | [`DetailCodeEnum`](#detail-code) | Optional | - |
| `detail_message` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "detail_code": null,
  "detail_message": null
}
```

#### Detail 1

##### Class Name

`Detail1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `detail_code` | [`DetailCode1Enum`](#detail-code-1) | Optional | - |
| `detail_message` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "detail_code": null,
  "detail_message": null
}
```

#### Detail 2

##### Class Name

`Detail2`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `detail_code` | [`DetailCode2Enum`](#detail-code-2) | Optional | - |
| `detail_message` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "detail_code": null,
  "detail_message": null
}
```

#### Detail 3

##### Class Name

`Detail3`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `detail_code` | [`DetailCode3Enum`](#detail-code-3) | Optional | - |
| `detail_message` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "detail_code": null,
  "detail_message": null
}
```

#### Detail 4

##### Class Name

`Detail4`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `detail_code` | [`DetailCode4Enum`](#detail-code-4) | Optional | - |
| `detail_message` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "detail_code": null,
  "detail_message": null
}
```

#### Detail 5

##### Class Name

`Detail5`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `detail_code` | [`DetailCode5Enum`](#detail-code-5) | Optional | - |
| `detail_message` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "detail_code": null,
  "detail_message": null
}
```

#### Detail 6

##### Class Name

`Detail6`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `detail_code` | [`DetailCode6Enum`](#detail-code-6) | Optional | - |
| `detail_message` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "detail_code": null,
  "detail_message": null
}
```

#### Detail 7

##### Class Name

`Detail7`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `detail_code` | [`DetailCode7Enum`](#detail-code-7) | Required | Chargeback code for visa, mastercard, amex, and discover cards |
| `detail_message` | `String` | Required | The detail a chargeback is being disputed |

##### Example (as JSON)

```json
{
  "detail_code": "C31",
  "detail_message": "detail_message8"
}
```

#### Detail 8

##### Class Name

`Detail8`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `detail_code` | [`DetailCode8Enum`](#detail-code-8) | Optional | - |
| `detail_message` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "detail_code": null,
  "detail_message": null
}
```

#### Detail 9

##### Class Name

`Detail9`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `detail_code` | [`DetailCode9Enum`](#detail-code-9) | Required | Adjustment detail code |
| `detail_message` | `String` | Required | Adjustment detail message for manual adjustment |

##### Example (as JSON)

```json
{
  "detail_code": "cross_border",
  "detail_message": "detail_message8"
}
```

#### Detail 10

##### Class Name

`Detail10`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `detail_code` | [`DetailCode10Enum`](#detail-code-10) | Required | - |
| `detail_message` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "detail_code": "info_mismatch",
  "detail_message": null
}
```

#### Disputes Request

##### Class Name

`DisputesRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `custom_data` | `Object` | Optional | - |
| `documentation` | [`Documentation1`](#documentation-1) | Optional | - |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |

##### Example (as JSON)

```json
{
  "custom_data": null,
  "documentation": null,
  "rbits": null
}
```

#### Disputes Response

##### Class Name

`DisputesResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<Disputes>`](#disputes) | Required | **Constraints**: *Unique Items Required* |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "results": {
    "amount": null,
    "create_time": null,
    "currency": null,
    "documentation": null,
    "fee": null,
    "id": null,
    "owner": {
      "id": null,
      "path": null,
      "resource": "accounts"
    },
    "path": null,
    "payment": {
      "id": null,
      "path": null,
      "resource": "payments"
    },
    "card_brand": null,
    "reason": null,
    "resolution": null,
    "resource": "disputes",
    "status": null,
    "txnr_chargeback_app_fees": {
      "id": null,
      "path": null,
      "resource": "transaction_records"
    },
    "txnr_chargeback_merchant": {
      "id": null,
      "path": null,
      "resource": "transaction_records"
    },
    "txnr_chargeback_reversal_app_fee": {
      "id": null,
      "path": null,
      "resource": "transaction_records"
    },
    "txnr_chargeback_reversal_merchant": {
      "id": null,
      "path": null,
      "resource": "transaction_records"
    },
    "txnr_merchant_chargeback_fee": {
      "id": null,
      "path": null,
      "resource": "transaction_records"
    },
    "type": null
  }
}
```

#### Document

##### Class Name

`Document`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `create_time` | `Integer` | Required | - |
| `id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `owner` | [`OwnerApplications`](#owner-applications) | Required | - |
| `path` | `String` | Optional | - |
| `reject_reason` | [`RejectReason`](#reject-reason) | Required | - |
| `resource` | `String` | Required | - |
| `status` | [`Status8Enum`](#status-8) | Required | - |
| `type` | [`Type15Enum`](#type-15) | Required | - |

##### Example (as JSON)

```json
{
  "create_time": null,
  "id": null,
  "owner": {
    "id": null,
    "resource": "applications"
  },
  "reject_reason": {
    "details": null,
    "reason_code": "failed_risk_review",
    "reason_message": null
  },
  "resource": "documents",
  "status": null,
  "type": null
}
```

#### Documentation

##### Class Name

`Documentation`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `documents` | `Array<String>` | Optional | - |
| `explanation` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "documents": null,
  "explanation": null
}
```

#### Documentation 1

##### Class Name

`Documentation1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `documents` | `Array<String>` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `explanation` | `String` | Optional | **Constraints**: *Maximum Length*: `65535` |

##### Example (as JSON)

```json
{
  "documents": null,
  "explanation": null
}
```

#### Embedded-Rbit

##### Class Name

`EmbeddedRbit`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `address` | [`AddressRbit`](#address-rbit) | Optional | - |
| `auto_billing` | [`AutoBilling`](#auto-billing) | Optional | - |
| `business_description` | [`BusinessDescription`](#business-description) | Optional | - |
| `business_name` | [`BusinessName`](#business-name) | Optional | - |
| `external_account` | [`ExternalAccount`](#external-account) | Optional | - |
| `fundraising_event` | [`FundraisingEvent`](#fundraising-event) | Optional | - |
| `fundraising_update` | [`FundraisingUpdate`](#fundraising-update) | Optional | - |
| `industry_code` | [`IndustryCode`](#industry-code) | Optional | - |
| `partner_service` | [`PartnerServiceRbit`](#partner-service-rbit) | Optional | - |
| `person` | [`PersonRbit`](#person-rbit) | Optional | - |
| `phone` | [`PhoneRbit`](#phone-rbit) | Optional | - |
| `mfa` | [`MfaRbit`](#mfa-rbit) | Optional | - |
| `receive_time` | `Integer` | Required | - |
| `source` | [`RbitSourceEnum`](#rbit-source) | Required | - |
| `transaction_details` | [`TransactionDetails`](#transaction-details) | Optional | - |
| `type` | [`RbitTypesEnum`](#rbit-types) | Required | - |

##### Example (as JSON)

```json
{
  "address": null,
  "auto_billing": null,
  "business_description": null,
  "business_name": null,
  "external_account": null,
  "fundraising_event": null,
  "fundraising_update": null,
  "industry_code": null,
  "partner_service": null,
  "person": null,
  "phone": null,
  "mfa": null,
  "receive_time": 38,
  "source": "user",
  "transaction_details": null,
  "type": "fundraising_event"
}
```

#### Entity Country Info

##### Class Name

`EntityCountryInfo`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `ca` | [`CA4`](#ca4) | Optional | - |
| `gb` | [`GB`](#gb) | Optional | - |
| `us` | [`US4`](#us4) | Optional | - |

##### Example (as JSON)

```json
{
  "CA": null,
  "GB": null,
  "US": null
}
```

#### Entity Verification

##### Class Name

`EntityVerification`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `documents` | `Array<String>` | Optional | **Constraints**: *Unique Items Required* |

##### Example (as JSON)

```json
{
  "documents": null
}
```

#### Entity Verification 1

##### Class Name

`EntityVerification1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `current_issues` | [`Array<CurrentIssue2>`](#current-issue-2) | Optional | - |
| `documents` | [`Array<Document>`](#document) | Optional | - |
| `verified` | `Boolean` | Required | - |

##### Example (as JSON)

```json
{
  "current_issues": null,
  "documents": null,
  "verified": false
}
```

#### Flat Guide

The configuration for a flat tip guide. All three guides must be provided.

##### Class Name

`FlatGuide`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `amount_low` | `Integer` | Required | The 'low' guide.<br>**Constraints**: `>= 0` |
| `amount_medium` | `Integer` | Required | The 'medium' guide.<br>**Constraints**: `>= 0` |
| `amount_high` | `Integer` | Required | The 'high' guide.<br>**Constraints**: `>= 0` |

##### Example (as JSON)

```json
{
  "amount_low": 220,
  "amount_medium": 60,
  "amount_high": 230
}
```

#### GB

##### Class Name

`GB`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `company_registration_number` | `String` | Optional | **Constraints**: *Pattern*: `^[A-Z0-9]{2}\d{6}$` |
| `legal_form` | [`LegalForm1Enum`](#legal-form-1) | Optional | - |

##### Example (as JSON)

```json
{
  "company_registration_number": null,
  "legal_form": null
}
```

#### GBP

##### Class Name

`GBP`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `next_payout_time` | `Integer` | Optional | - |
| `payout_method_id` | `String` | Optional | - |
| `period` | [`PeriodEnum`](#period) | Optional | - |

##### Example (as JSON)

```json
{
  "next_payout_time": null,
  "payout_method_id": null,
  "period": null
}
```

#### GBP1

##### Class Name

`GBP1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `balance` | `Integer` | Optional | - |
| `incoming_pending` | `Integer` | Optional | - |
| `outgoing_pending` | `Integer` | Optional | - |
| `reserve` | `Integer` | Optional | - |

##### Example (as JSON)

```json
{
  "balance": null,
  "incoming_pending": null,
  "outgoing_pending": null,
  "reserve": null
}
```

#### GBP2

##### Class Name

`GBP2`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `payout_method_id` | `String` | Required | **Constraints**: *Maximum Length*: `255` |
| `period` | [`PeriodEnum`](#period) | Required | - |

##### Example (as JSON)

```json
{
  "payout_method_id": "payout_method_id2",
  "period": "weekly"
}
```

#### Industry

##### Class Name

`Industry`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `category_detail` | `String` | Optional | **Constraints**: *Maximum Length*: `1024` |
| `merchant_category_code` | `String` | Optional | **Constraints**: *Pattern*: `^\d{4}$` |

##### Example (as JSON)

```json
{
  "category_detail": null,
  "merchant_category_code": null
}
```

#### Interchange Plus

The interchange plus pricing model for credit cards to collect platform markup fees.

##### Class Name

`InterchangePlus`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `fixed_fee_markup_amount` | `Integer` | Optional | The fixed markup fee amount.<br>**Constraints**: `>= 0`, `<= 100` |
| `variable_fee_markup_bps` | `Integer` | Optional | The basis points to calculate variable markup fee amount.<br>**Constraints**: `>= 0`, `<= 100` |

##### Example (as JSON)

```json
{
  "fixed_fee_markup_amount": null,
  "variable_fee_markup_bps": null
}
```

#### Itemized Receipt

##### Class Name

`ItemizedReceipt`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `amount` | `Float` | Required | - |
| `currency` | [`CurrencyEnum`](#currency) | Optional | - |
| `description` | `String` | Required | **Constraints**: *Maximum Length*: `1024` |
| `item_price` | `Integer` | Required | - |
| `project_name` | `String` | Optional | **Constraints**: *Maximum Length*: `1024` |
| `quantity` | `Float` | Required | - |
| `service_billing_method` | [`ServiceBillingMethodEnum`](#service-billing-method) | Optional | - |

##### Example (as JSON)

```json
{
  "amount": 56.78,
  "currency": null,
  "description": "description0",
  "item_price": 22,
  "project_name": null,
  "quantity": 149.16,
  "service_billing_method": null
}
```

#### Items Response

##### Class Name

`ItemsResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<ItemResp>`](#item-resp) | Required | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "results": {
    "create_time": null,
    "id": null,
    "owner": {
      "id": null,
      "path": null,
      "resource": "accounts"
    },
    "path": null,
    "product_name": null,
    "resource": "items",
    "state": null
  }
}
```

#### Legal Entities Request

##### Class Name

`LegalEntitiesRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `additional_representatives` | [`AdditionalRepresentativesReq`](#additional-representatives-req) | Optional | - |
| `address` | [`AddressLegalEntitiesNullable`](#address-legal-entities-nullable) | Optional | - |
| `controller` | [`ControllerReq`](#controller-req) | Optional | - |
| `custom_data` | `Object` | Optional | - |
| `description` | `String` | Optional | **Constraints**: *Maximum Length*: `1024` |
| `entity_country_info` | [`EntityCountryInfo`](#entity-country-info) | Optional | - |
| `entity_name` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `phone` | [`PhoneLegalEntitiesNullable`](#phone-legal-entities-nullable) | Optional | - |
| `primary_url` | `String` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |
| `terms_of_service` | [`TermsOfService`](#terms-of-service) | Optional | - |
| `token` | [`Token`](#token) | Optional | - |
| `reference_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |

##### Example (as JSON)

```json
{
  "additional_representatives": null,
  "address": null,
  "controller": null,
  "custom_data": null,
  "description": null,
  "entity_country_info": null,
  "entity_name": null,
  "phone": null,
  "primary_url": null,
  "rbits": null,
  "terms_of_service": null,
  "token": null,
  "reference_id": null
}
```

#### Legal Entities Response

##### Class Name

`LegalEntitiesResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<LegalEntityResp>`](#legal-entity-resp) | Required | **Constraints**: *Unique Items Required* |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "results": {
    "create_time": null,
    "id": null,
    "owner": {
      "id": null,
      "resource": "applications"
    },
    "path": null,
    "resource": "legal_entities",
    "api_version": null
  }
}
```

#### Legal Entities Verifications Request

##### Class Name

`LegalEntitiesVerificationsRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `additional_representatives` | [`AdditionalRepresentatives`](#additional-representatives) | Optional | - |
| `controller` | [`Controller`](#controller) | Optional | - |
| `entity_verification` | [`EntityVerification`](#entity-verification) | Optional | - |

##### Example (as JSON)

```json
{
  "additional_representatives": null,
  "controller": null,
  "entity_verification": null
}
```

#### Legal Entities Verifications Response

##### Class Name

`LegalEntitiesVerificationsResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `additional_representatives` | [`AdditionalRepresentatives1`](#additional-representatives-1) | Required | - |
| `controller` | [`Controller1`](#controller-1) | Required | - |
| `entity_verification` | [`EntityVerification1`](#entity-verification-1) | Required | - |
| `id` | `Object` | Optional | - |
| `owner` | [`OwnerLegalEntities`](#owner-legal-entities) | Required | - |
| `path` | `String` | Required | - |
| `resource` | `String` | Required | - |
| `api_version` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "additional_representatives": null,
  "controller": null,
  "entity_verification": null,
  "owner": {
    "id": null,
    "path": null,
    "resource": "legal_entities"
  },
  "path": null,
  "resource": "verifications",
  "api_version": null
}
```

#### Line Item

##### Class Name

`LineItem`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `commodity_code` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `currency` | [`CurrencyEnum`](#currency) | Required | - |
| `description` | `String` | Optional | **Constraints**: *Maximum Length*: `2047` |
| `discount_amount` | `Integer` | Optional | - |
| `discount_indicator` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `gross_net_indicator` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `item` | [`ItemNullableResp`](#item-nullable-resp) | Optional | - |
| `quantity` | `Integer` | Required | - |
| `tax_amount` | `Integer` | Optional | - |
| `tax_rate` | `Float` | Optional | - |
| `tax_type_applied` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `total_amount` | `Integer` | Required | - |
| `unit_of_measure` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `unit_price` | `Integer` | Required | - |

##### Example (as JSON)

```json
{
  "commodity_code": null,
  "currency": "CAD",
  "description": null,
  "discount_amount": null,
  "discount_indicator": null,
  "gross_net_indicator": null,
  "item": null,
  "quantity": 68,
  "tax_amount": null,
  "tax_rate": null,
  "tax_type_applied": null,
  "total_amount": 112,
  "unit_of_measure": null,
  "unit_price": 182
}
```

#### Line Item 1

##### Class Name

`LineItem1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `commodity_code` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `currency` | [`CurrencyEnum`](#currency) | Required | - |
| `description` | `String` | Optional | **Constraints**: *Maximum Length*: `2047` |
| `discount_amount` | `Integer` | Optional | - |
| `discount_indicator` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `gross_net_indicator` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `item` | [`ItemNullableReq`](#item-nullable-req) | Optional | - |
| `quantity` | `Integer` | Required | - |
| `tax_amount` | `Integer` | Optional | - |
| `tax_rate` | `Float` | Optional | - |
| `tax_type_applied` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `total_amount` | `Integer` | Required | - |
| `unit_of_measure` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `unit_price` | `Integer` | Required | - |

##### Example (as JSON)

```json
{
  "commodity_code": null,
  "currency": "CAD",
  "description": null,
  "discount_amount": null,
  "discount_indicator": null,
  "gross_net_indicator": null,
  "item": null,
  "quantity": 68,
  "tax_amount": null,
  "tax_rate": null,
  "tax_type_applied": null,
  "total_amount": 112,
  "unit_of_measure": null,
  "unit_price": 182
}
```

#### Name

##### Class Name

`Name`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `first` | `String` | Required | **Constraints**: *Minimum Length*: `2`, *Maximum Length*: `30` |
| `last` | `String` | Required | **Constraints**: *Minimum Length*: `2`, *Maximum Length*: `30` |

##### Example (as JSON)

```json
{
  "first": "first6",
  "last": "last0"
}
```

#### Notification Preferences Request

##### Class Name

`NotificationPreferencesRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `callback_uri` | `String` | Required | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |
| `topic` | [`Topic1Enum`](#topic-1) | Required | - |

##### Example (as JSON)

```json
{
  "callback_uri": "callback_uri4",
  "topic": "payouts.created"
}
```

#### Notification Preferences Request 1

##### Class Name

`NotificationPreferencesRequest1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `callback_uri` | `String` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |

##### Example (as JSON)

```json
{
  "callback_uri": null
}
```

#### Notification Preferences Response

##### Class Name

`NotificationPreferencesResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<Result1>`](#result-1) | Required | **Constraints**: *Unique Items Required* |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "results": {
    "callback_uri": null,
    "create_time": null,
    "id": null,
    "path": null,
    "resource": "notification_preferences",
    "status": null,
    "topic": null
  }
}
```

#### Notification Preferences Response 1

##### Class Name

`NotificationPreferencesResponse1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `callback_uri` | `String` | Required | - |
| `create_time` | `Integer` | Required | - |
| `id` | `String` | Required | - |
| `owner` | [`OwnerApplications`](#owner-applications) | Optional | - |
| `path` | `String` | Required | - |
| `resource` | `String` | Required | - |
| `status` | `String` | Required | - |
| `topic` | `String` | Required | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "callback_uri": null,
  "create_time": null,
  "id": null,
  "path": null,
  "resource": "notification_preferences",
  "status": "active",
  "topic": null
}
```

#### Notification Preferences Response 2

##### Class Name

`NotificationPreferencesResponse2`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `callback_uri` | `String` | Required | - |
| `create_time` | `Integer` | Required | - |
| `id` | `String` | Required | - |
| `owner` | [`OwnerApplications`](#owner-applications) | Optional | - |
| `path` | `String` | Required | - |
| `resource` | `String` | Required | - |
| `status` | [`Status20Enum`](#status-20) | Required | - |
| `topic` | `String` | Required | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "callback_uri": null,
  "create_time": null,
  "id": null,
  "path": null,
  "resource": "notification_preferences",
  "status": null,
  "topic": null
}
```

#### Notifications Response

##### Class Name

`NotificationsResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<Result>`](#result) | Required | **Constraints**: *Unique Items Required* |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "results": {
    "event_time": null,
    "id": null,
    "owner": {
      "id": null,
      "resource": "applications"
    },
    "path": null,
    "payload": null,
    "resource": "notifications",
    "topic": null
  }
}
```

#### Notifications Response 1

##### Class Name

`NotificationsResponse1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `event_time` | `Integer` | Required | - |
| `id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `owner` | [`OwnerApplications`](#owner-applications) | Required | - |
| `path` | `String` | Required | - |
| `payload` | `Object` | Required | - |
| `resource` | `String` | Required | - |
| `topic` | `String` | Required | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "event_time": null,
  "id": null,
  "owner": {
    "id": null,
    "resource": "applications"
  },
  "path": null,
  "payload": null,
  "resource": "notifications",
  "topic": null
}
```

#### Orders Response

##### Class Name

`OrdersResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<OrderResp>`](#order-resp) | Required | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "next": null,
  "previous": null,
  "results": [
    {
      "alternate_tax_amount": null,
      "alternate_tax_id": null,
      "buyer": null,
      "create_time": null,
      "currency": null,
      "customer_reference_number": null,
      "delivery_type": null,
      "discount_amount": null,
      "duty_amount": null,
      "freight_amount": null,
      "grand_total_amount": null,
      "id": null,
      "line_items": null,
      "long_description": null,
      "notes": null,
      "owner": null,
      "path": null,
      "reference_number": null,
      "resource": null,
      "service_address": null,
      "ship_from_address": null,
      "ship_to_address": null,
      "shipping_status": null,
      "short_description": null,
      "state": null,
      "status": null,
      "tax_amount": null,
      "terms": null,
      "type": null,
      "vat_amount": null,
      "vat_rate": null,
      "api_version": null
    }
  ],
  "api_version": null
}
```

#### Owner 3

##### Class Name

`Owner3`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Required | - |
| `path` | `String` | Required | - |
| `resource` | [`Resource1Enum`](#resource-1) | Required | - |

##### Example (as JSON)

```json
{
  "id": "id0",
  "path": "path6",
  "resource": "adjustments"
}
```

#### Owner 16

##### Class Name

`Owner16`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Required | - |
| `path` | `String` | Required | - |
| `resource` | [`ResourceTypesRbitEnum`](#resource-types-rbit) | Required | - |

##### Example (as JSON)

```json
{
  "id": "id0",
  "path": "path6",
  "resource": "payments"
}
```

#### Owner 20

Owner structure to be used in any resource where an application is the owner

##### Class Name

`Owner20`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Required | - |
| `path` | `String` | Optional | - |
| `resource` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "id": null,
  "resource": "applications"
}
```

#### Payment Methods Request

##### Class Name

`PaymentMethodsRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `credit_card` | [`CreditCard4`](#credit-card-4) | Optional | Credit card structure to be used for updating credit card information. |
| `payment_bank_us` | `Object` | Optional | Payment bank structure to be used for updating payment bank information. No field is allowed for update now. |
| `type` | [`Type3Enum`](#type-3) | Optional | - |
| `custom_data` | `Object` | Optional | - |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |

##### Example (as JSON)

```json
{
  "credit_card": null,
  "payment_bank_us": null,
  "type": null,
  "custom_data": null,
  "rbits": null
}
```

#### Payment Methods Response

##### Class Name

`PaymentMethodsResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<PaymentMethodResp>`](#payment-method-resp) | Required | **Constraints**: *Unique Items Required* |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "results": {
    "create_time": null,
    "id": null,
    "owner": {
      "id": null,
      "resource": "applications"
    },
    "path": null,
    "resource": "payment_methods",
    "status": null,
    "type": null
  }
}
```

#### Payment Methods Verify Bank Deposits Request

##### Class Name

`PaymentMethodsVerifyBankDepositsRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `microdeposits` | `Array<Integer>` | Required | - |

##### Example (as JSON)

```json
{
  "microdeposits": [
    170,
    171,
    172
  ]
}
```

#### Payment Bank

##### Class Name

`PaymentBank`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `standard` | [`Standard`](#standard) | Optional | The standard pricing model for payment banks to collect platform fees. |
| `type` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "type": "standard"
}
```

#### Payment Bank Us

##### Class Name

`PaymentBankUs`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `account_holder` | [`HolderResp`](#holder-resp) | Required | - |
| `account_type` | [`AccountTypeEnum`](#account-type) | Required | - |
| `last_four` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "account_holder": {
    "address": null,
    "email": null,
    "holder_name": "holder_name6",
    "phone": null
  },
  "account_type": "checking",
  "last_four": "last_four6"
}
```

#### Payments

##### Class Name

`Payments`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `current_issues` | [`Array<CurrentIssue>`](#current-issue) | Optional | - |
| `enabled` | `Boolean` | Required | - |
| `upcoming_issues` | `Hash` | Optional | - |

##### Example (as JSON)

```json
{
  "current_issues": null,
  "enabled": false,
  "upcoming_issues": null
}
```

#### Payments Cancel Request

##### Class Name

`PaymentsCancelRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `cancel_reason` | `String` | Required | - |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |

##### Example (as JSON)

```json
{
  "cancel_reason": "cancel_reason4",
  "rbits": null
}
```

#### Payments Capture Request

##### Class Name

`PaymentsCaptureRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `amounts` | [`CaptureAmounts`](#capture-amounts) | Optional | - |

##### Example (as JSON)

```json
{
  "amounts": null
}
```

#### Payments Request

##### Class Name

`PaymentsRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `account_id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `amount` | `Integer` | Required | **Constraints**: `>= 0` |
| `auto_capture` | `Boolean` | Optional | - |
| `capture_at` | `Integer` | Optional | - |
| `currency` | [`CurrencyEnum`](#currency) | Required | - |
| `custom_data` | `Object` | Optional | - |
| `fee_amount` | `Integer` | Optional | **Constraints**: `>= 0` |
| `order_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `payment_method` | [`PaymentMethodForPayments`](#payment-method-for-payments) | Required | - |
| `initiated_by` | [`InitiatedByReqEnum`](#initiated-by-req) | Optional | - |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |
| `reference_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |

##### Example (as JSON)

```json
{
  "account_id": "account_id2",
  "amount": 46,
  "auto_capture": null,
  "capture_at": null,
  "currency": "CAD",
  "custom_data": null,
  "fee_amount": null,
  "order_id": null,
  "payment_method": {
    "credit_card": null,
    "custom_data": null,
    "payment_bank_us": null,
    "payment_method_id": null,
    "token": null,
    "encoded_payment_method": null,
    "type": "credit_card"
  },
  "initiated_by": null,
  "rbits": null,
  "reference_id": null
}
```

#### Payments Request 1

##### Class Name

`PaymentsRequest1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `custom_data` | `Object` | Optional | - |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |
| `reference_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `amounts` | [`CaptureAmounts`](#capture-amounts) | Optional | - |

##### Example (as JSON)

```json
{
  "custom_data": null,
  "rbits": null,
  "reference_id": null,
  "amounts": null
}
```

#### Payments Response

##### Class Name

`PaymentsResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<PaymentsV30>`](#payments-v-3-0) | Required | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "results": {
    "amount": null,
    "amount_refunded": null,
    "amount_disputed": null,
    "create_time": null,
    "currency": null,
    "id": null,
    "owner": {
      "id": null,
      "path": null,
      "resource": "accounts"
    },
    "path": null,
    "payment_method": {
      "id": null,
      "path": null,
      "resource": "payment_methods"
    },
    "resource": "payments",
    "status": null,
    "initiated_by": null
  }
}
```

#### Payments 1

##### Class Name

`Payments1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `application_block` | [`ApplicationBlock4`](#application-block-4) | Optional | - |

##### Example (as JSON)

```json
{
  "application_block": null
}
```

#### Payout Methods Request

##### Class Name

`PayoutMethodsRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `custom_data` | `Object` | Optional | - |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |

##### Example (as JSON)

```json
{
  "custom_data": null,
  "rbits": null
}
```

#### Payout Methods Response

##### Class Name

`PayoutMethodsResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<PayoutMethodResp>`](#payout-method-resp) | Required | **Constraints**: *Unique Items Required* |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "results": {
    "id": null,
    "path": null,
    "resource": "payout_methods"
  }
}
```

#### Payout Bank Ca

##### Class Name

`PayoutBankCa`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `account_type` | [`AccountTypeEnum`](#account-type) | Required | - |
| `last_four` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "account_type": "checking",
  "last_four": "last_four6"
}
```

#### Payout Bank Ca 1

##### Class Name

`PayoutBankCa1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `account_number` | `String` | Required | **Constraints**: *Pattern*: `^[0-9]{5,17}$` |
| `account_type` | [`AccountTypeEnum`](#account-type) | Required | - |
| `institution_number` | `String` | Required | **Constraints**: *Pattern*: `^[0-9]{3}$` |
| `transit_number` | `String` | Required | **Constraints**: *Pattern*: `^[0-9]{5}$` |

##### Example (as JSON)

```json
{
  "account_number": "account_number0",
  "account_type": "checking",
  "institution_number": "institution_number2",
  "transit_number": "transit_number8"
}
```

#### Payout Bank Gb

##### Class Name

`PayoutBankGb`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `last_four` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "last_four": "last_four6"
}
```

#### Payout Bank Gb 1

##### Class Name

`PayoutBankGb1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `account_number` | `String` | Required | **Constraints**: *Pattern*: `^[0-9]{8}$` |
| `sort_code` | `String` | Required | **Constraints**: *Pattern*: `^[0-9]{6}$` |

##### Example (as JSON)

```json
{
  "account_number": "account_number0",
  "sort_code": "sort_code0"
}
```

#### Payout Bank Us

##### Class Name

`PayoutBankUs`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `account_type` | [`AccountTypeEnum`](#account-type) | Required | - |
| `last_four` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "account_type": "checking",
  "last_four": "last_four6"
}
```

#### Payout Bank Us 1

##### Class Name

`PayoutBankUs1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `account_number` | `String` | Required | **Constraints**: *Pattern*: `^[0-9]{3,17}$` |
| `account_type` | [`AccountTypeEnum`](#account-type) | Required | - |
| `routing_number` | `String` | Required | **Constraints**: *Pattern*: `^[0-9]{9}$` |

##### Example (as JSON)

```json
{
  "account_number": "account_number0",
  "account_type": "checking",
  "routing_number": "routing_number4"
}
```

#### Payouts

##### Class Name

`Payouts`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `current_issues` | [`Array<CurrentIssue>`](#current-issue) | Optional | - |
| `enabled` | `Boolean` | Required | - |
| `upcoming_issues` | `Hash` | Optional | - |

##### Example (as JSON)

```json
{
  "current_issues": null,
  "enabled": false,
  "upcoming_issues": null
}
```

#### Payouts Request

##### Class Name

`PayoutsRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `custom_data` | `Object` | Optional | - |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |

##### Example (as JSON)

```json
{
  "custom_data": null,
  "rbits": null
}
```

#### Payouts Response

##### Class Name

`PayoutsResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<Payout>`](#payout) | Required | **Constraints**: *Unique Items Required* |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "results": {
    "id": null,
    "owner": {
      "id": null,
      "path": null,
      "resource": "accounts"
    },
    "path": null,
    "resource": "payouts"
  }
}
```

#### Payouts 1

##### Class Name

`Payouts1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `application_block` | [`ApplicationBlock4`](#application-block-4) | Optional | - |

##### Example (as JSON)

```json
{
  "application_block": null
}
```

#### Percentage Guide

The configuration for a percentage tip guide. All three guides must be provided.

##### Class Name

`PercentageGuide`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `show_amount` | `Boolean` | Required | Whether or not to show the amount that the percentage equates to in the tip guide button. |
| `percentage_low` | `Integer` | Required | The 'low' guide.<br>**Constraints**: `>= 0` |
| `percentage_medium` | `Integer` | Required | The 'medium' guide.<br>**Constraints**: `>= 0` |
| `percentage_high` | `Integer` | Required | The 'high' guide.<br>**Constraints**: `>= 0` |

##### Example (as JSON)

```json
{
  "show_amount": false,
  "percentage_low": 10,
  "percentage_medium": 15,
  "percentage_high": 18
}
```

#### Personal Country Info

##### Class Name

`PersonalCountryInfo`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `ca` | [`CA`](#ca) | Optional | - |
| `gb` | `Object` | Optional | - |
| `us` | [`US`](#us) | Optional | - |

##### Example (as JSON)

```json
{
  "CA": null,
  "GB": null,
  "US": null
}
```

#### Personal Country Info 1

##### Class Name

`PersonalCountryInfo1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `ca` | [`CA1`](#ca1) | Optional | - |
| `gb` | `Object` | Optional | - |
| `us` | [`US1`](#us1) | Optional | - |

##### Example (as JSON)

```json
{
  "CA": null,
  "GB": null,
  "US": null
}
```

#### Personal Verification

##### Class Name

`PersonalVerification`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `documents` | `Array<String>` | Optional | **Constraints**: *Unique Items Required* |

##### Example (as JSON)

```json
{
  "documents": null
}
```

#### Personal Verification 5

##### Class Name

`PersonalVerification5`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `current_issues` | [`Array<CurrentIssue2>`](#current-issue-2) | Optional | - |
| `documents` | [`Array<Document>`](#document) | Optional | - |
| `verified` | `Boolean` | Required | - |

##### Example (as JSON)

```json
{
  "current_issues": null,
  "documents": null,
  "verified": false
}
```

#### Phone

##### Class Name

`Phone`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `country_code` | `String` | Optional | **Constraints**: *Pattern*: `^\+?[0-9]{1,3}$` |
| `phone_number` | `String` | Optional | **Constraints**: *Pattern*: `^[0-9]{1,14}$` |
| `type` | [`TypeEnum`](#type) | Optional | - |

##### Example (as JSON)

```json
{
  "country_code": null,
  "phone_number": null,
  "type": null
}
```

#### Phone 1

##### Class Name

`Phone1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `country_code` | `String` | Required | **Constraints**: *Pattern*: `^\+?[0-9]{1,3}$` |
| `phone_number` | `String` | Required | **Constraints**: *Pattern*: `^[0-9]{1,14}$` |
| `type` | [`TypeEnum`](#type) | Optional | - |

##### Example (as JSON)

```json
{
  "country_code": "country_code0",
  "phone_number": "phone_number2",
  "type": null
}
```

#### Rbits Request

##### Class Name

`RbitsRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `address` | [`AddressRbit`](#address-rbit) | Optional | - |
| `associated_resource` | [`AssociatedResource`](#associated-resource) | Required | - |
| `auto_billing` | [`AutoBilling`](#auto-billing) | Optional | - |
| `business_description` | [`BusinessDescription`](#business-description) | Optional | - |
| `business_name` | [`BusinessName`](#business-name) | Optional | - |
| `external_account` | [`ExternalAccount`](#external-account) | Optional | - |
| `fundraising_event` | [`FundraisingEvent`](#fundraising-event) | Optional | - |
| `fundraising_update` | [`FundraisingUpdate`](#fundraising-update) | Optional | - |
| `industry_code` | [`IndustryCode`](#industry-code) | Optional | - |
| `partner_service` | [`PartnerServiceRbit`](#partner-service-rbit) | Optional | - |
| `person` | [`PersonRbit`](#person-rbit) | Optional | - |
| `phone` | [`PhoneRbit`](#phone-rbit) | Optional | - |
| `mfa` | [`MfaRbit`](#mfa-rbit) | Optional | - |
| `receive_time` | `Integer` | Required | - |
| `source` | [`RbitSourceEnum`](#rbit-source) | Required | - |
| `transaction_details` | [`TransactionDetails`](#transaction-details) | Optional | - |
| `type` | [`RbitTypesEnum`](#rbit-types) | Required | - |

##### Example (as JSON)

```json
{
  "address": null,
  "associated_resource": {
    "id": "id2",
    "resource": "payout_methods"
  },
  "auto_billing": null,
  "business_description": null,
  "business_name": null,
  "external_account": null,
  "fundraising_event": null,
  "fundraising_update": null,
  "industry_code": null,
  "partner_service": null,
  "person": null,
  "phone": null,
  "mfa": null,
  "receive_time": 38,
  "source": "user",
  "transaction_details": null,
  "type": "fundraising_event"
}
```

#### Rbits Response

##### Class Name

`RbitsResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `address` | [`AddressRbit`](#address-rbit) | Optional | - |
| `auto_billing` | [`AutoBilling`](#auto-billing) | Optional | - |
| `business_description` | [`BusinessDescription`](#business-description) | Optional | - |
| `business_name` | [`BusinessName`](#business-name) | Optional | - |
| `create_time` | `Integer` | Required | - |
| `external_account` | [`ExternalAccount`](#external-account) | Optional | - |
| `fundraising_event` | [`FundraisingEvent`](#fundraising-event) | Optional | - |
| `fundraising_update` | [`FundraisingUpdate`](#fundraising-update) | Optional | - |
| `id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `industry_code` | [`IndustryCode`](#industry-code) | Optional | - |
| `owner` | [`Owner16`](#owner-16) | Required | - |
| `partner_service` | [`PartnerServiceRbit`](#partner-service-rbit) | Optional | - |
| `path` | `String` | Required | - |
| `person` | [`PersonRbit`](#person-rbit) | Optional | - |
| `phone` | [`PhoneRbit`](#phone-rbit) | Optional | - |
| `mfa` | [`MfaRbit`](#mfa-rbit) | Optional | - |
| `receive_time` | `Integer` | Required | - |
| `resource` | `String` | Required | - |
| `source` | [`RbitSourceEnum`](#rbit-source) | Required | - |
| `state` | [`StateEnum`](#state) | Required | - |
| `transaction_details` | [`TransactionDetails`](#transaction-details) | Optional | - |
| `type` | [`RbitTypesEnum`](#rbit-types) | Required | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "create_time": null,
  "id": null,
  "owner": null,
  "path": null,
  "receive_time": null,
  "resource": "rbits",
  "source": null,
  "state": null,
  "type": null
}
```

#### Rbits Response 1

##### Class Name

`RbitsResponse1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<Result2>`](#result-2) | Required | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "results": {
    "create_time": null,
    "id": null,
    "owner": null,
    "path": null,
    "receive_time": null,
    "resource": "rbits",
    "source": null,
    "state": null,
    "type": null
  }
}
```

#### Reason

##### Class Name

`Reason`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `reason_code` | [`ReasonCode9Enum`](#reason-code-9) | Required | The category of adjustment reason |
| `reason_message` | `String` | Required | Adjustment descriptive reason |
| `details` | [`Array<Detail9>`](#detail-9) | Optional | - |

##### Example (as JSON)

```json
{
  "reason_code": "CROSS_BORDER",
  "reason_message": "reason_message2",
  "details": null
}
```

#### Recoveries Request

##### Class Name

`RecoveriesRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `custom_data` | `Object` | Optional | - |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |

##### Example (as JSON)

```json
{
  "custom_data": null,
  "rbits": null
}
```

#### Recoveries Response

##### Class Name

`RecoveriesResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<Recoveries>`](#recoveries) | Required | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "results": {
    "amount": null,
    "create_time": null,
    "currency": null,
    "failure_reason": null,
    "id": null,
    "owner": {
      "id": null,
      "path": null,
      "resource": "accounts"
    },
    "path": null,
    "payout_method": {
      "id": null,
      "path": null,
      "resource": "payout_methods"
    },
    "resource": "recoveries",
    "status": null,
    "txnr_failure": {
      "id": null,
      "path": null,
      "resource": "transaction_records"
    },
    "txnr_recovery": {
      "id": null,
      "path": null,
      "resource": "transaction_records"
    }
  }
}
```

#### Refunds Request

##### Class Name

`RefundsRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `custom_data` | `Object` | Optional | - |
| `rbits` | [`Array<EmbeddedRbit>`](#embedded-rbit) | Optional | - |
| `reference_id` | `String` | Optional | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |

##### Example (as JSON)

```json
{
  "custom_data": null,
  "rbits": null,
  "reference_id": null
}
```

#### Refunds Response

##### Class Name

`RefundsResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<RefundResp>`](#refund-resp) | Required | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "results": {
    "amounts": null,
    "create_time": null,
    "failure_reason": null,
    "id": null,
    "order": {
      "id": null,
      "path": null,
      "resource": "orders"
    },
    "owner": {
      "id": null,
      "path": null,
      "resource": "accounts"
    },
    "path": null,
    "payment": {
      "id": null,
      "path": null,
      "resource": "payments"
    },
    "payment_method": {
      "id": null,
      "path": null,
      "resource": "payment_methods"
    },
    "refund_reason": null,
    "resource": "refunds",
    "status": null,
    "txnr_app_fee_refund": {
      "id": null,
      "path": null,
      "resource": "transaction_records"
    },
    "txnr_merchant_refund": {
      "id": null,
      "path": null,
      "resource": "transaction_records"
    }
  }
}
```

#### Reject Reason

##### Class Name

`RejectReason`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `details` | [`Array<Detail10>`](#detail-10) | Required | **Constraints**: *Unique Items Required* |
| `reason_code` | `String` | Required | - |
| `reason_message` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "details": null,
  "reason_code": "failed_risk_review",
  "reason_message": null
}
```

#### Representative 0

##### Class Name

`Representative0`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `personal_verification` | [`PersonalVerification`](#personal-verification) | Optional | - |

##### Example (as JSON)

```json
{
  "personal_verification": null
}
```

#### Representative 01

##### Class Name

`Representative01`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `personal_verification` | [`PersonalVerification5`](#personal-verification-5) | Required | - |

##### Example (as JSON)

```json
{
  "personal_verification": {
    "current_issues": null,
    "documents": null,
    "verified": false
  }
}
```

#### Resolution

##### Class Name

`Resolution`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `resolution_time` | `Integer` | Optional | - |
| `type` | [`Type5Enum`](#type-5) | Optional | - |

##### Example (as JSON)

```json
{
  "resolution_time": null,
  "type": null
}
```

#### Result

##### Class Name

`Result`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `event_time` | `Integer` | Required | - |
| `id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `owner` | [`OwnerApplications`](#owner-applications) | Required | - |
| `path` | `String` | Required | - |
| `payload` | `Object` | Required | - |
| `resource` | `String` | Required | - |
| `topic` | `String` | Required | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "event_time": null,
  "id": null,
  "owner": {
    "id": null,
    "resource": "applications"
  },
  "path": null,
  "payload": null,
  "resource": "notifications",
  "topic": null
}
```

#### Result 1

##### Class Name

`Result1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `callback_uri` | `String` | Required | - |
| `create_time` | `Integer` | Required | - |
| `id` | `String` | Required | - |
| `owner` | [`OwnerApplications`](#owner-applications) | Optional | - |
| `path` | `String` | Required | - |
| `resource` | `String` | Required | - |
| `status` | [`Status20Enum`](#status-20) | Required | - |
| `topic` | `String` | Required | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "callback_uri": null,
  "create_time": null,
  "id": null,
  "path": null,
  "resource": "notification_preferences",
  "status": null,
  "topic": null
}
```

#### Result 2

##### Class Name

`Result2`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `address` | [`AddressRbit`](#address-rbit) | Optional | - |
| `auto_billing` | [`AutoBilling`](#auto-billing) | Optional | - |
| `business_description` | [`BusinessDescription`](#business-description) | Optional | - |
| `business_name` | [`BusinessName`](#business-name) | Optional | - |
| `create_time` | `Integer` | Required | - |
| `external_account` | [`ExternalAccount`](#external-account) | Optional | - |
| `fundraising_event` | [`FundraisingEvent`](#fundraising-event) | Optional | - |
| `fundraising_update` | [`FundraisingUpdate`](#fundraising-update) | Optional | - |
| `id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `industry_code` | [`IndustryCode`](#industry-code) | Optional | - |
| `owner` | [`Owner16`](#owner-16) | Required | - |
| `partner_service` | [`PartnerServiceRbit`](#partner-service-rbit) | Optional | - |
| `path` | `String` | Required | - |
| `person` | [`PersonRbit`](#person-rbit) | Optional | - |
| `phone` | [`PhoneRbit`](#phone-rbit) | Optional | - |
| `mfa` | [`MfaRbit`](#mfa-rbit) | Optional | - |
| `receive_time` | `Integer` | Required | - |
| `resource` | `String` | Required | - |
| `source` | [`RbitSourceEnum`](#rbit-source) | Required | - |
| `state` | [`StateEnum`](#state) | Required | - |
| `transaction_details` | [`TransactionDetails`](#transaction-details) | Optional | - |
| `type` | [`RbitTypesEnum`](#rbit-types) | Required | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "create_time": null,
  "id": null,
  "owner": null,
  "path": null,
  "receive_time": null,
  "resource": "rbits",
  "source": null,
  "state": null,
  "type": null
}
```

#### Shipping Info

##### Class Name

`ShippingInfo`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `actual_delivery_time` | `Integer` | Optional | - |
| `carrier` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `expected_delivery_time` | `Integer` | Optional | - |
| `shipping_time` | `Integer` | Optional | - |
| `tracking_number` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `tracking_url` | `String` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |

##### Example (as JSON)

```json
{
  "actual_delivery_time": null,
  "carrier": null,
  "expected_delivery_time": null,
  "shipping_time": null,
  "tracking_number": null,
  "tracking_url": null
}
```

#### Shipping Status

##### Class Name

`ShippingStatus`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `actual_delivery_time` | `Integer` | Optional | - |
| `carrier` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `expected_delivery_time` | `Integer` | Optional | - |
| `shipping_time` | `Integer` | Optional | - |
| `tracking_number` | `String` | Optional | **Constraints**: *Maximum Length*: `1024` |
| `tracking_uri` | `String` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |

##### Example (as JSON)

```json
{
  "actual_delivery_time": null,
  "carrier": null,
  "expected_delivery_time": null,
  "shipping_time": null,
  "tracking_number": null,
  "tracking_uri": null
}
```

#### Shipping Status 1

##### Class Name

`ShippingStatus1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `actual_delivery_time` | `Integer` | Optional | - |
| `carrier` | `String` | Optional | **Constraints**: *Maximum Length*: `255` |
| `expected_delivery_time` | `Integer` | Optional | - |
| `shipping_time` | `Integer` | Optional | - |
| `tracking_number` | `String` | Optional | **Constraints**: *Maximum Length*: `1024` |
| `tracking_uri` | `String` | Optional | **Constraints**: *Maximum Length*: `2063`, *Pattern*: `^https?://.+$` |

##### Example (as JSON)

```json
{
  "actual_delivery_time": null,
  "carrier": null,
  "expected_delivery_time": null,
  "shipping_time": null,
  "tracking_number": null,
  "tracking_uri": null
}
```

#### Standard

The standard pricing model for payment banks to collect platform fees.

##### Class Name

`Standard`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `fixed_fee_amount` | `Integer` | Optional | The fixed fee amount.<br>**Constraints**: `>= 0`, `<= 100` |
| `variable_fee_bps` | `Integer` | Optional | The basis points to calculate variable fee amount.<br>**Constraints**: `>= 0`, `<= 100` |
| `max_fee_amount` | `Integer` | Optional | The max value of total fee amount.<br>**Constraints**: `>= 0` |
| `min_fee_amount` | `Integer` | Optional | The min value of total fee amount.<br>**Constraints**: `>= 0` |

##### Example (as JSON)

```json
{
  "fixed_fee_amount": null,
  "variable_fee_bps": null,
  "max_fee_amount": null,
  "min_fee_amount": null
}
```

#### Target

##### Class Name

`Target`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `id` | `String` | Optional | - |
| `path` | `String` | Optional | - |
| `resource` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "id": null,
  "path": null,
  "resource": null
}
```

#### Terminal Configuration

##### Class Name

`TerminalConfiguration`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `address` | [`AddressTerminalsResp`](#address-terminals-resp) | Required | - |
| `currency` | [`CurrencyEnum`](#currency) | Required | - |
| `supported_card_brands` | [`Array<TerminalsSupportedCardBrandEnum>`](#terminals-supported-card-brand) | Required | The collection of card brands that are supported by the terminal. Must provide at least one.<br>**Constraints**: *Minimum Items*: `1`, *Unique Items Required* |
| `credit_debit_preference` | [`CreditDebitPreference1Enum`](#credit-debit-preference-1) | Required | Determines how the terminal should prefer credit vs debit when a card is dipped. "credit" indicates credit is the preferred application selection, whereas "debit" would prefer the debit application. "prompt" will perform the EMV default behavior, which is to prompt if multiple applications exist. |
| `sim_card_id` | `String` | Optional | The identifier of the SIM card installed in the terminal. Nullable if terminal does not have a SIM card. |
| `timezone` | [`TimezoneEnum`](#timezone) | Required | Timezone of the terminal' |
| `tip` | [`TerminalsTip`](#terminals-tip) | Required | - |
| `signature_required` | `Boolean` | Required | Whether or not this terminal requires signature verification from payers. |
| `contactless_payments` | [`ContactlessPayments`](#contactless-payments) | Required | The response schema for contactless payments configuration. |
| `quick_chip` | [`QuickChip`](#quick-chip) | Required | Configuration settings for quick chip functionality. |
| `deferred_authorization` | [`DeferredAuthorization`](#deferred-authorization) | Required | Configuration settings for deferred authorization functionality. |

##### Example (as JSON)

```json
{
  "address": null,
  "currency": null,
  "supported_card_brands": [
    "visa",
    "american_express",
    "discover",
    "mastercard"
  ],
  "credit_debit_preference": null,
  "timezone": null,
  "tip": {
    "mode": "prompt_on_terminal",
    "terminal_display": {
      "amount_guide_type": "percentage_guide",
      "percentage_guide": {
        "show_amount": false,
        "percentage_low": 15,
        "percentage_medium": 18,
        "percentage_high": 20
      }
    }
  },
  "signature_required": null,
  "contactless_payments": null,
  "quick_chip": null,
  "deferred_authorization": {
    "enabled": null,
    "international_enabled": null,
    "max_transaction_count": 20,
    "max_total_amount": 250000,
    "max_transaction_amount": 12500,
    "supported_card_entry_modes": [
      "chip",
      "contactless"
    ]
  }
}
```

#### Terminal Configuration 1

##### Class Name

`TerminalConfiguration1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `address` | [`AddressTerminalsReq`](#address-terminals-req) | Optional | - |
| `currency` | [`CurrencyEnum`](#currency) | Required | - |
| `supported_card_brands` | [`Array<TerminalsSupportedCardBrandEnum>`](#terminals-supported-card-brand) | Required | The collection of card brands that are supported by the terminal. Must provide at least one.<br>**Constraints**: *Minimum Items*: `1`, *Unique Items Required* |
| `credit_debit_preference` | [`CreditDebitPreference1Enum`](#credit-debit-preference-1) | Optional | Determines how the terminal should prefer credit vs debit when a card is dipped. "credit" indicates credit is the preferred application selection, whereas "debit" would prefer the debit application. "prompt" will perform the EMV default behavior, which is to prompt if multiple applications exist. |
| `sim_card_id` | `String` | Optional | The identifier of the SIM card installed in the terminal. Nullable if terminal does not have a SIM card. |
| `timezone` | [`TimezoneEnum`](#timezone) | Required | Timezone of the terminal' |
| `tip` | [`TerminalsTip`](#terminals-tip) | Required | - |
| `signature_required` | `Boolean` | Required | Whether or not this terminal requires signature verification from payers. |
| `contactless_payments` | [`ContactlessPaymentsReq`](#contactless-payments-req) | Required | The request schema for modifying contactless payments configuration settings. |
| `quick_chip` | [`QuickChip`](#quick-chip) | Required | Configuration settings for quick chip functionality. |
| `deferred_authorization` | [`DeferredAuthorization`](#deferred-authorization) | Required | Configuration settings for deferred authorization functionality. |

##### Example (as JSON)

```json
{
  "currency": null,
  "supported_card_brands": [
    "visa",
    "american_express",
    "discover",
    "mastercard"
  ],
  "timezone": null,
  "tip": {
    "mode": "prompt_on_terminal",
    "terminal_display": {
      "amount_guide_type": "percentage_guide",
      "percentage_guide": {
        "show_amount": false,
        "percentage_low": 15,
        "percentage_medium": 18,
        "percentage_high": 20
      }
    }
  },
  "signature_required": null,
  "contactless_payments": null,
  "quick_chip": null,
  "deferred_authorization": {
    "enabled": null,
    "international_enabled": null,
    "max_transaction_count": 20,
    "max_total_amount": 250000,
    "max_transaction_amount": 12500,
    "supported_card_entry_modes": [
      "chip",
      "contactless"
    ]
  }
}
```

#### Terminal Configuration 2

##### Class Name

`TerminalConfiguration2`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `address` | [`AddressTerminalsReq`](#address-terminals-req) | Optional | - |
| `currency` | [`CurrencyEnum`](#currency) | Optional | - |
| `supported_card_brands` | [`Array<TerminalsSupportedCardBrandEnum>`](#terminals-supported-card-brand) | Optional | The collection of card brands that are supported by the terminal. Must provide at least one.<br>**Constraints**: *Minimum Items*: `1`, *Unique Items Required* |
| `credit_debit_preference` | [`CreditDebitPreference1Enum`](#credit-debit-preference-1) | Optional | Determines how the terminal should prefer credit vs debit when a card is dipped. "credit" indicates credit is the preferred application selection, whereas "debit" would prefer the debit application. "prompt" will perform the EMV default behavior, which is to prompt if multiple applications exist. |
| `sim_card_id` | `String` | Optional | The identifier of the SIM card installed in the terminal. Nullable if terminal does not have a SIM card. |
| `timezone` | [`TimezoneEnum`](#timezone) | Optional | Timezone of the terminal' |
| `tip` | [`TerminalsTip`](#terminals-tip) | Optional | - |
| `signature_required` | `Boolean` | Optional | Whether or not this terminal requires signature verification from payers. |
| `contactless_payments` | [`ContactlessPaymentsReq`](#contactless-payments-req) | Optional | The request schema for modifying contactless payments configuration settings. |
| `quick_chip` | [`QuickChip`](#quick-chip) | Optional | Configuration settings for quick chip functionality. |
| `deferred_authorization` | [`DeferredAuthorization`](#deferred-authorization) | Optional | Configuration settings for deferred authorization functionality. |

##### Example (as JSON)

```json
{
  "address": null,
  "currency": null,
  "supported_card_brands": null,
  "credit_debit_preference": null,
  "sim_card_id": null,
  "timezone": null,
  "tip": null,
  "signature_required": null,
  "contactless_payments": null,
  "quick_chip": null,
  "deferred_authorization": null
}
```

#### Terminal Display

This configuration is required if the mode is "prompt_on_terminal", and is responsible for configuring how the tip guide appears on the physical terminal.

##### Class Name

`TerminalDisplay`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `amount_guide_type` | [`AmountGuideTypeEnum`](#amount-guide-type) | Required | The type of the amount guide can be either a percentage guide or a flat guide. Percentage guides will offer the payer a chance to tip with one of a few default tip percentages that are configured. Flat guides will offer the payer flat tip amounts to choose from. Both types of guides will allow the payer to manually enter a tip amount. |
| `percentage_guide` | [`PercentageGuide`](#percentage-guide) | Optional | The configuration for a percentage tip guide. All three guides must be provided. |
| `flat_guide` | [`FlatGuide`](#flat-guide) | Optional | The configuration for a flat tip guide. All three guides must be provided. |

##### Example (as JSON)

```json
{
  "amount_guide_type": "percentage_guide",
  "percentage_guide": null,
  "flat_guide": null
}
```

#### Terminals Request

##### Class Name

`TerminalsRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `account_id` | `String` | Required | **Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `serial_number` | `String` | Required | The serial number of the physical terminal. |
| `model` | [`Model1Enum`](#model-1) | Required | The model of the physical terminal. |
| `reference_id` | `String` | Optional | A reference ID that can be used to identify the terminals resource in WePay's system. Searching capabilities are supported on this field.<br>**Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `terminal_configuration` | [`TerminalConfiguration1`](#terminal-configuration-1) | Required | - |

##### Example (as JSON)

```json
{
  "account_id": null,
  "serial_number": "FA00332-1000138",
  "model": null,
  "terminal_configuration": {
    "currency": null,
    "supported_card_brands": [
      "visa",
      "american_express",
      "discover",
      "mastercard"
    ],
    "timezone": null,
    "tip": {
      "mode": "prompt_on_terminal",
      "terminal_display": {
        "amount_guide_type": "percentage_guide",
        "percentage_guide": {
          "show_amount": false,
          "percentage_low": 15,
          "percentage_medium": 18,
          "percentage_high": 20
        }
      }
    },
    "signature_required": null,
    "contactless_payments": null,
    "quick_chip": null,
    "deferred_authorization": {
      "enabled": null,
      "international_enabled": null,
      "max_transaction_count": 20,
      "max_total_amount": 250000,
      "max_transaction_amount": 12500,
      "supported_card_entry_modes": [
        "chip",
        "contactless"
      ]
    }
  }
}
```

#### Terminals Request 1

##### Class Name

`TerminalsRequest1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `reference_id` | `String` | Optional | A reference ID that can be used to identify the terminals resource in WePay's system. Searching capabilities are supported on this field.<br>**Constraints**: *Minimum Length*: `1`, *Maximum Length*: `255` |
| `terminal_configuration` | [`TerminalConfiguration2`](#terminal-configuration-2) | Optional | - |

##### Example (as JSON)

```json
{
  "reference_id": null,
  "terminal_configuration": null
}
```

#### Terminals Response

##### Class Name

`TerminalsResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<TerminalResp>`](#terminal-resp) | Required | **Constraints**: *Unique Items Required* |
| `api_version` | `String` | Required | - |

##### Example (as JSON)

```json
{
  "results": {
    "id": null,
    "resource": "terminals",
    "path": null,
    "owner": {
      "id": null,
      "path": null,
      "resource": "accounts"
    },
    "api_version": null,
    "status": null,
    "serial_number": "FA00332-1000138",
    "model": null,
    "last_call_home": null,
    "terminal_application_version": null,
    "terminal_configuration": {
      "address": null,
      "currency": null,
      "supported_card_brands": [
        "visa",
        "american_express",
        "discover",
        "mastercard"
      ],
      "credit_debit_preference": null,
      "timezone": null,
      "tip": {
        "mode": "prompt_on_terminal",
        "terminal_display": {
          "amount_guide_type": "percentage_guide",
          "percentage_guide": {
            "show_amount": false,
            "percentage_low": 15,
            "percentage_medium": 18,
            "percentage_high": 20
          }
        }
      },
      "signature_required": null,
      "contactless_payments": null,
      "quick_chip": null,
      "deferred_authorization": {
        "enabled": null,
        "international_enabled": null,
        "max_transaction_count": 20,
        "max_total_amount": 250000,
        "max_transaction_amount": 12500,
        "supported_card_entry_modes": [
          "chip",
          "contactless"
        ]
      }
    }
  },
  "api_version": "3.0"
}
```

#### Terms of Service

##### Class Name

`TermsOfService`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `acceptance_time` | `Integer` | Optional | - |
| `original_ip` | `String` | Optional | **Constraints**: *Maximum Length*: `45`, *Pattern*: `^[A-F0-9:\.]*$` |

##### Example (as JSON)

```json
{
  "acceptance_time": null,
  "original_ip": null
}
```

#### Tokens Request

##### Class Name

`TokensRequest`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `legal_entities` | [`LegalEntity`](#legal-entity) | Optional | - |
| `payment_methods` | [`PaymentMethodReq`](#payment-method-req) | Optional | - |
| `payout_methods` | [`PayoutMethodReq`](#payout-method-req) | Optional | - |
| `resource` | [`Resource2Enum`](#resource-2) | Required | - |

##### Example (as JSON)

```json
{
  "legal_entities": null,
  "payment_methods": null,
  "payout_methods": null,
  "resource": "legal_entities"
}
```

#### Tokens Response

##### Class Name

`TokensResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `create_time` | `Integer` | Required | - |
| `expire_time` | `Integer` | Required | - |
| `id` | `String` | Required | The generated token id. |
| `owner` | [`Owner20`](#owner-20) | Required | Owner structure to be used in any resource where an application is the owner |
| `path` | `String` | Optional | - |
| `resource` | `String` | Required | - |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "create_time": null,
  "expire_time": null,
  "id": null,
  "owner": {
    "id": null,
    "resource": "applications"
  },
  "resource": "tokens"
}
```

#### Transaction Records Response

##### Class Name

`TransactionRecordsResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `mnext` | `String` | Optional | - |
| `previous` | `String` | Optional | - |
| `results` | [`Array<TransactionRecord>`](#transaction-record) | Required | **Constraints**: *Unique Items Required* |
| `api_version` | `String` | Optional | - |

##### Example (as JSON)

```json
{
  "results": {
    "create_time": null,
    "id": null,
    "path": null,
    "resource": "transaction_records"
  }
}
```

#### Upcoming Issue

##### Class Name

`UpcomingIssue`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `additional_documents_required` | `Array<String>` | Optional | - |
| `errant_fields` | `Hash` | Optional | - |
| `in_review` | `Array<String>` | Optional | - |
| `application_block` | [`ApplicationBlock`](#application-block) | Optional | - |
| `issue_type` | [`IssueTypeEnum`](#issue-type) | Required | - |
| `target` | [`Target`](#target) | Required | - |

##### Example (as JSON)

```json
{
  "additional_documents_required": null,
  "errant_fields": null,
  "in_review": null,
  "application_block": null,
  "issue_type": "additional_documents_required",
  "target": {
    "id": null,
    "path": null,
    "resource": null
  }
}
```

#### US

##### Class Name

`US`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `social_security_number` | `String` | Optional | **Constraints**: *Pattern*: `^\d{3}[ -]?\d{2}[ -]?\d{4}$` |
| `social_security_number_last_four` | `String` | Optional | **Constraints**: *Pattern*: `^\d{4}$` |

##### Example (as JSON)

```json
{
  "social_security_number": null,
  "social_security_number_last_four": null
}
```

#### US1

##### Class Name

`US1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `social_security_number_is_present` | `Boolean` | Optional | - |
| `social_security_number_last_four_is_present` | `Boolean` | Optional | - |

##### Example (as JSON)

```json
{
  "social_security_number_is_present": null,
  "social_security_number_last_four_is_present": null
}
```

#### US4

##### Class Name

`US4`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `employer_identification_number` | `String` | Optional | **Constraints**: *Pattern*: `^\d{9}$` |
| `legal_form` | [`LegalFormEnum`](#legal-form) | Optional | - |

##### Example (as JSON)

```json
{
  "employer_identification_number": null,
  "legal_form": null
}
```

#### USD

##### Class Name

`USD`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `next_payout_time` | `Integer` | Optional | - |
| `payout_method_id` | `String` | Optional | - |
| `period` | [`PeriodEnum`](#period) | Optional | - |

##### Example (as JSON)

```json
{
  "next_payout_time": null,
  "payout_method_id": null,
  "period": null
}
```

#### USD1

##### Class Name

`USD1`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `balance` | `Integer` | Optional | - |
| `incoming_pending` | `Integer` | Optional | - |
| `outgoing_pending` | `Integer` | Optional | - |
| `reserve` | `Integer` | Optional | - |

##### Example (as JSON)

```json
{
  "balance": null,
  "incoming_pending": null,
  "outgoing_pending": null,
  "reserve": null
}
```

#### USD2

##### Class Name

`USD2`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `payout_method_id` | `String` | Required | **Constraints**: *Maximum Length*: `255` |
| `period` | [`PeriodEnum`](#period) | Required | - |

##### Example (as JSON)

```json
{
  "payout_method_id": "payout_method_id2",
  "period": "weekly"
}
```

### Enumerations

* [Currency](#currency)
* [Country Code](#country-code)
* [Rbit-Types](#rbit-types)
* [Rbit-Source](#rbit-source)
* [Fee Type](#fee-type)
* [Resource-Legal Entities](#resource-legal-entities)
* [Resource Types-Rbit](#resource-types-rbit)
* [Initiated By-Resp](#initiated-by-resp)
* [Resource-Payments](#resource-payments)
* [Currency-Nullable](#currency-nullable)
* [Resource-Notifications](#resource-notifications)
* [Terminals Status](#terminals-status)
* [Resource-Accounts](#resource-accounts)
* [Resource-Verifications](#resource-verifications)
* [Resource-Capabilities](#resource-capabilities)
* [Initiated By-Req](#initiated-by-req)
* [Account Type](#account-type)
* [Address Type](#address-type)
* [Amount Guide Type](#amount-guide-type)
* [Card Brand 2](#card-brand-2)
* [Card Brand](#card-brand)
* [Card Entry Type](#card-entry-type)
* [Code Type](#code-type)
* [Credit Debit Preference](#credit-debit-preference)
* [Credit Debit Preference 1](#credit-debit-preference-1)
* [Delivery Type](#delivery-type)
* [Detail Code](#detail-code)
* [Detail Code 1](#detail-code-1)
* [Detail Code 2](#detail-code-2)
* [Detail Code 3](#detail-code-3)
* [Detail Code 4](#detail-code-4)
* [Detail Code 5](#detail-code-5)
* [Detail Code 6](#detail-code-6)
* [Detail Code 7](#detail-code-7)
* [Detail Code 8](#detail-code-8)
* [Detail Code 9](#detail-code-9)
* [Detail Code 10](#detail-code-10)
* [Errant Field](#errant-field)
* [Issue Type](#issue-type)
* [Issue Type 4](#issue-type-4)
* [Legal Form](#legal-form)
* [Legal Form 1](#legal-form-1)
* [Mfa Action](#mfa-action)
* [Mode](#mode)
* [Model](#model)
* [Model 1](#model-1)
* [Name Type](#name-type)
* [Payment Method Type](#payment-method-type)
* [Payout Method Type](#payout-method-type)
* [Period](#period)
* [Phone Type](#phone-type)
* [Reason Code](#reason-code)
* [Reason Code 1](#reason-code-1)
* [Reason Code 2](#reason-code-2)
* [Reason Code 3](#reason-code-3)
* [Reason Code 4](#reason-code-4)
* [Reason Code 5](#reason-code-5)
* [Reason Code 6](#reason-code-6)
* [Reason Code 7](#reason-code-7)
* [Reason Code 8](#reason-code-8)
* [Reason Code 9](#reason-code-9)
* [Resource](#resource)
* [Resource 1](#resource-1)
* [Resource 2](#resource-2)
* [Role](#role)
* [Service Billing Method](#service-billing-method)
* [Setup By](#setup-by)
* [State](#state)
* [Status](#status)
* [Status 2](#status-2)
* [Status 3](#status-3)
* [Status 4](#status-4)
* [Status 5](#status-5)
* [Status 8](#status-8)
* [Status 20](#status-20)
* [Supported Card Entry Mode](#supported-card-entry-mode)
* [Terminals-Supported Card Brand](#terminals-supported-card-brand)
* [Timezone](#timezone)
* [Topic](#topic)
* [Topic 1](#topic-1)
* [Type](#type)
* [Type 2](#type-2)
* [Type 3](#type-3)
* [Type 4](#type-4)
* [Type 5](#type-5)
* [Type 6](#type-6)
* [Type 7](#type-7)
* [Type 8](#type-8)
* [Type 9](#type-9)
* [Type 12](#type-12)
* [Type 15](#type-15)
* [Type 27](#type-27)
* [Units](#units)
* [Virtual Terminal Mode](#virtual-terminal-mode)

#### Currency

##### Class Name

`CurrencyEnum`

##### Fields

| Name |
|  --- |
| `USD` |
| `CAD` |
| `GBP` |

#### Country Code

##### Class Name

`CountryCodeEnum`

##### Fields

| Name |
|  --- |
| `AD` |
| `AE` |
| `AF` |
| `AG` |
| `AI` |
| `AL` |
| `AM` |
| `AO` |
| `AQ` |
| `AR` |
| `AS` |
| `AT` |
| `AU` |
| `AW` |
| `AX` |
| `AZ` |
| `BA` |
| `BB` |
| `BD` |
| `BE` |
| `BF` |
| `BG` |
| `BH` |
| `BI` |
| `BJ` |
| `BL` |
| `BM` |
| `BN` |
| `BO` |
| `BQ` |
| `BR` |
| `BS` |
| `BT` |
| `BV` |
| `BW` |
| `BY` |
| `BZ` |
| `CA` |
| `CC` |
| `CD` |
| `CF` |
| `CG` |
| `CH` |
| `CI` |
| `CK` |
| `CL` |
| `CM` |
| `CN` |
| `CO` |
| `CR` |
| `CU` |
| `CV` |
| `CW` |
| `CX` |
| `CY` |
| `CZ` |
| `DE` |
| `DJ` |
| `DK` |
| `DM` |
| `DO` |
| `DZ` |
| `EC` |
| `EE` |
| `EG` |
| `EH` |
| `ER` |
| `ES` |
| `ET` |
| `FI` |
| `FJ` |
| `FK` |
| `FM` |
| `FO` |
| `FR` |
| `GA` |
| `GB` |
| `GD` |
| `GE` |
| `GF` |
| `GG` |
| `GH` |
| `GI` |
| `GL` |
| `GM` |
| `GN` |
| `GP` |
| `GQ` |
| `GR` |
| `GS` |
| `GT` |
| `GU` |
| `GW` |
| `GY` |
| `HK` |
| `HM` |
| `HN` |
| `HR` |
| `HT` |
| `HU` |
| `ID` |
| `IE` |
| `IL` |
| `IM` |
| `IN` |
| `IO` |
| `IQ` |
| `IR` |
| `IS` |
| `IT` |
| `JE` |
| `JM` |
| `JO` |
| `JP` |
| `KE` |
| `KG` |
| `KH` |
| `KI` |
| `KM` |
| `KN` |
| `KP` |
| `KR` |
| `KW` |
| `KY` |
| `KZ` |
| `LA` |
| `LB` |
| `LC` |
| `LI` |
| `LK` |
| `LR` |
| `LS` |
| `LT` |
| `LU` |
| `LV` |
| `LY` |
| `MA` |
| `MC` |
| `MD` |
| `ME` |
| `MF` |
| `MG` |
| `MH` |
| `MK` |
| `ML` |
| `MM` |
| `MN` |
| `MO` |
| `MP` |
| `MQ` |
| `MR` |
| `MS` |
| `MT` |
| `MU` |
| `MV` |
| `MW` |
| `MX` |
| `MY` |
| `MZ` |
| `NA` |
| `NC` |
| `NE` |
| `NF` |
| `NG` |
| `NI` |
| `NL` |
| `NO` |
| `NP` |
| `NR` |
| `NU` |
| `NZ` |
| `OM` |
| `PA` |
| `PE` |
| `PF` |
| `PG` |
| `PH` |
| `PK` |
| `PL` |
| `PM` |
| `PN` |
| `PR` |
| `PS` |
| `PT` |
| `PW` |
| `PY` |
| `QA` |
| `RE` |
| `RO` |
| `RS` |
| `RU` |
| `RW` |
| `SA` |
| `SB` |
| `SC` |
| `SD` |
| `SE` |
| `SG` |
| `SH` |
| `SI` |
| `SJ` |
| `SK` |
| `SL` |
| `SM` |
| `SN` |
| `SO` |
| `SR` |
| `SS` |
| `ST` |
| `SV` |
| `SX` |
| `SY` |
| `SZ` |
| `TC` |
| `TD` |
| `TF` |
| `TG` |
| `TH` |
| `TJ` |
| `TK` |
| `TL` |
| `TM` |
| `TN` |
| `TO` |
| `TR` |
| `TT` |
| `TV` |
| `TW` |
| `TZ` |
| `UA` |
| `UG` |
| `UM` |
| `US` |
| `UY` |
| `UZ` |
| `VA` |
| `VC` |
| `VE` |
| `VG` |
| `VI` |
| `VN` |
| `VU` |
| `WF` |
| `WS` |
| `YE` |
| `YT` |
| `ZA` |
| `ZM` |
| `ZW` |

#### Rbit-Types

##### Class Name

`RbitTypesEnum`

##### Fields

| Name |
|  --- |
| `ADDRESS` |
| `AUTO_BILLING` |
| `BUSINESS_DESCRIPTION` |
| `BUSINESS_NAME` |
| `EXTERNAL_ACCOUNT` |
| `FUNDRAISING_EVENT` |
| `FUNDRAISING_UPDATE` |
| `INDUSTRY_CODE` |
| `PARTNER_SERVICE` |
| `PERSON` |
| `PHONE` |
| `TRANSACTION_DETAILS` |
| `MFA` |

#### Rbit-Source

##### Class Name

`RbitSourceEnum`

##### Fields

| Name |
|  --- |
| `USER` |
| `GUIDESTAR` |
| `EXPERIAN_PRECISE_ID` |
| `EXPERIAN_BIZ_ID` |
| `EXPERIAN_BIZ_IQ` |
| `EQUIFAX` |
| `SPOKEO` |
| `WHITEPAGES` |
| `IRS_TIN_CHECK` |
| `PARTNER_DATABASE` |
| `PARTNER_EMPLOYEE` |
| `GENERIC_WEBSITE` |

#### Fee Type

##### Class Name

`FeeTypeEnum`

##### Fields

| Name |
|  --- |
| `VISA` |
| `MASTERCARD` |
| `AMEX` |
| `DISCOVER` |
| `ECHECK` |
| `CHARGEBACK` |
| `OTHER` |

#### Resource-Legal Entities

##### Class Name

`ResourceLegalEntitiesEnum`

##### Fields

| Name |
|  --- |
| `LEGAL_ENTITIES` |

#### Resource Types-Rbit

##### Class Name

`ResourceTypesRbitEnum`

##### Fields

| Name |
|  --- |
| `LEGAL_ENTITIES` |
| `ACCOUNTS` |
| `PAYOUT_METHODS` |
| `PAYMENT_METHODS` |
| `PAYMENTS` |
| `REFUNDS` |
| `ITEMS` |
| `ORDERS` |

#### Initiated By-Resp

##### Class Name

`InitiatedByRespEnum`

##### Fields

| Name |
|  --- |
| `CUSTOMER` |
| `MERCHANT` |
| `NONE` |

#### Resource-Payments

##### Class Name

`ResourcePaymentsEnum`

##### Fields

| Name |
|  --- |
| `PAYMENTS` |

#### Currency-Nullable

##### Class Name

`CurrencyNullableEnum`

##### Fields

| Name |
|  --- |
| `USD` |
| `CAD` |
| `GBP` |

#### Resource-Notifications

##### Class Name

`ResourceNotificationsEnum`

##### Fields

| Name |
|  --- |
| `NOTIFICATIONS` |

#### Terminals Status

The status of the terminal. Active means the terminal is able to accept authorizations. Inactive means the terminal has been deactivated and is unable to accept payments (this can occur for risk and fraud related reasons).

##### Class Name

`TerminalsStatusEnum`

##### Fields

| Name |
|  --- |
| `ACTIVE` |
| `DELETED` |
| `INACTIVE` |

#### Resource-Accounts

##### Class Name

`ResourceAccountsEnum`

##### Fields

| Name |
|  --- |
| `ACCOUNTS` |

#### Resource-Verifications

##### Class Name

`ResourceVerificationsEnum`

##### Fields

| Name |
|  --- |
| `VERIFICATIONS` |

#### Resource-Capabilities

##### Class Name

`ResourceCapabilitiesEnum`

##### Fields

| Name |
|  --- |
| `CAPABILITIES` |

#### Initiated By-Req

##### Class Name

`InitiatedByReqEnum`

##### Fields

| Name |
|  --- |
| `CUSTOMER` |
| `MERCHANT` |

#### Account Type

##### Class Name

`AccountTypeEnum`

##### Fields

| Name |
|  --- |
| `CHECKING` |
| `SAVINGS` |

#### Address Type

##### Class Name

`AddressTypeEnum`

##### Fields

| Name |
|  --- |
| `INCORPORATION` |
| `HEADQUARTERS` |
| `SATELLITE` |
| `MAIL_FORWARDING` |
| `HOME` |

#### Amount Guide Type

The type of the amount guide can be either a percentage guide or a flat guide. Percentage guides will offer the payer a chance to tip with one of a few default tip percentages that are configured. Flat guides will offer the payer flat tip amounts to choose from. Both types of guides will allow the payer to manually enter a tip amount.

##### Class Name

`AmountGuideTypeEnum`

##### Fields

| Name |
|  --- |
| `PERCENTAGE_GUIDE` |
| `FLAT_GUIDE` |

#### Card Brand 2

##### Class Name

`CardBrand2Enum`

##### Fields

| Name |
|  --- |
| `MASTERCARD` |
| `VISA` |
| `AMEX` |
| `DISCOVER` |

#### Card Brand

##### Class Name

`CardBrandEnum`

##### Fields

| Name |
|  --- |
| `VISA` |
| `MASTERCARD` |
| `DISCOVER` |
| `AMEX` |
| `JCB` |
| `DINERS` |

#### Card Entry Type

##### Class Name

`CardEntryTypeEnum`

##### Fields

| Name |
|  --- |
| `CARD_KEYED` |

#### Code Type

##### Class Name

`CodeTypeEnum`

##### Fields

| Name |
|  --- |
| `MERCHANT_CATEGORY_CODE` |
| `STANDARD_INDUSTRY_CODE` |
| `NORTH_AMERICAN_INDUSTRY_CLASSIFICATION_SYSTEM` |

#### Credit Debit Preference

Determines how the terminal should prefer to charge contactless cards. "credit" is the EMV default, selecting the highest priority application in the card (which is the credit application). Debit preferred attempts to select debit network application on the card first.

##### Class Name

`CreditDebitPreferenceEnum`

##### Fields

| Name |
|  --- |
| `CREDIT` |
| `DEBIT` |

#### Credit Debit Preference 1

Determines how the terminal should prefer credit vs debit when a card is dipped. "credit" indicates credit is the preferred application selection, whereas "debit" would prefer the debit application. "prompt" will perform the EMV default behavior, which is to prompt if multiple applications exist.

##### Class Name

`CreditDebitPreference1Enum`

##### Fields

| Name |
|  --- |
| `CREDIT` |
| `DEBIT` |
| `PROMPT` |

#### Delivery Type

##### Class Name

`DeliveryTypeEnum`

##### Fields

| Name |
|  --- |
| `NONE` |
| `FULLY_DELIVERED` |
| `POINT_OF_SALE` |
| `SHIPPING` |
| `DONATION` |
| `SUBSCRIPTION` |
| `PARTIAL_PREPAYMENT` |
| `FULL_PREPAYMENT` |

#### Detail Code

##### Class Name

`DetailCodeEnum`

##### Fields

| Name |
|  --- |
| `PROCESSING` |
| `UNKNOWN` |

#### Detail Code 1

##### Class Name

`DetailCode1Enum`

##### Fields

| Name |
|  --- |
| `RISK_REVIEW` |
| `PROCESSING` |
| `UNKNOWN` |

#### Detail Code 2

##### Class Name

`DetailCode2Enum`

##### Fields

| Name |
|  --- |
| `MANUAL_CAPTURE` |
| `PROCESSING` |
| `RISK_REVIEW` |
| `ECHECK_SUBMISSION` |
| `BANK_VERIFICATION` |
| `UNKNOWN` |

#### Detail Code 3

##### Class Name

`DetailCode3Enum`

##### Fields

| Name |
|  --- |
| `RISK_REVIEW` |
| `PROCESSING` |

#### Detail Code 4

##### Class Name

`DetailCode4Enum`

##### Fields

| Name |
|  --- |
| `SUSPECTED_PAYER_FRAUD` |
| `SUSPECTED_MERCHANT_FRAUD` |
| `ACCOUNT_COMPROMISED` |
| `UNABLE_TO_VERIFY_CONTROLLING_OWNER` |
| `UNABLE_TO_VERIFY_PAYER` |
| `UNABLE_TO_VERIFY_OWNER_PAYER` |
| `AGAINST_TOS` |
| `ACCOUNT_CANNOT_GO_NEGATIVE` |
| `HIGH_RISK_ACCOUNT` |
| `NAME_MISMATCH` |
| `ADMIN_KYC_MISMATCH` |
| `OTHER` |
| `UNKNOWN` |

#### Detail Code 5

##### Class Name

`DetailCode5Enum`

##### Fields

| Name |
|  --- |
| `INVALID_ADDRESS` |
| `INVALID_CARD_NUMBER` |
| `INVALID_CARD_TYPE` |
| `CARD_NOT_SUPPORTED` |
| `INCORRECT_CID` |
| `DECLINE_BANK` |
| `DECLINE_ISSUER` |
| `DECLINE_INSUFFICIENT_FUNDS` |
| `DECLINE_CARD_STOLEN` |
| `DECLINE_CARD_INACTIVE` |
| `DECLINE_CREDIT_LIMIT` |
| `DECLINE_BLACKLISTED` |
| `DECLINE_GENERAL` |
| `CARD_EXPIRED` |
| `CARD_INVALID_DATA` |
| `CARD_MISSING_FIELDS` |
| `SYSTEM_FAILURE` |
| `EXCESSIVE_AUTHORIZATIONS` |
| `ACCOUNT_CANNOT_TRANSACT` |
| `ABUSE` |
| `BANK_FAILURE` |
| `TESTING` |
| `NO_PAYMENT_ATTEMPTED` |
| `FAILED_PERMANENTLY` |
| `UNEXPECTED` |
| `UNDEFINED` |
| `DEBIT_CARD_NOT_ACCEPTED` |
| `EXCEEDED_TOKEN_AMOUNT_LIMIT` |
| `TOKEN_CURRENCY_MISMATCH` |
| `PROCESSOR_TIMED_OUT` |
| `PROCESSOR_DECLINED` |
| `R01` |
| `R02` |
| `R03` |
| `R04` |
| `R05` |
| `R06` |
| `R07` |
| `R08` |
| `R09` |
| `R10` |
| `R11` |
| `R12` |
| `R13` |
| `R14` |
| `R15` |
| `R16` |
| `R17` |
| `R18` |
| `R19` |
| `R20` |
| `R21` |
| `R22` |
| `R23` |
| `R24` |
| `R25` |
| `R26` |
| `R27` |
| `R28` |
| `R29` |
| `R30` |
| `R31` |
| `R32` |
| `R33` |
| `R34` |
| `R35` |
| `R36` |
| `R37` |
| `R38` |
| `R39` |
| `R40` |
| `R41` |
| `R42` |
| `R43` |
| `R44` |
| `R45` |
| `R46` |
| `R47` |
| `R50` |
| `R51` |
| `R52` |
| `R53` |
| `R61` |
| `R67` |
| `R68` |
| `R69` |
| `R70` |
| `R71` |
| `R72` |
| `R73` |
| `R74` |
| `R75` |
| `R76` |
| `R80` |
| `R81` |
| `R82` |
| `R83` |
| `R84` |
| `R94` |
| `R95` |
| `R97` |
| `R98` |
| `R99` |
| `REQUEST_EXPIRED` |
| `RISK_REVIEW` |
| `UNKNOWN` |

#### Detail Code 6

##### Class Name

`DetailCode6Enum`

##### Fields

| Name |
|  --- |
| `INSUFFICIENT_FUNDS` |
| `UNKNOWN` |

#### Detail Code 7

Chargeback code for visa, mastercard, amex, and discover cards

##### Class Name

`DetailCode7Enum`

##### Fields

| Name |
|  --- |
| `ENUM_101` |
| `ENUM_102` |
| `ENUM_103` |
| `ENUM_104` |
| `ENUM_105` |
| `ENUM_111` |
| `ENUM_112` |
| `ENUM_113` |
| `ENUM_121` |
| `ENUM_122` |
| `ENUM_123` |
| `ENUM_124` |
| `ENUM_125` |
| `ENUM_126` |
| `ENUM_1261` |
| `ENUM_1262` |
| `ENUM_127` |
| `ENUM_131` |
| `ENUM_132` |
| `ENUM_133` |
| `ENUM_134` |
| `ENUM_135` |
| `ENUM_136` |
| `ENUM_137` |
| `ENUM_138` |
| `ENUM_139` |
| `ENUM_4807` |
| `ENUM_4808` |
| `ENUM_4812` |
| `ENUM_4831` |
| `ENUM_4834` |
| `ENUM_4835` |
| `ENUM_4837` |
| `ENUM_4840` |
| `ENUM_4841` |
| `ENUM_4842` |
| `ENUM_4846` |
| `ENUM_4847` |
| `ENUM_4849` |
| `ENUM_4850` |
| `ENUM_4853` |
| `ENUM_4854` |
| `ENUM_4855` |
| `ENUM_4859` |
| `ENUM_4860` |
| `ENUM_4862` |
| `ENUM_4863` |
| `ENUM_4870` |
| `ENUM_4871` |
| `ENUM_6305` |
| `ENUM_6321` |
| `C04` |
| `C05` |
| `C08` |
| `C28` |
| `C31` |
| `C32` |
| `F10` |
| `F14` |
| `F22` |
| `F24` |
| `F25` |
| `F29` |
| `FR2` |
| `FR4` |
| `FR6` |
| `P01` |
| `P03` |
| `P04` |
| `P05` |
| `P07` |
| `P08` |
| `P22` |
| `P23` |
| `ENUM_4534` |
| `ENUM_4541` |
| `ENUM_4542` |
| `ENUM_4550` |
| `ENUM_4553` |
| `ENUM_4586` |
| `ENUM_4752` |
| `ENUM_4753` |
| `ENUM_4754` |
| `ENUM_4755` |
| `ENUM_7010` |
| `ENUM_7030` |
| `UNKNOWN` |

#### Detail Code 8

##### Class Name

`DetailCode8Enum`

##### Fields

| Name |
|  --- |
| `RISK_REVIEW` |
| `UNKNOWN` |

#### Detail Code 9

Adjustment detail code

##### Class Name

`DetailCode9Enum`

##### Fields

| Name |
|  --- |
| `CROSS_BORDER` |
| `BALANCE_TRANSFER` |
| `OTHER` |
| `PARTIAL_CHARGEBACK_REVERSALS` |
| `CHARGEBACK_FEE_REIMBURSEMENTS` |
| `LIEN_OR_LEVY` |
| `ESCHEATMENT` |
| `CORRECTION_TO_FEE_SCHEDULES` |
| `PROCESSING_FEE_REIMBURSEMENTS` |
| `REVSHARE_DISBURSEMENTS` |
| `INADVERTENT_REFUNDS` |
| `BANK_OVERDRAFT_FEE` |
| `NEGATIVE_ACCOUNT_BALANCE_RECOVERY` |
| `NEGATIVE_ACCOUNT_BALANCE_TO_ZERO` |
| `SYSTEM_ISSUES` |
| `MISCELLANEOUS` |

#### Detail Code 10

##### Class Name

`DetailCode10Enum`

##### Fields

| Name |
|  --- |
| `ILLEGIBLE` |
| `CORRUPT_FILE` |
| `INFO_MISMATCH` |
| `DOC_UNSUPPORTED` |
| `INCOMPLETE` |

#### Errant Field

##### Class Name

`ErrantFieldEnum`

##### Fields

| Name |
|  --- |
| `IS_NULL` |
| `IS_PO_BOX` |
| `IS_FALSE` |

#### Issue Type

##### Class Name

`IssueTypeEnum`

##### Fields

| Name |
|  --- |
| `APPLICATION_BLOCK` |
| `ERRANT_FIELDS` |
| `ADDITIONAL_DOCUMENTS_REQUIRED` |
| `IN_REVIEW` |
| `UNSUPPORTED` |
| `FRAUD` |
| `HIGH_RISK_CB_RATE` |
| `REPORTED_USER` |
| `TOS_VIOLATION` |
| `COUNTRY_NOT_SUPPORTED` |
| `COMPLIANCE` |
| `CLOSED_FOR_LOSS` |

#### Issue Type 4

##### Class Name

`IssueType4Enum`

##### Fields

| Name |
|  --- |
| `ERRANT_FIELDS` |
| `ADDITIONAL_DOCUMENTS_REQUIRED` |
| `IN_REVIEW` |

#### Legal Form

##### Class Name

`LegalFormEnum`

##### Fields

| Name |
|  --- |
| `INDIVIDUAL` |
| `SOLE_PROPRIETOR` |
| `LIMITED_LIABILITY_COMPANY` |
| `PARTNERSHIP` |
| `CORPORATION` |
| `NONPROFIT_CORPORATION` |
| `UNINCORPORATED_ASSOCIATION` |
| `PERSONAL_TRUST` |
| `STATUTORY_TRUST` |
| `GOVERNMENT_AGENCY` |

#### Legal Form 1

##### Class Name

`LegalForm1Enum`

##### Fields

| Name |
|  --- |
| `INDIVIDUAL` |
| `SOLE_TRADER` |
| `PARTNERSHIP` |
| `CHARITY` |
| `LIMITED_LIABILITY_PARTNERSHIP` |
| `PRIVATE_LIMITED_COMPANY` |
| `PUBLIC_LIMITED_COMPANY` |

#### Mfa Action

##### Class Name

`MfaActionEnum`

##### Fields

| Name |
|  --- |
| `ACTIVATED` |
| `DISABLED` |
| `UPDATED` |

#### Mode

The way in which tip is handled by this terminal. If "disabled", tip will not be prompted for. Otherwise, value determines if the prompt should appear on the terminal or on the receipt. Note: If set to "prompt_on_terminal" then you must provide the "terminal_display" field as well.

##### Class Name

`ModeEnum`

##### Fields

| Name |
|  --- |
| `DISABLED` |
| `PROMPT_ON_TERMINAL` |
| `PROMPT_ON_RECEIPT` |

#### Model

##### Class Name

`ModelEnum`

##### Fields

| Name |
|  --- |
| `VERIFONE_P400` |
| `VERIFONE_V400M` |

#### Model 1

The model of the physical terminal.

##### Class Name

`Model1Enum`

##### Fields

| Name |
|  --- |
| `VERIFONE_P400` |
| `VERIFONE_V400M` |

#### Name Type

##### Class Name

`NameTypeEnum`

##### Fields

| Name |
|  --- |
| `LEGAL` |
| `DBA` |

#### Payment Method Type

##### Class Name

`PaymentMethodTypeEnum`

##### Fields

| Name |
|  --- |
| `CREDIT_CARD` |
| `PAYMENT_BANK_US` |

#### Payout Method Type

##### Class Name

`PayoutMethodTypeEnum`

##### Fields

| Name |
|  --- |
| `PAYOUT_BANK_CA` |
| `PAYOUT_BANK_GB` |
| `PAYOUT_BANK_US` |

#### Period

##### Class Name

`PeriodEnum`

##### Fields

| Name |
|  --- |
| `DAILY` |
| `WEEKLY` |
| `MONTHLY` |

#### Phone Type

##### Class Name

`PhoneTypeEnum`

##### Fields

| Name |
|  --- |
| `MOBILE` |
| `PERSONAL` |
| `BUSINESS` |

#### Reason Code

##### Class Name

`ReasonCodeEnum`

##### Fields

| Name |
|  --- |
| `PROCESSING` |
| `UNKNOWN` |

#### Reason Code 1

##### Class Name

`ReasonCode1Enum`

##### Fields

| Name |
|  --- |
| `REVIEW` |
| `PROCESSING` |
| `UNKNOWN` |

#### Reason Code 2

##### Class Name

`ReasonCode2Enum`

##### Fields

| Name |
|  --- |
| `PENDING_CAPTURE` |
| `PROCESSING` |
| `REVIEW` |
| `ECHECK_SUBMISSION` |
| `BANK_VERIFICATION` |
| `UNKNOWN` |

#### Reason Code 3

##### Class Name

`ReasonCode3Enum`

##### Fields

| Name |
|  --- |
| `REVIEW` |
| `PROCESSING` |

#### Reason Code 4

##### Class Name

`ReasonCode4Enum`

##### Fields

| Name |
|  --- |
| `SUSPECTED_FRAUD` |
| `VERIFICATION` |
| `OTHER` |
| `UNKNOWN` |

#### Reason Code 5

##### Class Name

`ReasonCode5Enum`

##### Fields

| Name |
|  --- |
| `NOT_CAPTURED` |
| `ECHECK_FRAUD` |
| `BANK_NOT_CONFIRMED` |
| `BANK_SYSTEM_ERROR` |
| `PAYMENT_EXPIRED` |
| `REVIEW` |
| `UNKNOWN` |

#### Reason Code 6

##### Class Name

`ReasonCode6Enum`

##### Fields

| Name |
|  --- |
| `BANK_REJECT` |
| `UNKNOWN` |

#### Reason Code 7

The category of dispute reason

##### Class Name

`ReasonCode7Enum`

##### Fields

| Name |
|  --- |
| `FRAUD` |
| `RECOGNITION` |
| `PROCESSING_ERROR` |
| `SERVICES_NOT_PROVIDED` |
| `NOT_AS_DESCRIBED` |
| `INQUIRY` |
| `UNKNOWN` |

#### Reason Code 8

##### Class Name

`ReasonCode8Enum`

##### Fields

| Name |
|  --- |
| `REVIEW` |
| `UNKNOWN` |

#### Reason Code 9

The category of adjustment reason

##### Class Name

`ReasonCode9Enum`

##### Fields

| Name |
|  --- |
| `CROSS_BORDER` |
| `BALANCE_TRANSFER` |
| `CHARGEBACK` |
| `ESCHEATMENT` |
| `REIMBURSEMENTS_AND_CORRECTIONS` |
| `MISCELLANEOUS` |

#### Resource

##### Class Name

`ResourceEnum`

##### Fields

| Name |
|  --- |
| `ORDERS` |

#### Resource 1

##### Class Name

`Resource1Enum`

##### Fields

| Name |
|  --- |
| `PAYMENTS` |
| `REFUNDS` |
| `ADJUSTMENTS` |
| `PAYOUTS` |
| `RECOVERIES` |
| `DISPUTES` |

#### Resource 2

##### Class Name

`Resource2Enum`

##### Fields

| Name |
|  --- |
| `PAYMENT_METHODS` |
| `PAYOUT_METHODS` |
| `LEGAL_ENTITIES` |

#### Role

##### Class Name

`RoleEnum`

##### Fields

| Name |
|  --- |
| `EMPLOYEE` |
| `FUNDRAISER` |
| `FUNDRAISING_TEAM_CAPTAIN` |
| `OTHER_THIRD_PARTY` |

#### Service Billing Method

##### Class Name

`ServiceBillingMethodEnum`

##### Fields

| Name |
|  --- |
| `FREE_FORM_ENTRY` |
| `TIMED_BILLING_AT_STAFF_RATE` |
| `TIMED_BILLING_AT_TASK_RATE` |
| `TIMED_BILLING_AT_PROJECT_RATE` |
| `HOURLY_BILLING_AT_STAFF_RATE` |
| `HOURLY_BILLING_AT_TASK_RATE` |
| `HOURLY_BILLING_AT_PROJECT_RATE` |
| `FLAT_PROJECT_AMOUNT` |

#### Setup By

##### Class Name

`SetupByEnum`

##### Fields

| Name |
|  --- |
| `PAYER` |
| `MERCHANT` |

#### State

##### Class Name

`StateEnum`

##### Fields

| Name |
|  --- |
| `ACTIVE` |
| `DELETED` |

#### Status

##### Class Name

`StatusEnum`

##### Fields

| Name |
|  --- |
| `PENDING` |
| `COMPLETED` |
| `FAILED` |

#### Status 2

##### Class Name

`Status2Enum`

##### Fields

| Name |
|  --- |
| `UNVERIFIED` |
| `VERIFIED` |
| `VERIFICATION_FAILED` |
| `DELETED` |

#### Status 3

##### Class Name

`Status3Enum`

##### Fields

| Name |
|  --- |
| `PENDING` |
| `COMPLETED` |
| `FAILED` |
| `CANCELED` |

#### Status 4

##### Class Name

`Status4Enum`

##### Fields

| Name |
|  --- |
| `UNPAID` |
| `PAID` |
| `DISPUTED` |

#### Status 5

##### Class Name

`Status5Enum`

##### Fields

| Name |
|  --- |
| `AWAITING_MERCHANT_RESPONSE` |
| `PENDING_WEPAY_REVIEW` |
| `AWAITING_CHARGEBACK_DECISION` |
| `RESOLVED` |

#### Status 8

##### Class Name

`Status8Enum`

##### Fields

| Name |
|  --- |
| `IN_REVIEW` |
| `VERIFIED` |
| `REJECTED` |

#### Status 20

##### Class Name

`Status20Enum`

##### Fields

| Name |
|  --- |
| `ACTIVE` |
| `UNREACHABLE` |
| `DELETED` |

#### Supported Card Entry Mode

##### Class Name

`SupportedCardEntryModeEnum`

##### Fields

| Name |
|  --- |
| `CHIP` |
| `MAGNETIC_STRIPE` |
| `CONTACTLESS` |
| `FALLBACK_TO_MAGNETIC_STRIPE` |

#### Terminals-Supported Card Brand

##### Class Name

`TerminalsSupportedCardBrandEnum`

##### Fields

| Name |
|  --- |
| `VISA` |
| `AMERICAN_EXPRESS` |
| `DISCOVER` |
| `MASTERCARD` |

#### Timezone

Timezone of the terminal'

##### Class Name

`TimezoneEnum`

##### Fields

| Name |
|  --- |
| `ENUM_USALASKA` |
| `ENUM_USALEUTIAN` |
| `ENUM_USARIZONA` |
| `ENUM_USCENTRAL` |
| `ENUM_USEASTINDIANA` |
| `ENUM_USEASTERN` |
| `ENUM_USHAWAII` |
| `ENUM_USINDIANASTARKE` |
| `ENUM_USMICHIGAN` |
| `ENUM_USMOUNTAIN` |
| `ENUM_USPACIFIC` |
| `ENUM_USPACIFICNEW` |
| `ENUM_USSAMOA` |

#### Topic

##### Class Name

`TopicEnum`

##### Fields

| Name |
|  --- |
| `ENUM_ADJUSTMENTS` |
| `ENUM_ADJUSTMENTSCREATED` |
| `ENUM_ACCOUNTS` |
| `ENUM_ACCOUNTSCREATED` |
| `ENUM_ACCOUNTSUPDATED` |
| `ENUM_ACCOUNTSCAPABILITIES` |
| `ENUM_ACCOUNTSCAPABILITIESUPDATED` |
| `ENUM_ACCOUNTSNEGATIVE_BALANCE` |
| `ENUM_LEGAL_ENTITIES` |
| `ENUM_LEGAL_ENTITIESCREATED` |
| `ENUM_LEGAL_ENTITIESUPDATED` |
| `ENUM_LEGAL_ENTITIESVERIFICATIONS` |
| `ENUM_LEGAL_ENTITIESVERIFICATIONSUPDATED` |
| `ENUM_DISPUTES` |
| `ENUM_DISPUTESCREATED` |
| `ENUM_DISPUTESRESOLVED` |
| `ENUM_DISPUTESUPDATED` |
| `ENUM_DISPUTESFUNDS_WITHDRAWN` |
| `ENUM_DISPUTESFUNDS_REINSTATED` |
| `ENUM_PAYMENT_METHODS` |
| `ENUM_PAYMENT_METHODSCREATED` |
| `ENUM_PAYMENT_METHODSDELETED` |
| `ENUM_PAYMENT_METHODSUPDATED` |
| `ENUM_PAYMENT_METHODSVERIFIED` |
| `ENUM_PAYMENT_METHODSMICRODEPOSIT_SENT` |
| `ENUM_PAYOUT_METHODS` |
| `ENUM_PAYOUT_METHODSCREATED` |
| `ENUM_PAYMENTS` |
| `ENUM_PAYMENTSCREATED` |
| `ENUM_PAYMENTSCOMPLETED` |
| `ENUM_PAYMENTSFAILED` |
| `ENUM_PAYMENTSIN_REVIEW` |
| `ENUM_PAYMENTSCANCELED` |
| `ENUM_PAYOUTS` |
| `ENUM_PAYOUTSCREATED` |
| `ENUM_PAYOUTSCOMPLETED` |
| `ENUM_PAYOUTSIN_REVIEW` |
| `ENUM_PAYOUTSFAILED` |
| `ENUM_RECOVERIES` |
| `ENUM_RECOVERIESCREATED` |
| `ENUM_RECOVERIESCOMPLETED` |
| `ENUM_RECOVERIESFAILED` |
| `ENUM_REFUNDS` |
| `ENUM_REFUNDSCREATED` |
| `ENUM_REFUNDSCOMPLETED` |
| `ENUM_REFUNDSFAILED` |

#### Topic 1

##### Class Name

`Topic1Enum`

##### Fields

| Name |
|  --- |
| `ENUM_ADJUSTMENTSCREATED` |
| `ENUM_ACCOUNTSCREATED` |
| `ENUM_ACCOUNTSUPDATED` |
| `ENUM_ACCOUNTSCAPABILITIESUPDATED` |
| `ENUM_ACCOUNTSNEGATIVE_BALANCE` |
| `ENUM_LEGAL_ENTITIESCREATED` |
| `ENUM_LEGAL_ENTITIESUPDATED` |
| `ENUM_LEGAL_ENTITIESVERIFICATIONSUPDATED` |
| `ENUM_DISPUTESCREATED` |
| `ENUM_DISPUTESRESOLVED` |
| `ENUM_DISPUTESUPDATED` |
| `ENUM_DISPUTESFUNDS_WITHDRAWN` |
| `ENUM_DISPUTESFUNDS_REINSTATED` |
| `ENUM_PAYMENT_METHODSCREATED` |
| `ENUM_PAYMENT_METHODSDELETED` |
| `ENUM_PAYMENT_METHODSUPDATED` |
| `ENUM_PAYMENT_METHODSVERIFIED` |
| `ENUM_PAYMENT_METHODSMICRODEPOSIT_SENT` |
| `ENUM_PAYOUT_METHODSCREATED` |
| `ENUM_PAYMENTSCREATED` |
| `ENUM_PAYMENTSCOMPLETED` |
| `ENUM_PAYMENTSFAILED` |
| `ENUM_PAYMENTSIN_REVIEW` |
| `ENUM_PAYMENTSCANCELED` |
| `ENUM_PAYOUTSCREATED` |
| `ENUM_PAYOUTSCOMPLETED` |
| `ENUM_PAYOUTSIN_REVIEW` |
| `ENUM_PAYOUTSFAILED` |
| `ENUM_RECOVERIESCREATED` |
| `ENUM_RECOVERIESCOMPLETED` |
| `ENUM_RECOVERIESFAILED` |
| `ENUM_REFUNDSCREATED` |
| `ENUM_REFUNDSCOMPLETED` |
| `ENUM_REFUNDSFAILED` |

#### Type

##### Class Name

`TypeEnum`

##### Fields

| Name |
|  --- |
| `MOBILE` |
| `PERSONAL` |
| `BUSINESS` |

#### Type 2

##### Class Name

`Type2Enum`

##### Fields

| Name |
|  --- |
| `PAYOUT_BANK_CA` |
| `PAYOUT_BANK_GB` |
| `PAYOUT_BANK_US` |

#### Type 3

##### Class Name

`Type3Enum`

##### Fields

| Name |
|  --- |
| `CREDIT_CARD` |
| `PAYMENT_BANK_US` |

#### Type 4

##### Class Name

`Type4Enum`

##### Fields

| Name |
|  --- |
| `GOODS` |
| `SERVICE` |
| `DONATION` |
| `EVENT` |
| `PERSONAL` |

#### Type 5

##### Class Name

`Type5Enum`

##### Fields

| Name |
|  --- |
| `WON` |
| `LOST` |
| `PENDING` |

#### Type 6

##### Class Name

`Type6Enum`

##### Fields

| Name |
|  --- |
| `INQUIRY` |
| `CHARGEBACK` |

#### Type 7

##### Class Name

`Type7Enum`

##### Fields

| Name |
|  --- |
| `CREDIT` |
| `DEBIT` |

#### Type 8

##### Class Name

`Type8Enum`

##### Fields

| Name |
|  --- |
| `MERCHANT_PAYMENT` |
| `APP_FEE` |
| `MERCHANT_PAYMENT_REFUND` |
| `APP_FEE_REFUND` |
| `MERCHANT_CHARGEBACK` |
| `APP_FEE_CHARGEBACK` |
| `MERCHANT_CHARGEBACK_FEE` |
| `MERCHANT_CHARGEBACK_REVERSAL` |
| `APP_FEE_CHARGEBACK_REVERSAL` |
| `PAYOUT` |
| `PAYOUT_RETURN` |
| `RECOVERY` |
| `RECOVERY_RETURN` |
| `ADJUSTMENT` |

#### Type 9

##### Class Name

`Type9Enum`

##### Fields

| Name |
|  --- |
| `CREDIT_CARD` |
| `PAYMENT_BANK_US` |
| `PAYMENT_METHOD_ID` |
| `ENCODED_PAYMENT_METHOD` |

#### Type 12

##### Class Name

`Type12Enum`

##### Fields

| Name |
|  --- |
| `LEGAL_ENTITY` |
| `LEGAL_ENTITY_ID` |

#### Type 15

##### Class Name

`Type15Enum`

##### Fields

| Name |
|  --- |
| `PASSPORT` |
| `DRIVERS_LICENSE` |
| `OTHER_GOVERNMENT_ISSUED_PHOTO_ID` |
| `CURRENT_LEASE_CONTRACT` |
| `CURRENT_UTILITY_BILL` |
| `BENEFITS_CARD` |
| `BIRTH_CERTIFICATE` |
| `CERTIFICATE_OF_CITIZENSHIP` |
| `CERTIFICATE_OF_NATURALIZATION` |
| `CERTIFIED_COPY_OF_COURT_ORDER` |
| `EMPLOYMENT_AUTHORIZATION_CARD` |
| `PERMANENT_RESIDENT_CARD` |
| `SOCIAL_SECURITY_CARD` |
| `SOCIAL_INSURANCE_NUMBER_CARD` |
| `EVIDENCE_OF_CORPORATE_REGISTRATION` |
| `EVIDENCE_OF_NONPROFIT_REGISTRATION` |
| `EVIDENCE_OF_AUTHORITY` |
| `CURRENT_BANK_STATEMENT` |
| `CURRENT_LOCAL_TAX_BILL` |
| `MORTGAGE_STATEMENT` |
| `ELECTORAL_REGISTER_ENTRY` |

#### Type 27

##### Class Name

`Type27Enum`

##### Fields

| Name |
|  --- |
| `NOTIFICATION` |

#### Units

##### Class Name

`UnitsEnum`

##### Fields

| Name |
|  --- |
| `POUNDS` |
| `KILOGRAMS` |

#### Virtual Terminal Mode

##### Class Name

`VirtualTerminalModeEnum`

##### Fields

| Name |
|  --- |
| `MOBILE` |
| `WEB` |

## Utility Classes Documentation

### ApiHelper Class

API utility class.

### Methods

| Name | Return Type | Description |
|  --- | --- | --- |
| json_deserialize | Hash | Deserializes a JSON string to a Ruby Hash. |
| rfc3339 | DateTime | Safely converts a string into an RFC3339 DateTime object. |

## Common Code Documentation

### HttpResponse

Http response received.

#### Properties

| Name | Type | Description |
|  --- | --- | --- |
| status_code | Integer | The status code returned by the server. |
| reason_phrase | String | The reason phrase returned by the server. |
| headers | Hash | Response headers. |
| raw_body | String | Response body. |
| request | HttpRequest | The request that resulted in this response. |

### HttpRequest

Represents a single Http Request.

#### Properties

| Name | Type | Tag | Description |
|  --- | --- | --- | --- |
| http_method | HttpMethodEnum |  | The HTTP method of the request. |
| query_url | String |  | The endpoint URL for the API request. |
| headers | Hash | Optional | Request headers. |
| parameters | Hash | Optional | Request body. |

